//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import 'mixins';

/// Overrides `$carbon--grid-breakpoints` to use a 12 column grid instead of the default 16
/// @type Map
/// @access public
/// @group @carbon/grid
$carbon--12-column-grid: map-merge(
  $carbon--grid-breakpoints,
  (
    lg:
      map-merge(
        map-get($carbon--grid-breakpoints, lg),
        (
          columns: 12,
        )
      ),
    xlg:
      map-merge(
        map-get($carbon--grid-breakpoints, xlg),
        (
          columns: 12,
        )
      ),
    max:
      map-merge(
        map-get($carbon--grid-breakpoints, max),
        (
          columns: 12,
        )
      ),
  )
);

@include carbon--grid($breakpoints: $carbon--12-column-grid);
