// Code generated by @carbon/colors. DO NOT EDIT.
//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//
@import './mixins';
// Deprecated ☠️
@include ibm--colors();
// Preferred
@include carbon--colors();
