// Code generated by @carbon/layout. DO NOT EDIT.
//
// Copyright IBM Corp. 2018, 2019
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--container-01: 1.5rem !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--container-02: 2rem !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--container-03: 2.5rem !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--container-04: 3rem !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--container-05: 4rem !default;

/// @type List
/// @access public
/// @group @carbon/layout
$carbon--container: (
  $carbon--container-01,
  $carbon--container-02,
  $carbon--container-03,
  $carbon--container-04,
  $carbon--container-05
);

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--container-01
$container-01: $carbon--container-01 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--container-02
$container-02: $carbon--container-02 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--container-03
$container-03: $carbon--container-03 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--container-04
$container-04: $carbon--container-04 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--container-05
$container-05: $carbon--container-05 !default;
