# Generated by Django 3.2.13 on 2022-05-23 04:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("document_templates", "0003_auto_20220328_0930"),
    ]

    operations = [
        migrations.AddField(
            model_name="documenttemplatevariable",
            name="template",
            field=models.TextField(
                blank=True,
                help_text="Jinja template with 'value' in context",
                verbose_name="Template",
            ),
        ),
    ]
