//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import 'convert';

/// Default mini-unit value
/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--mini-unit-size: 8px !default;

/// Get the value of the corresponding number of units
/// @param {Number} $count - The number of units to get the value for
/// @return {Number} In rem units
/// @access public
/// @group @carbon/layout
@function carbon--mini-units($count) {
  @return carbon--rem($carbon--mini-unit-size * $count);
}
