# Generated by Django 3.2.12 on 2022-03-28 03:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('reports', '0005_auto_20210826_1951'),
    ]

    operations = [
        migrations.AlterField(
            model_name='report',
            name='model',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='contenttypes.contenttype', verbose_name='Model'),
        ),
    ]
