# Generated by Django 3.2.12 on 2022-03-28 08:34

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('document_templates', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='documenttemplate',
            options={'verbose_name': 'Document Template', 'verbose_name_plural': 'Document Templates'},
        ),
        migrations.AddField(
            model_name='documenttemplate',
            name='model',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.PROTECT, to='contenttypes.contenttype', verbose_name='Model'),
            preserve_default=False,
        ),
        migrations.CreateModel(
            name='DocumentTemplateVariable',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('value', models.CharField(max_length=255, verbose_name='Value')),
                ('raw_value', models.BooleanField(default=False, verbose_name='Raw value')),
                ('document_template', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='variables', to='document_templates.documenttemplate')),
            ],
            options={
                'verbose_name': 'Variable',
                'verbose_name_plural': 'Variables',
            },
        ),
    ]
