# Generated by Django 3.2.12 on 2022-03-28 09:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('document_templates', '0002_auto_20220328_0834'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documenttemplate',
            name='file',
            field=models.FileField(help_text="Must be a *.docx file, use '{{ variable-name }}' to insert variables from below", upload_to='document_templates/'),
        ),
        migrations.AlterField(
            model_name='documenttemplatevariable',
            name='name',
            field=models.CharField(help_text='Name to use in the template document', max_length=255, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='documenttemplatevariable',
            name='value',
            field=models.CharField(help_text='Path to the desired value (see help)', max_length=255, verbose_name='Value'),
        ),
    ]
