//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import '@carbon/import-once/scss/import-once';
@import '@carbon/colors/scss/colors';
@import '@carbon/themes/scss/themes';
@import '@carbon/layout/scss/layout';
@import '@carbon/grid/scss/grid';
@import '@carbon/icons/scss/icons';
@import '@carbon/type/scss/type';
@import '@carbon/motion/scss/motion';
