//
// Copyright IBM Corp. 2016, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

/// Use rem here to accomodate zoom behavior
/// @link https://github.com/IBM/carbon-components/pull/1032#discussion_r210418579
/// @access private
/// @group ui-shell
$unit: 0.5rem;
