from django.utils.translation import gettext as _

LANGUAGES = (
    ("aa", _("Afar")),
    ("ab", _("Abkhazian")),
    ("ae", _("Avestan")),
    ("af", _("Afrikaans")),
    ("ak", _("Akan")),
    ("am", _("Amharic")),
    ("an", _("Aragonese")),
    ("ar", _("Arabic")),
    ("as", _("Assamese")),
    ("av", _("Avaric")),
    ("ay", _("Aymara")),
    ("az", _("Azerbaijani")),
    ("ba", _("Bashkir")),
    ("be", _("Belarusian")),
    ("bg", _("Bulgarian")),
    ("bh", _("Bihari languages")),
    ("bi", _("Bislama")),
    ("bm", _("Bambara")),
    ("bn", _("Bengali")),
    ("bo", _("Tibetan")),
    ("br", _("Breton")),
    ("bs", _("Bosnian")),
    ("ca", _("Catalan")),
    ("ce", _("Chechen")),
    ("ch", _("Chamorro")),
    ("co", _("Corsican")),
    ("cr", _("Cree")),
    ("cs", _("Czech")),
    ("cu", _("Church Slavic")),
    ("cv", _("Chuvash")),
    ("cy", _("Welsh")),
    ("da", _("Danish")),
    ("de", _("German")),
    ("dv", _("Dhivehi")),
    ("dz", _("Dzongkha")),
    ("ee", _("Ewe")),
    ("el", _("Modern Greek")),
    ("en", _("English")),
    ("eo", _("Esperanto")),
    ("es", _("Spanish")),
    ("et", _("Estonian")),
    ("eu", _("Basque")),
    ("fa", _("Persian")),
    ("ff", _("Fulah")),
    ("fi", _("Finnish")),
    ("fj", _("Fijian")),
    ("fo", _("Faroese")),
    ("fr", _("French")),
    ("fy", _("Western Frisian")),
    ("ga", _("Irish")),
    ("gd", _("Scottish Gaelic")),
    ("gl", _("Galician")),
    ("gn", _("Guarani")),
    ("gu", _("Gujarati")),
    ("gv", _("Manx")),
    ("ha", _("Hausa")),
    ("he", _("Hebrew")),
    ("hi", _("Hindi")),
    ("ho", _("Hiri Motu")),
    ("hr", _("Croatian")),
    ("ht", _("Haitian")),
    ("hu", _("Hungarian")),
    ("hy", _("Armenian")),
    ("hz", _("Herero")),
    ("ia", _("Interlingua")),
    ("id", _("Indonesian")),
    ("ie", _("Interlingue")),
    ("ig", _("Igbo")),
    ("ii", _("Sichuan Yi")),
    ("ik", _("Inupiaq")),
    ("in", _("Indonesian")),
    ("io", _("Ido")),
    ("is", _("Icelandic")),
    ("it", _("Italian")),
    ("iu", _("Inuktitut")),
    ("iw", _("Hebrew")),
    ("ja", _("Japanese")),
    ("ji", _("Yiddish")),
    ("jv", _("Javanese")),
    ("jw", _("Javanese")),
    ("ka", _("Georgian")),
    ("kg", _("Kongo")),
    ("ki", _("Kikuyu")),
    ("kj", _("Kuanyama")),
    ("kk", _("Kazakh")),
    ("kl", _("Kalaallisut")),
    ("km", _("Khmer")),
    ("kn", _("Kannada")),
    ("ko", _("Korean")),
    ("kr", _("Kanuri")),
    ("ks", _("Kashmiri")),
    ("ku", _("Kurdish")),
    ("kv", _("Komi")),
    ("kw", _("Cornish")),
    ("ky", _("Kirghiz")),
    ("la", _("Latin")),
    ("lb", _("Luxembourgish")),
    ("lg", _("Ganda")),
    ("li", _("Limburgan")),
    ("ln", _("Lingala")),
    ("lo", _("Lao")),
    ("lt", _("Lithuanian")),
    ("lu", _("Luba-Katanga")),
    ("lv", _("Latvian")),
    ("mg", _("Malagasy")),
    ("mh", _("Marshallese")),
    ("mi", _("Maori")),
    ("mk", _("Macedonian")),
    ("ml", _("Malayalam")),
    ("mn", _("Mongolian")),
    ("mo", _("Moldavian")),
    ("mr", _("Marathi")),
    ("ms", _("Malay")),
    ("mt", _("Maltese")),
    ("my", _("Burmese")),
    ("na", _("Nauru")),
    ("nb", _("Norwegian Bokmål")),
    ("nd", _("North Ndebele")),
    ("ne", _("Nepali")),
    ("ng", _("Ndonga")),
    ("nl", _("Dutch")),
    ("nn", _("Norwegian Nynorsk")),
    ("no", _("Norwegian")),
    ("nr", _("South Ndebele")),
    ("nv", _("Navajo")),
    ("ny", _("Nyanja")),
    ("oc", _("Occitan")),
    ("oj", _("Ojibwa")),
    ("om", _("Oromo")),
    ("or", _("Oriya")),
    ("os", _("Ossetian")),
    ("pa", _("Panjabi")),
    ("pi", _("Pali")),
    ("pl", _("Polish")),
    ("ps", _("Pushto")),
    ("pt", _("Portuguese")),
    ("qu", _("Quechua")),
    ("rm", _("Romansh")),
    ("rn", _("Rundi")),
    ("ro", _("Romanian")),
    ("ru", _("Russian")),
    ("rw", _("Kinyarwanda")),
    ("sa", _("Sanskrit")),
    ("sc", _("Sardinian")),
    ("sd", _("Sindhi")),
    ("se", _("Northern Sami")),
    ("sg", _("Sango")),
    ("sh", _("Serbo-Croatian")),
    ("si", _("Sinhala")),
    ("sk", _("Slovak")),
    ("sl", _("Slovenian")),
    ("sm", _("Samoan")),
    ("sn", _("Shona")),
    ("so", _("Somali")),
    ("sq", _("Albanian")),
    ("sr", _("Serbian")),
    ("ss", _("Swati")),
    ("st", _("Southern Sotho")),
    ("su", _("Sundanese")),
    ("sv", _("Swedish")),
    ("sw", _("Swahili")),
    ("ta", _("Tamil")),
    ("te", _("Telugu")),
    ("tg", _("Tajik")),
    ("th", _("Thai")),
    ("ti", _("Tigrinya")),
    ("tk", _("Turkmen")),
    ("tl", _("Tagalog")),
    ("tn", _("Tswana")),
    ("to", _("Tonga")),
    ("tr", _("Turkish")),
    ("ts", _("Tsonga")),
    ("tt", _("Tatar")),
    ("tw", _("Twi")),
    ("ty", _("Tahitian")),
    ("ug", _("Uighur")),
    ("uk", _("Ukrainian")),
    ("ur", _("Urdu")),
    ("uz", _("Uzbek")),
    ("ve", _("Venda")),
    ("vi", _("Vietnamese")),
    ("vo", _("Volapük")),
    ("wa", _("Walloon")),
    ("wo", _("Wolof")),
    ("xh", _("Xhosa")),
    ("yi", _("Yiddish")),
    ("yo", _("Yoruba")),
    ("za", _("Zhuang")),
    ("zh", _("Chinese")),
    ("zu", _("Zulu")),
    ("aaa", _("Ghotuo")),
    ("aab", _("Alumu-Tesu")),
    ("aac", _("Ari")),
    ("aad", _("Amal")),
    ("aae", _("Arbëreshë Albanian")),
    ("aaf", _("Aranadan")),
    ("aag", _("Ambrak")),
    ("aah", _("Abu' Arapesh")),
    ("aai", _("Arifama-Miniafia")),
    ("aak", _("Ankave")),
    ("aal", _("Afade")),
    ("aam", _("Aramanik")),
    ("aan", _("Anambé")),
    ("aao", _("Algerian Saharan Arabic")),
    ("aap", _("Pará Arára")),
    ("aaq", _("Eastern Abnaki")),
    ("aas", _("Aasáx")),
    ("aat", _("Arvanitika Albanian")),
    ("aau", _("Abau")),
    ("aav", _("Austro-Asiatic languages")),
    ("aaw", _("Solong")),
    ("aax", _("Mandobo Atas")),
    ("aaz", _("Amarasi")),
    ("aba", _("Abé")),
    ("abb", _("Bankon")),
    ("abc", _("Ambala Ayta")),
    ("abd", _("Manide")),
    ("abe", _("Western Abnaki")),
    ("abf", _("Abai Sungai")),
    ("abg", _("Abaga")),
    ("abh", _("Tajiki Arabic")),
    ("abi", _("Abidji")),
    ("abj", _("Aka-Bea")),
    ("abl", _("Lampung Nyo")),
    ("abm", _("Abanyom")),
    ("abn", _("Abua")),
    ("abo", _("Abon")),
    ("abp", _("Abellen Ayta")),
    ("abq", _("Abaza")),
    ("abr", _("Abron")),
    ("abs", _("Ambonese Malay")),
    ("abt", _("Ambulas")),
    ("abu", _("Abure")),
    ("abv", _("Baharna Arabic")),
    ("abw", _("Pal")),
    ("abx", _("Inabaknon")),
    ("aby", _("Aneme Wake")),
    ("abz", _("Abui")),
    ("aca", _("Achagua")),
    ("acb", _("Áncá")),
    ("acd", _("Gikyode")),
    ("ace", _("Achinese")),
    ("acf", _("Saint Lucian Creole French")),
    ("ach", _("Acoli")),
    ("aci", _("Aka-Cari")),
    ("ack", _("Aka-Kora")),
    ("acl", _("Akar-Bale")),
    ("acm", _("Mesopotamian Arabic")),
    ("acn", _("Achang")),
    ("acp", _("Eastern Acipa")),
    ("acq", _("Ta'izzi-Adeni Arabic")),
    ("acr", _("Achi")),
    ("acs", _("Acroá")),
    ("act", _("Achterhoeks")),
    ("acu", _("Achuar-Shiwiar")),
    ("acv", _("Achumawi")),
    ("acw", _("Hijazi Arabic")),
    ("acx", _("Omani Arabic")),
    ("acy", _("Cypriot Arabic")),
    ("acz", _("Acheron")),
    ("ada", _("Adangme")),
    ("adb", _("Atauran")),
    ("add", _("Lidzonka")),
    ("ade", _("Adele")),
    ("adf", _("Dhofari Arabic")),
    ("adg", _("Andegerebinha")),
    ("adh", _("Adhola")),
    ("adi", _("Adi")),
    ("adj", _("Adioukrou")),
    ("adl", _("Galo")),
    ("adn", _("Adang")),
    ("ado", _("Abu")),
    ("adp", _("Adap")),
    ("adq", _("Adangbe")),
    ("adr", _("Adonara")),
    ("ads", _("Adamorobe Sign Language")),
    ("adt", _("Adnyamathanha")),
    ("adu", _("Aduge")),
    ("adw", _("Amundava")),
    ("adx", _("Amdo Tibetan")),
    ("ady", _("Adyghe")),
    ("adz", _("Adzera")),
    ("aea", _("Areba")),
    ("aeb", _("Tunisian Arabic")),
    ("aec", _("Saidi Arabic")),
    ("aed", _("Argentine Sign Language")),
    ("aee", _("Northeast Pashai")),
    ("aek", _("Haeke")),
    ("ael", _("Ambele")),
    ("aem", _("Arem")),
    ("aen", _("Armenian Sign Language")),
    ("aeq", _("Aer")),
    ("aer", _("Eastern Arrernte")),
    ("aes", _("Alsea")),
    ("aeu", _("Akeu")),
    ("aew", _("Ambakich")),
    ("aey", _("Amele")),
    ("aez", _("Aeka")),
    ("afa", _("Afro-Asiatic languages")),
    ("afb", _("Gulf Arabic")),
    ("afd", _("Andai")),
    ("afe", _("Putukwam")),
    ("afg", _("Afghan Sign Language")),
    ("afh", _("Afrihili")),
    ("afi", _("Akrukay")),
    ("afk", _("Nanubae")),
    ("afn", _("Defaka")),
    ("afo", _("Eloyi")),
    ("afp", _("Tapei")),
    ("afs", _("Afro-Seminole Creole")),
    ("aft", _("Afitti")),
    ("afu", _("Awutu")),
    ("afz", _("Obokuitai")),
    ("aga", _("Aguano")),
    ("agb", _("Legbo")),
    ("agc", _("Agatu")),
    ("agd", _("Agarabi")),
    ("age", _("Angal")),
    ("agf", _("Arguni")),
    ("agg", _("Angor")),
    ("agh", _("Ngelima")),
    ("agi", _("Agariya")),
    ("agj", _("Argobba")),
    ("agk", _("Isarog Agta")),
    ("agl", _("Fembe")),
    ("agm", _("Angaataha")),
    ("agn", _("Agutaynen")),
    ("ago", _("Tainae")),
    ("agp", _("Paranan")),
    ("agq", _("Aghem")),
    ("agr", _("Aguaruna")),
    ("ags", _("Esimbi")),
    ("agt", _("Central Cagayan Agta")),
    ("agu", _("Aguacateco")),
    ("agv", _("Remontado Dumagat")),
    ("agw", _("Kahua")),
    ("agx", _("Aghul")),
    ("agy", _("Southern Alta")),
    ("agz", _("Mt. Iriga Agta")),
    ("aha", _("Ahanta")),
    ("ahb", _("Axamb")),
    ("ahg", _("Qimant")),
    ("ahh", _("Aghu")),
    ("ahi", _("Tiagbamrin Aizi")),
    ("ahk", _("Akha")),
    ("ahl", _("Igo")),
    ("ahm", _("Mobumrin Aizi")),
    ("ahn", _("Àhàn")),
    ("aho", _("Ahom")),
    ("ahp", _("Aproumu Aizi")),
    ("ahr", _("Ahirani")),
    ("ahs", _("Ashe")),
    ("aht", _("Ahtena")),
    ("aia", _("Arosi")),
    ("aib", _("Ainu")),
    ("aic", _("Ainbai")),
    ("aid", _("Alngith")),
    ("aie", _("Amara")),
    ("aif", _("Agi")),
    ("aig", _("Antigua and Barbuda Creole English")),
    ("aih", _("Ai-Cham")),
    ("aii", _("Assyrian Neo-Aramaic")),
    ("aij", _("Lishanid Noshan")),
    ("aik", _("Ake")),
    ("ail", _("Aimele")),
    ("aim", _("Aimol")),
    ("ain", _("Ainu")),
    ("aio", _("Aiton")),
    ("aip", _("Burumakok")),
    ("aiq", _("Aimaq")),
    ("air", _("Airoran")),
    ("ais", _("Nataoran Amis")),
    ("ait", _("Arikem")),
    ("aiw", _("Aari")),
    ("aix", _("Aighon")),
    ("aiy", _("Ali")),
    ("aja", _("Aja")),
    ("ajg", _("Aja")),
    ("aji", _("Ajië")),
    ("ajn", _("Andajin")),
    ("ajp", _("South Levantine Arabic")),
    ("ajt", _("Judeo-Tunisian Arabic")),
    ("aju", _("Judeo-Moroccan Arabic")),
    ("ajw", _("Ajawa")),
    ("ajz", _("Amri Karbi")),
    ("akb", _("Batak Angkola")),
    ("akc", _("Mpur")),
    ("akd", _("Ukpet-Ehom")),
    ("ake", _("Akawaio")),
    ("akf", _("Akpa")),
    ("akg", _("Anakalangu")),
    ("akh", _("Angal Heneng")),
    ("aki", _("Aiome")),
    ("akj", _("Aka-Jeru")),
    ("akk", _("Akkadian")),
    ("akl", _("Aklanon")),
    ("akm", _("Aka-Bo")),
    ("ako", _("Akurio")),
    ("akp", _("Siwu")),
    ("akq", _("Ak")),
    ("akr", _("Araki")),
    ("aks", _("Akaselem")),
    ("akt", _("Akolet")),
    ("aku", _("Akum")),
    ("akv", _("Akhvakh")),
    ("akw", _("Akwa")),
    ("akx", _("Aka-Kede")),
    ("aky", _("Aka-Kol")),
    ("akz", _("Alabama")),
    ("ala", _("Alago")),
    ("alc", _("Qawasqar")),
    ("ald", _("Alladian")),
    ("ale", _("Aleut")),
    ("alf", _("Alege")),
    ("alg", _("Algonquian languages")),
    ("alh", _("Alawa")),
    ("ali", _("Amaimon")),
    ("alj", _("Alangan")),
    ("alk", _("Alak")),
    ("all", _("Allar")),
    ("alm", _("Amblong")),
    ("aln", _("Gheg Albanian")),
    ("alo", _("Larike-Wakasihu")),
    ("alp", _("Alune")),
    ("alq", _("Algonquin")),
    ("alr", _("Alutor")),
    ("als", _("Tosk Albanian")),
    ("alt", _("Southern Altai")),
    ("alu", _("'Are'are")),
    ("alv", _("Atlantic-Congo languages")),
    ("alw", _("Alaba-K’abeena")),
    ("alx", _("Amol")),
    ("aly", _("Alyawarr")),
    ("alz", _("Alur")),
    ("ama", _("Amanayé")),
    ("amb", _("Ambo")),
    ("amc", _("Amahuaca")),
    ("ame", _("Yanesha'")),
    ("amf", _("Hamer-Banna")),
    ("amg", _("Amurdak")),
    ("ami", _("Amis")),
    ("amj", _("Amdang")),
    ("amk", _("Ambai")),
    ("aml", _("War-Jaintia")),
    ("amm", _("Ama")),
    ("amn", _("Amanab")),
    ("amo", _("Amo")),
    ("amp", _("Alamblak")),
    ("amq", _("Amahai")),
    ("amr", _("Amarakaeri")),
    ("ams", _("Southern Amami-Oshima")),
    ("amt", _("Amto")),
    ("amu", _("Guerrero Amuzgo")),
    ("amv", _("Ambelau")),
    ("amw", _("Western Neo-Aramaic")),
    ("amx", _("Anmatyerre")),
    ("amy", _("Ami")),
    ("amz", _("Atampaya")),
    ("ana", _("Andaqui")),
    ("anb", _("Andoa")),
    ("anc", _("Ngas")),
    ("and", _("Ansus")),
    ("ane", _("Xârâcùù")),
    ("anf", _("Animere")),
    ("ang", _("Old English")),
    ("anh", _("Nend")),
    ("ani", _("Andi")),
    ("anj", _("Anor")),
    ("ank", _("Goemai")),
    ("anl", _("Anu-Hkongso Chin")),
    ("anm", _("Anal")),
    ("ann", _("Obolo")),
    ("ano", _("Andoque")),
    ("anp", _("Angika")),
    ("anq", _("Jarawa")),
    ("anr", _("Andh")),
    ("ans", _("Anserma")),
    ("ant", _("Antakarinya")),
    ("anu", _("Anuak")),
    ("anv", _("Denya")),
    ("anw", _("Anaang")),
    ("anx", _("Andra-Hus")),
    ("any", _("Anyin")),
    ("anz", _("Anem")),
    ("aoa", _("Angolar")),
    ("aob", _("Abom")),
    ("aoc", _("Pemon")),
    ("aod", _("Andarum")),
    ("aoe", _("Angal Enen")),
    ("aof", _("Bragat")),
    ("aog", _("Angoram")),
    ("aoh", _("Arma")),
    ("aoi", _("Anindilyakwa")),
    ("aoj", _("Mufian")),
    ("aok", _("Arhö")),
    ("aol", _("Alor")),
    ("aom", _("Ömie")),
    ("aon", _("Bumbita Arapesh")),
    ("aor", _("Aore")),
    ("aos", _("Taikat")),
    ("aot", _("Atong")),
    ("aou", _("A'ou")),
    ("aox", _("Atorada")),
    ("aoz", _("Uab Meto")),
    ("apa", _("Apache languages")),
    ("apb", _("Sa'a")),
    ("apc", _("North Levantine Arabic")),
    ("apd", _("Sudanese Arabic")),
    ("ape", _("Bukiyip")),
    ("apf", _("Pahanan Agta")),
    ("apg", _("Ampanang")),
    ("aph", _("Athpariya")),
    ("api", _("Apiaká")),
    ("apj", _("Jicarilla Apache")),
    ("apk", _("Kiowa Apache")),
    ("apl", _("Lipan Apache")),
    ("apm", _("Mescalero-Chiricahua Apache")),
    ("apn", _("Apinayé")),
    ("apo", _("Ambul")),
    ("app", _("Apma")),
    ("apq", _("A-Pucikwar")),
    ("apr", _("Arop-Lokep")),
    ("aps", _("Arop-Sissano")),
    ("apt", _("Apatani")),
    ("apu", _("Apurinã")),
    ("apv", _("Alapmunte")),
    ("apw", _("Western Apache")),
    ("apx", _("Aputai")),
    ("apy", _("Apalaí")),
    ("apz", _("Safeyoka")),
    ("aqa", _("Alacalufan languages")),
    ("aqc", _("Archi")),
    ("aqd", _("Ampari Dogon")),
    ("aqg", _("Arigidi")),
    ("aqk", _("Aninka")),
    ("aql", _("Algic languages")),
    ("aqm", _("Atohwaim")),
    ("aqn", _("Northern Alta")),
    ("aqp", _("Atakapa")),
    ("aqr", _("Arhâ")),
    ("aqt", _("Angaité")),
    ("aqz", _("Akuntsu")),
    ("arb", _("Standard Arabic")),
    ("arc", _("Official Aramaic")),
    ("ard", _("Arabana")),
    ("are", _("Western Arrarnta")),
    ("arh", _("Arhuaco")),
    ("ari", _("Arikara")),
    ("arj", _("Arapaso")),
    ("ark", _("Arikapú")),
    ("arl", _("Arabela")),
    ("arn", _("Mapudungun")),
    ("aro", _("Araona")),
    ("arp", _("Arapaho")),
    ("arq", _("Algerian Arabic")),
    ("arr", _("Karo")),
    ("ars", _("Najdi Arabic")),
    ("art", _("Artificial languages")),
    ("aru", _("Aruá")),
    ("arv", _("Arbore")),
    ("arw", _("Arawak")),
    ("arx", _("Aruá")),
    ("ary", _("Moroccan Arabic")),
    ("arz", _("Egyptian Arabic")),
    ("asa", _("Asu")),
    ("asb", _("Assiniboine")),
    ("asc", _("Casuarina Coast Asmat")),
    ("asd", _("Asas")),
    ("ase", _("American Sign Language")),
    ("asf", _("Auslan")),
    ("asg", _("Cishingini")),
    ("ash", _("Abishira")),
    ("asi", _("Buruwai")),
    ("asj", _("Sari")),
    ("ask", _("Ashkun")),
    ("asl", _("Asilulu")),
    ("asn", _("Xingú Asuriní")),
    ("aso", _("Dano")),
    ("asp", _("Algerian Sign Language")),
    ("asq", _("Austrian Sign Language")),
    ("asr", _("Asuri")),
    ("ass", _("Ipulo")),
    ("ast", _("Asturian")),
    ("asu", _("Tocantins Asurini")),
    ("asv", _("Asoa")),
    ("asw", _("Australian Aborigines Sign Language")),
    ("asx", _("Muratayak")),
    ("asy", _("Yaosakor Asmat")),
    ("asz", _("As")),
    ("ata", _("Pele-Ata")),
    ("atb", _("Zaiwa")),
    ("atc", _("Atsahuaca")),
    ("atd", _("Ata Manobo")),
    ("ate", _("Atemble")),
    ("atg", _("Ivbie North-Okpela-Arhe")),
    ("ath", _("Athapascan languages")),
    ("ati", _("Attié")),
    ("atj", _("Atikamekw")),
    ("atk", _("Ati")),
    ("atl", _("Mt. Iraya Agta")),
    ("atm", _("Ata")),
    ("atn", _("Ashtiani")),
    ("ato", _("Atong")),
    ("atp", _("Pudtol Atta")),
    ("atq", _("Aralle-Tabulahan")),
    ("atr", _("Waimiri-Atroari")),
    ("ats", _("Gros Ventre")),
    ("att", _("Pamplona Atta")),
    ("atu", _("Reel")),
    ("atv", _("Northern Altai")),
    ("atw", _("Atsugewi")),
    ("atx", _("Arutani")),
    ("aty", _("Aneityum")),
    ("atz", _("Arta")),
    ("aua", _("Asumboa")),
    ("aub", _("Alugu")),
    ("auc", _("Waorani")),
    ("aud", _("Anuta")),
    ("aue", _("ǂKxʼauǁʼein")),
    ("auf", _("Arauan languages")),
    ("aug", _("Aguna")),
    ("auh", _("Aushi")),
    ("aui", _("Anuki")),
    ("auj", _("Awjilah")),
    ("auk", _("Heyo")),
    ("aul", _("Aulua")),
    ("aum", _("Asu")),
    ("aun", _("Molmo One")),
    ("auo", _("Auyokawa")),
    ("aup", _("Makayam")),
    ("auq", _("Anus")),
    ("aur", _("Aruek")),
    ("aus", _("Australian languages")),
    ("aut", _("Austral")),
    ("auu", _("Auye")),
    ("auw", _("Awyi")),
    ("aux", _("Aurá")),
    ("auy", _("Awiyaana")),
    ("auz", _("Uzbeki Arabic")),
    ("avb", _("Avau")),
    ("avd", _("Alviri-Vidari")),
    ("avi", _("Avikam")),
    ("avk", _("Kotava")),
    ("avl", _("Eastern Egyptian Bedawi Arabic")),
    ("avm", _("Angkamuthi")),
    ("avn", _("Avatime")),
    ("avo", _("Agavotaguerra")),
    ("avs", _("Aushiri")),
    ("avt", _("Au")),
    ("avu", _("Avokaya")),
    ("avv", _("Avá-Canoeiro")),
    ("awa", _("Awadhi")),
    ("awb", _("Awa")),
    ("awc", _("Cicipu")),
    ("awd", _("Arawakan languages")),
    ("awe", _("Awetí")),
    ("awg", _("Anguthimri")),
    ("awh", _("Awbono")),
    ("awi", _("Aekyom")),
    ("awk", _("Awabakal")),
    ("awm", _("Arawum")),
    ("awn", _("Awngi")),
    ("awo", _("Awak")),
    ("awr", _("Awera")),
    ("aws", _("South Awyu")),
    ("awt", _("Araweté")),
    ("awu", _("Central Awyu")),
    ("awv", _("Jair Awyu")),
    ("aww", _("Awun")),
    ("awx", _("Awara")),
    ("awy", _("Edera Awyu")),
    ("axb", _("Abipon")),
    ("axe", _("Ayerrerenge")),
    ("axg", _("Mato Grosso Arára")),
    ("axk", _("Yaka")),
    ("axl", _("Lower Southern Aranda")),
    ("axm", _("Middle Armenian")),
    ("axx", _("Xârâgurè")),
    ("aya", _("Awar")),
    ("ayb", _("Ayizo Gbe")),
    ("ayc", _("Southern Aymara")),
    ("ayd", _("Ayabadhu")),
    ("aye", _("Ayere")),
    ("ayg", _("Ginyanga")),
    ("ayh", _("Hadrami Arabic")),
    ("ayi", _("Leyigha")),
    ("ayk", _("Akuku")),
    ("ayl", _("Libyan Arabic")),
    ("ayn", _("Sanaani Arabic")),
    ("ayo", _("Ayoreo")),
    ("ayp", _("North Mesopotamian Arabic")),
    ("ayq", _("Ayi")),
    ("ayr", _("Central Aymara")),
    ("ays", _("Sorsogon Ayta")),
    ("ayt", _("Magbukun Ayta")),
    ("ayu", _("Ayu")),
    ("ayx", _("Ayi")),
    ("ayy", _("Tayabas Ayta")),
    ("ayz", _("Mai Brat")),
    ("aza", _("Azha")),
    ("azb", _("South Azerbaijani")),
    ("azc", _("Uto-Aztecan languages")),
    ("azd", _("Eastern Durango Nahuatl")),
    ("azg", _("San Pedro Amuzgos Amuzgo")),
    ("azj", _("North Azerbaijani")),
    ("azm", _("Ipalapa Amuzgo")),
    ("azn", _("Western Durango Nahuatl")),
    ("azo", _("Awing")),
    ("azt", _("Faire Atta")),
    ("azz", _("Highland Puebla Nahuatl")),
    ("baa", _("Babatana")),
    ("bab", _("Bainouk-Gunyuño")),
    ("bac", _("Badui")),
    ("bad", _("Banda languages")),
    ("bae", _("Baré")),
    ("baf", _("Nubaca")),
    ("bag", _("Tuki")),
    ("bah", _("Bahamas Creole English")),
    ("bai", _("Bamileke languages")),
    ("baj", _("Barakai")),
    ("bal", _("Baluchi")),
    ("ban", _("Balinese")),
    ("bao", _("Waimaha")),
    ("bap", _("Bantawa")),
    ("bar", _("Bavarian")),
    ("bas", _("Basa")),
    ("bat", _("Baltic languages")),
    ("bau", _("Bada")),
    ("bav", _("Vengo")),
    ("baw", _("Bambili-Bambui")),
    ("bax", _("Bamun")),
    ("bay", _("Batuley")),
    ("baz", _("Tunen")),
    ("bba", _("Baatonum")),
    ("bbb", _("Barai")),
    ("bbc", _("Batak Toba")),
    ("bbd", _("Bau")),
    ("bbe", _("Bangba")),
    ("bbf", _("Baibai")),
    ("bbg", _("Barama")),
    ("bbh", _("Bugan")),
    ("bbi", _("Barombi")),
    ("bbj", _("Ghomálá'")),
    ("bbk", _("Babanki")),
    ("bbl", _("Bats")),
    ("bbm", _("Babango")),
    ("bbn", _("Uneapa")),
    ("bbo", _("Northern Bobo Madaré")),
    ("bbp", _("West Central Banda")),
    ("bbq", _("Bamali")),
    ("bbr", _("Girawa")),
    ("bbs", _("Bakpinka")),
    ("bbt", _("Mburku")),
    ("bbu", _("Kulung")),
    ("bbv", _("Karnai")),
    ("bbw", _("Baba")),
    ("bbx", _("Bubia")),
    ("bby", _("Befang")),
    ("bbz", _("Babalia Creole Arabic")),
    ("bca", _("Central Bai")),
    ("bcb", _("Bainouk-Samik")),
    ("bcc", _("Southern Balochi")),
    ("bcd", _("North Babar")),
    ("bce", _("Bamenyam")),
    ("bcf", _("Bamu")),
    ("bcg", _("Baga Pokur")),
    ("bch", _("Bariai")),
    ("bci", _("Baoulé")),
    ("bcj", _("Bardi")),
    ("bck", _("Bunuba")),
    ("bcl", _("Central Bikol")),
    ("bcm", _("Bannoni")),
    ("bcn", _("Bali")),
    ("bco", _("Kaluli")),
    ("bcp", _("Bali")),
    ("bcq", _("Bench")),
    ("bcr", _("Babine")),
    ("bcs", _("Kohumono")),
    ("bct", _("Bendi")),
    ("bcu", _("Awad Bing")),
    ("bcv", _("Shoo-Minda-Nye")),
    ("bcw", _("Bana")),
    ("bcy", _("Bacama")),
    ("bcz", _("Bainouk-Gunyaamolo")),
    ("bda", _("Bayot")),
    ("bdb", _("Basap")),
    ("bdc", _("Emberá-Baudó")),
    ("bdd", _("Bunama")),
    ("bde", _("Bade")),
    ("bdf", _("Biage")),
    ("bdg", _("Bonggi")),
    ("bdh", _("Baka")),
    ("bdi", _("Burun")),
    ("bdj", _("Bai")),
    ("bdk", _("Budukh")),
    ("bdl", _("Indonesian Bajau")),
    ("bdm", _("Buduma")),
    ("bdn", _("Baldemu")),
    ("bdo", _("Morom")),
    ("bdp", _("Bende")),
    ("bdq", _("Bahnar")),
    ("bdr", _("West Coast Bajau")),
    ("bds", _("Burunge")),
    ("bdt", _("Bokoto")),
    ("bdu", _("Oroko")),
    ("bdv", _("Bodo Parja")),
    ("bdw", _("Baham")),
    ("bdx", _("Budong-Budong")),
    ("bdy", _("Bandjalang")),
    ("bdz", _("Badeshi")),
    ("bea", _("Beaver")),
    ("beb", _("Bebele")),
    ("bec", _("Iceve-Maci")),
    ("bed", _("Bedoanas")),
    ("bee", _("Byangsi")),
    ("bef", _("Benabena")),
    ("beg", _("Belait")),
    ("beh", _("Biali")),
    ("bei", _("Bekati'")),
    ("bej", _("Beja")),
    ("bek", _("Bebeli")),
    ("bem", _("Bemba")),
    ("beo", _("Beami")),
    ("bep", _("Besoa")),
    ("beq", _("Beembe")),
    ("ber", _("Berber languages")),
    ("bes", _("Besme")),
    ("bet", _("Guiberoua Béte")),
    ("beu", _("Blagar")),
    ("bev", _("Daloa Bété")),
    ("bew", _("Betawi")),
    ("bex", _("Jur Modo")),
    ("bey", _("Beli")),
    ("bez", _("Bena")),
    ("bfa", _("Bari")),
    ("bfb", _("Pauri Bareli")),
    ("bfc", _("Panyi Bai")),
    ("bfd", _("Bafut")),
    ("bfe", _("Betaf")),
    ("bff", _("Bofi")),
    ("bfg", _("Busang Kayan")),
    ("bfh", _("Blafe")),
    ("bfi", _("British Sign Language")),
    ("bfj", _("Bafanji")),
    ("bfk", _("Ban Khor Sign Language")),
    ("bfl", _("Banda-Ndélé")),
    ("bfm", _("Mmen")),
    ("bfn", _("Bunak")),
    ("bfo", _("Malba Birifor")),
    ("bfp", _("Beba")),
    ("bfq", _("Badaga")),
    ("bfr", _("Bazigar")),
    ("bfs", _("Southern Bai")),
    ("bft", _("Balti")),
    ("bfu", _("Gahri")),
    ("bfw", _("Bondo")),
    ("bfx", _("Bantayanon")),
    ("bfy", _("Bagheli")),
    ("bfz", _("Mahasu Pahari")),
    ("bga", _("Gwamhi-Wuri")),
    ("bgb", _("Bobongko")),
    ("bgc", _("Haryanvi")),
    ("bgd", _("Rathwi Bareli")),
    ("bge", _("Bauria")),
    ("bgf", _("Bangandu")),
    ("bgg", _("Bugun")),
    ("bgi", _("Giangan")),
    ("bgj", _("Bangolan")),
    ("bgk", _("Bit")),
    ("bgl", _("Bo")),
    ("bgm", _("Baga Mboteni")),
    ("bgn", _("Western Balochi")),
    ("bgo", _("Baga Koga")),
    ("bgp", _("Eastern Balochi")),
    ("bgq", _("Bagri")),
    ("bgr", _("Bawm Chin")),
    ("bgs", _("Tagabawa")),
    ("bgt", _("Bughotu")),
    ("bgu", _("Mbongno")),
    ("bgv", _("Warkay-Bipim")),
    ("bgw", _("Bhatri")),
    ("bgx", _("Balkan Gagauz Turkish")),
    ("bgy", _("Benggoi")),
    ("bgz", _("Banggai")),
    ("bha", _("Bharia")),
    ("bhb", _("Bhili")),
    ("bhc", _("Biga")),
    ("bhd", _("Bhadrawahi")),
    ("bhe", _("Bhaya")),
    ("bhf", _("Odiai")),
    ("bhg", _("Binandere")),
    ("bhh", _("Bukharic")),
    ("bhi", _("Bhilali")),
    ("bhj", _("Bahing")),
    ("bhk", _("Albay Bicolano")),
    ("bhl", _("Bimin")),
    ("bhm", _("Bathari")),
    ("bhn", _("Bohtan Neo-Aramaic")),
    ("bho", _("Bhojpuri")),
    ("bhp", _("Bima")),
    ("bhq", _("Tukang Besi South")),
    ("bhr", _("Bara Malagasy")),
    ("bhs", _("Buwal")),
    ("bht", _("Bhattiyali")),
    ("bhu", _("Bhunjia")),
    ("bhv", _("Bahau")),
    ("bhw", _("Biak")),
    ("bhx", _("Bhalay")),
    ("bhy", _("Bhele")),
    ("bhz", _("Bada")),
    ("bia", _("Badimaya")),
    ("bib", _("Bissa")),
    ("bic", _("Bikaru")),
    ("bid", _("Bidiyo")),
    ("bie", _("Bepour")),
    ("bif", _("Biafada")),
    ("big", _("Biangai")),
    ("bij", _("Vaghat-Ya-Bijim-Legeri")),
    ("bik", _("Bikol")),
    ("bil", _("Bile")),
    ("bim", _("Bimoba")),
    ("bin", _("Bini")),
    ("bio", _("Nai")),
    ("bip", _("Bila")),
    ("biq", _("Bipi")),
    ("bir", _("Bisorio")),
    ("bit", _("Berinomo")),
    ("biu", _("Biete")),
    ("biv", _("Southern Birifor")),
    ("biw", _("Kol")),
    ("bix", _("Bijori")),
    ("biy", _("Birhor")),
    ("biz", _("Baloi")),
    ("bja", _("Budza")),
    ("bjb", _("Banggarla")),
    ("bjc", _("Bariji")),
    ("bjd", _("Bandjigali")),
    ("bje", _("Biao-Jiao Mien")),
    ("bjf", _("Barzani Jewish Neo-Aramaic")),
    ("bjg", _("Bidyogo")),
    ("bjh", _("Bahinemo")),
    ("bji", _("Burji")),
    ("bjj", _("Kanauji")),
    ("bjk", _("Barok")),
    ("bjl", _("Bulu")),
    ("bjm", _("Bajelani")),
    ("bjn", _("Banjar")),
    ("bjo", _("Mid-Southern Banda")),
    ("bjp", _("Fanamaket")),
    ("bjq", _("Southern Betsimisaraka Malagasy")),
    ("bjr", _("Binumarien")),
    ("bjs", _("Bajan")),
    ("bjt", _("Balanta-Ganja")),
    ("bju", _("Busuu")),
    ("bjv", _("Bedjond")),
    ("bjw", _("Bakwé")),
    ("bjx", _("Banao Itneg")),
    ("bjy", _("Bayali")),
    ("bjz", _("Baruga")),
    ("bka", _("Kyak")),
    ("bkb", _("Finallig")),
    ("bkc", _("Baka")),
    ("bkd", _("Binukid")),
    ("bkf", _("Beeke")),
    ("bkg", _("Buraka")),
    ("bkh", _("Bakoko")),
    ("bki", _("Baki")),
    ("bkj", _("Pande")),
    ("bkk", _("Brokskat")),
    ("bkl", _("Berik")),
    ("bkm", _("Kom")),
    ("bkn", _("Bukitan")),
    ("bko", _("Kwa'")),
    ("bkp", _("Boko")),
    ("bkq", _("Bakairí")),
    ("bkr", _("Bakumpai")),
    ("bks", _("Northern Sorsoganon")),
    ("bkt", _("Boloki")),
    ("bku", _("Buhid")),
    ("bkv", _("Bekwarra")),
    ("bkw", _("Bekwel")),
    ("bkx", _("Baikeno")),
    ("bky", _("Bokyi")),
    ("bkz", _("Bungku")),
    ("bla", _("Siksika")),
    ("blb", _("Bilua")),
    ("blc", _("Bella Coola")),
    ("bld", _("Bolango")),
    ("ble", _("Balanta-Kentohe")),
    ("blf", _("Buol")),
    ("blg", _("Balau")),
    ("blh", _("Kuwaa")),
    ("bli", _("Bolia")),
    ("blj", _("Bolongan")),
    ("blk", _("Pa'o Karen")),
    ("bll", _("Biloxi")),
    ("blm", _("Beli")),
    ("bln", _("Southern Catanduanes Bikol")),
    ("blo", _("Anii")),
    ("blp", _("Blablanga")),
    ("blq", _("Baluan-Pam")),
    ("blr", _("Blang")),
    ("bls", _("Balaesang")),
    ("blt", _("Tai Dam")),
    ("blv", _("Kibala")),
    ("blw", _("Balangao")),
    ("blx", _("Mag-Indi Ayta")),
    ("bly", _("Notre")),
    ("blz", _("Balantak")),
    ("bma", _("Lame")),
    ("bmb", _("Bembe")),
    ("bmc", _("Biem")),
    ("bmd", _("Baga Manduri")),
    ("bme", _("Limassa")),
    ("bmf", _("Bom-Kim")),
    ("bmg", _("Bamwe")),
    ("bmh", _("Kein")),
    ("bmi", _("Bagirmi")),
    ("bmj", _("Bote-Majhi")),
    ("bmk", _("Ghayavi")),
    ("bml", _("Bomboli")),
    ("bmm", _("Northern Betsimisaraka Malagasy")),
    ("bmn", _("Bina")),
    ("bmo", _("Bambalang")),
    ("bmp", _("Bulgebi")),
    ("bmq", _("Bomu")),
    ("bmr", _("Muinane")),
    ("bms", _("Bilma Kanuri")),
    ("bmt", _("Biao Mon")),
    ("bmu", _("Somba-Siawari")),
    ("bmv", _("Bum")),
    ("bmw", _("Bomwali")),
    ("bmx", _("Baimak")),
    ("bmy", _("Bemba")),
    ("bmz", _("Baramu")),
    ("bna", _("Bonerate")),
    ("bnb", _("Bookan")),
    ("bnc", _("Bontok")),
    ("bnd", _("Banda")),
    ("bne", _("Bintauna")),
    ("bnf", _("Masiwang")),
    ("bng", _("Benga")),
    ("bni", _("Bangi")),
    ("bnj", _("Eastern Tawbuid")),
    ("bnk", _("Bierebo")),
    ("bnl", _("Boon")),
    ("bnm", _("Batanga")),
    ("bnn", _("Bunun")),
    ("bno", _("Bantoanon")),
    ("bnp", _("Bola")),
    ("bnq", _("Bantik")),
    ("bnr", _("Butmas-Tur")),
    ("bns", _("Bundeli")),
    ("bnt", _("Bantu languages")),
    ("bnu", _("Bentong")),
    ("bnv", _("Bonerif")),
    ("bnw", _("Bisis")),
    ("bnx", _("Bangubangu")),
    ("bny", _("Bintulu")),
    ("bnz", _("Beezen")),
    ("boa", _("Bora")),
    ("bob", _("Aweer")),
    ("boe", _("Mundabli")),
    ("bof", _("Bolon")),
    ("bog", _("Bamako Sign Language")),
    ("boh", _("Boma")),
    ("boi", _("Barbareño")),
    ("boj", _("Anjam")),
    ("bok", _("Bonjo")),
    ("bol", _("Bole")),
    ("bom", _("Berom")),
    ("bon", _("Bine")),
    ("boo", _("Tiemacèwè Bozo")),
    ("bop", _("Bonkiman")),
    ("boq", _("Bogaya")),
    ("bor", _("Borôro")),
    ("bot", _("Bongo")),
    ("bou", _("Bondei")),
    ("bov", _("Tuwuli")),
    ("bow", _("Rema")),
    ("box", _("Buamu")),
    ("boy", _("Bodo")),
    ("boz", _("Tiéyaxo Bozo")),
    ("bpa", _("Daakaka")),
    ("bpb", _("Barbacoas")),
    ("bpd", _("Banda-Banda")),
    ("bpe", _("Bauni")),
    ("bpg", _("Bonggo")),
    ("bph", _("Botlikh")),
    ("bpi", _("Bagupi")),
    ("bpj", _("Binji")),
    ("bpk", _("Orowe")),
    ("bpl", _("Broome Pearling Lugger Pidgin")),
    ("bpm", _("Biyom")),
    ("bpn", _("Dzao Min")),
    ("bpo", _("Anasi")),
    ("bpp", _("Kaure")),
    ("bpq", _("Banda Malay")),
    ("bpr", _("Koronadal Blaan")),
    ("bps", _("Sarangani Blaan")),
    ("bpt", _("Barrow Point")),
    ("bpu", _("Bongu")),
    ("bpv", _("Bian Marind")),
    ("bpw", _("Bo")),
    ("bpx", _("Palya Bareli")),
    ("bpy", _("Bishnupriya")),
    ("bpz", _("Bilba")),
    ("bqa", _("Tchumbuli")),
    ("bqb", _("Bagusa")),
    ("bqc", _("Boko")),
    ("bqd", _("Bung")),
    ("bqf", _("Baga Kaloum")),
    ("bqg", _("Bago-Kusuntu")),
    ("bqh", _("Baima")),
    ("bqi", _("Bakhtiari")),
    ("bqj", _("Bandial")),
    ("bqk", _("Banda-Mbrès")),
    ("bql", _("Bilakura")),
    ("bqm", _("Wumboko")),
    ("bqn", _("Bulgarian Sign Language")),
    ("bqo", _("Balo")),
    ("bqp", _("Busa")),
    ("bqq", _("Biritai")),
    ("bqr", _("Burusu")),
    ("bqs", _("Bosngun")),
    ("bqt", _("Bamukumbit")),
    ("bqu", _("Boguru")),
    ("bqv", _("Koro Wachi")),
    ("bqw", _("Buru")),
    ("bqx", _("Baangi")),
    ("bqy", _("Bengkala Sign Language")),
    ("bqz", _("Bakaka")),
    ("bra", _("Braj")),
    ("brb", _("Lave")),
    ("brc", _("Berbice Creole Dutch")),
    ("brd", _("Baraamu")),
    ("brf", _("Bira")),
    ("brg", _("Baure")),
    ("brh", _("Brahui")),
    ("bri", _("Mokpwe")),
    ("brj", _("Bieria")),
    ("brk", _("Birked")),
    ("brl", _("Birwa")),
    ("brm", _("Barambu")),
    ("brn", _("Boruca")),
    ("bro", _("Brokkat")),
    ("brp", _("Barapasi")),
    ("brq", _("Breri")),
    ("brr", _("Birao")),
    ("brs", _("Baras")),
    ("brt", _("Bitare")),
    ("bru", _("Eastern Bru")),
    ("brv", _("Western Bru")),
    ("brw", _("Bellari")),
    ("brx", _("Bodo")),
    ("bry", _("Burui")),
    ("brz", _("Bilbil")),
    ("bsa", _("Abinomn")),
    ("bsb", _("Brunei Bisaya")),
    ("bsc", _("Bassari")),
    ("bse", _("Wushi")),
    ("bsf", _("Bauchi")),
    ("bsg", _("Bashkardi")),
    ("bsh", _("Kati")),
    ("bsi", _("Bassossi")),
    ("bsj", _("Bangwinji")),
    ("bsk", _("Burushaski")),
    ("bsl", _("Basa-Gumna")),
    ("bsm", _("Busami")),
    ("bsn", _("Barasana-Eduria")),
    ("bso", _("Buso")),
    ("bsp", _("Baga Sitemu")),
    ("bsq", _("Bassa")),
    ("bsr", _("Bassa-Kontagora")),
    ("bss", _("Akoose")),
    ("bst", _("Basketo")),
    ("bsu", _("Bahonsuai")),
    ("bsv", _("Baga Sobané")),
    ("bsw", _("Baiso")),
    ("bsx", _("Yangkam")),
    ("bsy", _("Sabah Bisaya")),
    ("bta", _("Bata")),
    ("btb", _("Beti")),
    ("btc", _("Bati")),
    ("btd", _("Batak Dairi")),
    ("bte", _("Gamo-Ningi")),
    ("btf", _("Birgit")),
    ("btg", _("Gagnoa Bété")),
    ("bth", _("Biatah Bidayuh")),
    ("bti", _("Burate")),
    ("btj", _("Bacanese Malay")),
    ("btk", _("Batak languages")),
    ("btl", _("Bhatola")),
    ("btm", _("Batak Mandailing")),
    ("btn", _("Ratagnon")),
    ("bto", _("Rinconada Bikol")),
    ("btp", _("Budibud")),
    ("btq", _("Batek")),
    ("btr", _("Baetora")),
    ("bts", _("Batak Simalungun")),
    ("btt", _("Bete-Bendi")),
    ("btu", _("Batu")),
    ("btv", _("Bateri")),
    ("btw", _("Butuanon")),
    ("btx", _("Batak Karo")),
    ("bty", _("Bobot")),
    ("btz", _("Batak Alas-Kluet")),
    ("bua", _("Buriat")),
    ("bub", _("Bua")),
    ("buc", _("Bushi")),
    ("bud", _("Ntcham")),
    ("bue", _("Beothuk")),
    ("buf", _("Bushoong")),
    ("bug", _("Buginese")),
    ("buh", _("Younuo Bunu")),
    ("bui", _("Bongili")),
    ("buj", _("Basa-Gurmana")),
    ("buk", _("Bugawac")),
    ("bum", _("Bulu")),
    ("bun", _("Sherbro")),
    ("buo", _("Terei")),
    ("bup", _("Busoa")),
    ("buq", _("Brem")),
    ("bus", _("Bokobaru")),
    ("but", _("Bungain")),
    ("buu", _("Budu")),
    ("buv", _("Bun")),
    ("buw", _("Bubi")),
    ("bux", _("Boghom")),
    ("buy", _("Bullom So")),
    ("buz", _("Bukwen")),
    ("bva", _("Barein")),
    ("bvb", _("Bube")),
    ("bvc", _("Baelelea")),
    ("bvd", _("Baeggu")),
    ("bve", _("Berau Malay")),
    ("bvf", _("Boor")),
    ("bvg", _("Bonkeng")),
    ("bvh", _("Bure")),
    ("bvi", _("Belanda Viri")),
    ("bvj", _("Baan")),
    ("bvk", _("Bukat")),
    ("bvl", _("Bolivian Sign Language")),
    ("bvm", _("Bamunka")),
    ("bvn", _("Buna")),
    ("bvo", _("Bolgo")),
    ("bvp", _("Bumang")),
    ("bvq", _("Birri")),
    ("bvr", _("Burarra")),
    ("bvt", _("Bati")),
    ("bvu", _("Bukit Malay")),
    ("bvv", _("Baniva")),
    ("bvw", _("Boga")),
    ("bvx", _("Dibole")),
    ("bvy", _("Baybayanon")),
    ("bvz", _("Bauzi")),
    ("bwa", _("Bwatoo")),
    ("bwb", _("Namosi-Naitasiri-Serua")),
    ("bwc", _("Bwile")),
    ("bwd", _("Bwaidoka")),
    ("bwe", _("Bwe Karen")),
    ("bwf", _("Boselewa")),
    ("bwg", _("Barwe")),
    ("bwh", _("Bishuo")),
    ("bwi", _("Baniwa")),
    ("bwj", _("Láá Láá Bwamu")),
    ("bwk", _("Bauwaki")),
    ("bwl", _("Bwela")),
    ("bwm", _("Biwat")),
    ("bwn", _("Wunai Bunu")),
    ("bwo", _("Boro")),
    ("bwp", _("Mandobo Bawah")),
    ("bwq", _("Southern Bobo Madaré")),
    ("bwr", _("Bura-Pabir")),
    ("bws", _("Bomboma")),
    ("bwt", _("Bafaw-Balong")),
    ("bwu", _("Buli")),
    ("bww", _("Bwa")),
    ("bwx", _("Bu-Nao Bunu")),
    ("bwy", _("Cwi Bwamu")),
    ("bwz", _("Bwisi")),
    ("bxa", _("Tairaha")),
    ("bxb", _("Belanda Bor")),
    ("bxc", _("Molengue")),
    ("bxd", _("Pela")),
    ("bxe", _("Birale")),
    ("bxf", _("Bilur")),
    ("bxg", _("Bangala")),
    ("bxh", _("Buhutu")),
    ("bxi", _("Pirlatapa")),
    ("bxj", _("Bayungu")),
    ("bxk", _("Bukusu")),
    ("bxl", _("Jalkunan")),
    ("bxm", _("Mongolia Buriat")),
    ("bxn", _("Burduna")),
    ("bxo", _("Barikanchi")),
    ("bxp", _("Bebil")),
    ("bxq", _("Beele")),
    ("bxr", _("Russia Buriat")),
    ("bxs", _("Busam")),
    ("bxu", _("China Buriat")),
    ("bxv", _("Berakou")),
    ("bxw", _("Bankagooma")),
    ("bxx", _("Borna")),
    ("bxz", _("Binahari")),
    ("bya", _("Batak")),
    ("byb", _("Bikya")),
    ("byc", _("Ubaghara")),
    ("byd", _("Benyadu'")),
    ("bye", _("Pouye")),
    ("byf", _("Bete")),
    ("byg", _("Baygo")),
    ("byh", _("Bhujel")),
    ("byi", _("Buyu")),
    ("byj", _("Bina")),
    ("byk", _("Biao")),
    ("byl", _("Bayono")),
    ("bym", _("Bidjara")),
    ("byn", _("Bilin")),
    ("byo", _("Biyo")),
    ("byp", _("Bumaji")),
    ("byq", _("Basay")),
    ("byr", _("Baruya")),
    ("bys", _("Burak")),
    ("byt", _("Berti")),
    ("byv", _("Medumba")),
    ("byw", _("Belhariya")),
    ("byx", _("Qaqet")),
    ("byy", _("Buya")),
    ("byz", _("Banaro")),
    ("bza", _("Bandi")),
    ("bzb", _("Andio")),
    ("bzc", _("Southern Betsimisaraka Malagasy")),
    ("bzd", _("Bribri")),
    ("bze", _("Jenaama Bozo")),
    ("bzf", _("Boikin")),
    ("bzg", _("Babuza")),
    ("bzh", _("Mapos Buang")),
    ("bzi", _("Bisu")),
    ("bzj", _("Belize Kriol English")),
    ("bzk", _("Nicaragua Creole English")),
    ("bzl", _("Boano")),
    ("bzm", _("Bolondo")),
    ("bzn", _("Boano")),
    ("bzo", _("Bozaba")),
    ("bzp", _("Kemberano")),
    ("bzq", _("Buli")),
    ("bzr", _("Biri")),
    ("bzs", _("Brazilian Sign Language")),
    ("bzt", _("Brithenig")),
    ("bzu", _("Burmeso")),
    ("bzv", _("Naami")),
    ("bzw", _("Basa")),
    ("bzx", _("Kɛlɛngaxo Bozo")),
    ("bzy", _("Obanliku")),
    ("bzz", _("Evant")),
    ("caa", _("Chortí")),
    ("cab", _("Garifuna")),
    ("cac", _("Chuj")),
    ("cad", _("Caddo")),
    ("cae", _("Lehar")),
    ("caf", _("Southern Carrier")),
    ("cag", _("Nivaclé")),
    ("cah", _("Cahuarano")),
    ("cai", _("Central American Indian languages")),
    ("caj", _("Chané")),
    ("cak", _("Kaqchikel")),
    ("cal", _("Carolinian")),
    ("cam", _("Cemuhî")),
    ("can", _("Chambri")),
    ("cao", _("Chácobo")),
    ("cap", _("Chipaya")),
    ("caq", _("Car Nicobarese")),
    ("car", _("Galibi Carib")),
    ("cas", _("Tsimané")),
    ("cau", _("Caucasian languages")),
    ("cav", _("Cavineña")),
    ("caw", _("Callawalla")),
    ("cax", _("Chiquitano")),
    ("cay", _("Cayuga")),
    ("caz", _("Canichana")),
    ("cba", _("Chibchan languages")),
    ("cbb", _("Cabiyarí")),
    ("cbc", _("Carapana")),
    ("cbd", _("Carijona")),
    ("cbe", _("Chipiajes")),
    ("cbg", _("Chimila")),
    ("cbh", _("Cagua")),
    ("cbi", _("Chachi")),
    ("cbj", _("Ede Cabe")),
    ("cbk", _("Chavacano")),
    ("cbl", _("Bualkhaw Chin")),
    ("cbn", _("Nyahkur")),
    ("cbo", _("Izora")),
    ("cbq", _("Tsucuba")),
    ("cbr", _("Cashibo-Cacataibo")),
    ("cbs", _("Cashinahua")),
    ("cbt", _("Chayahuita")),
    ("cbu", _("Candoshi-Shapra")),
    ("cbv", _("Cacua")),
    ("cbw", _("Kinabalian")),
    ("cby", _("Carabayo")),
    ("cca", _("Cauca")),
    ("ccc", _("Chamicuro")),
    ("ccd", _("Cafundo Creole")),
    ("cce", _("Chopi")),
    ("ccg", _("Samba Daka")),
    ("cch", _("Atsam")),
    ("ccj", _("Kasanga")),
    ("ccl", _("Cutchi-Swahili")),
    ("ccm", _("Malaccan Creole Malay")),
    ("ccn", _("North Caucasian languages")),
    ("cco", _("Comaltepec Chinantec")),
    ("ccp", _("Chakma")),
    ("ccq", _("Chaungtha")),
    ("ccr", _("Cacaopera")),
    ("ccs", _("South Caucasian languages")),
    ("cda", _("Choni")),
    ("cdc", _("Chadic languages")),
    ("cdd", _("Caddoan languages")),
    ("cde", _("Chenchu")),
    ("cdf", _("Chiru")),
    ("cdg", _("Chamari")),
    ("cdh", _("Chambeali")),
    ("cdi", _("Chodri")),
    ("cdj", _("Churahi")),
    ("cdm", _("Chepang")),
    ("cdn", _("Chaudangsi")),
    ("cdo", _("Min Dong Chinese")),
    ("cdr", _("Cinda-Regi-Tiyal")),
    ("cds", _("Chadian Sign Language")),
    ("cdy", _("Chadong")),
    ("cdz", _("Koda")),
    ("cea", _("Lower Chehalis")),
    ("ceb", _("Cebuano")),
    ("ceg", _("Chamacoco")),
    ("cek", _("Eastern Khumi Chin")),
    ("cel", _("Celtic languages")),
    ("cen", _("Cen")),
    ("cet", _("Centúúm")),
    ("cey", _("Ekai Chin")),
    ("cfa", _("Dijim-Bwilim")),
    ("cfd", _("Cara")),
    ("cfg", _("Como Karim")),
    ("cfm", _("Falam Chin")),
    ("cga", _("Changriwa")),
    ("cgc", _("Kagayanen")),
    ("cgg", _("Chiga")),
    ("cgk", _("Chocangacakha")),
    ("chb", _("Chibcha")),
    ("chc", _("Catawba")),
    ("chd", _("Highland Oaxaca Chontal")),
    ("chf", _("Tabasco Chontal")),
    ("chg", _("Chagatai")),
    ("chh", _("Chinook")),
    ("chj", _("Ojitlán Chinantec")),
    ("chk", _("Chuukese")),
    ("chl", _("Cahuilla")),
    ("chm", _("Mari")),
    ("chn", _("Chinook jargon")),
    ("cho", _("Choctaw")),
    ("chp", _("Chipewyan")),
    ("chq", _("Quiotepec Chinantec")),
    ("chr", _("Cherokee")),
    ("cht", _("Cholón")),
    ("chw", _("Chuwabu")),
    ("chx", _("Chantyal")),
    ("chy", _("Cheyenne")),
    ("chz", _("Ozumacín Chinantec")),
    ("cia", _("Cia-Cia")),
    ("cib", _("Ci Gbe")),
    ("cic", _("Chickasaw")),
    ("cid", _("Chimariko")),
    ("cie", _("Cineni")),
    ("cih", _("Chinali")),
    ("cik", _("Chitkuli Kinnauri")),
    ("cim", _("Cimbrian")),
    ("cin", _("Cinta Larga")),
    ("cip", _("Chiapanec")),
    ("cir", _("Tiri")),
    ("ciw", _("Chippewa")),
    ("ciy", _("Chaima")),
    ("cja", _("Western Cham")),
    ("cje", _("Chru")),
    ("cjh", _("Upper Chehalis")),
    ("cji", _("Chamalal")),
    ("cjk", _("Chokwe")),
    ("cjm", _("Eastern Cham")),
    ("cjn", _("Chenapian")),
    ("cjo", _("Ashéninka Pajonal")),
    ("cjp", _("Cabécar")),
    ("cjr", _("Chorotega")),
    ("cjs", _("Shor")),
    ("cjv", _("Chuave")),
    ("cjy", _("Jinyu Chinese")),
    ("cka", _("Khumi Awa Chin")),
    ("ckb", _("Central Kurdish")),
    ("ckh", _("Chak")),
    ("ckl", _("Cibak")),
    ("ckm", _("Chakavian")),
    ("ckn", _("Kaang Chin")),
    ("cko", _("Anufo")),
    ("ckq", _("Kajakse")),
    ("ckr", _("Kairak")),
    ("cks", _("Tayo")),
    ("ckt", _("Chukot")),
    ("cku", _("Koasati")),
    ("ckv", _("Kavalan")),
    ("ckx", _("Caka")),
    ("cky", _("Cakfem-Mushere")),
    ("ckz", _("Cakchiquel-Quiché Mixed Language")),
    ("cla", _("Ron")),
    ("clc", _("Chilcotin")),
    ("cld", _("Chaldean Neo-Aramaic")),
    ("cle", _("Lealao Chinantec")),
    ("clh", _("Chilisso")),
    ("cli", _("Chakali")),
    ("clj", _("Laitu Chin")),
    ("clk", _("Idu-Mishmi")),
    ("cll", _("Chala")),
    ("clm", _("Clallam")),
    ("clo", _("Lowland Oaxaca Chontal")),
    ("clt", _("Lautu Chin")),
    ("clu", _("Caluyanun")),
    ("clw", _("Chulym")),
    ("cly", _("Eastern Highland Chatino")),
    ("cma", _("Maa")),
    ("cmc", _("Chamic languages")),
    ("cme", _("Cerma")),
    ("cmg", _("Classical Mongolian")),
    ("cmi", _("Emberá-Chamí")),
    ("cmk", _("Chimakum")),
    ("cml", _("Campalagian")),
    ("cmm", _("Michigamea")),
    ("cmn", _("Mandarin Chinese")),
    ("cmo", _("Central Mnong")),
    ("cmr", _("Mro-Khimi Chin")),
    ("cms", _("Messapic")),
    ("cmt", _("Camtho")),
    ("cna", _("Changthang")),
    ("cnb", _("Chinbon Chin")),
    ("cnc", _("Côông")),
    ("cng", _("Northern Qiang")),
    ("cnh", _("Hakha Chin")),
    ("cni", _("Asháninka")),
    ("cnk", _("Khumi Chin")),
    ("cnl", _("Lalana Chinantec")),
    ("cno", _("Con")),
    ("cnp", _("Northern Ping Chinese")),
    ("cnr", _("Montenegrin")),
    ("cns", _("Central Asmat")),
    ("cnt", _("Tepetotutla Chinantec")),
    ("cnu", _("Chenoua")),
    ("cnw", _("Ngawn Chin")),
    ("cnx", _("Middle Cornish")),
    ("coa", _("Cocos Islands Malay")),
    ("cob", _("Chicomuceltec")),
    ("coc", _("Cocopa")),
    ("cod", _("Cocama-Cocamilla")),
    ("coe", _("Koreguaje")),
    ("cof", _("Colorado")),
    ("cog", _("Chong")),
    ("coh", _("Chonyi-Dzihana-Kauma")),
    ("coj", _("Cochimi")),
    ("cok", _("Santa Teresa Cora")),
    ("col", _("Columbia-Wenatchi")),
    ("com", _("Comanche")),
    ("con", _("Cofán")),
    ("coo", _("Comox")),
    ("cop", _("Coptic")),
    ("coq", _("Coquille")),
    ("cot", _("Caquinte")),
    ("cou", _("Wamey")),
    ("cov", _("Cao Miao")),
    ("cow", _("Cowlitz")),
    ("cox", _("Nanti")),
    ("coy", _("Coyaima")),
    ("coz", _("Chochotec")),
    ("cpa", _("Palantla Chinantec")),
    ("cpb", _("Ucayali-Yurúa Ashéninka")),
    ("cpc", _("Ajyíninka Apurucayali")),
    ("cpe", _("English-based creoles and pidgins")),
    ("cpf", _("French-based creoles and pidgins")),
    ("cpg", _("Cappadocian Greek")),
    ("cpi", _("Chinese Pidgin English")),
    ("cpn", _("Cherepon")),
    ("cpo", _("Kpeego")),
    ("cpp", _("Portuguese-based creoles and pidgins")),
    ("cps", _("Capiznon")),
    ("cpu", _("Pichis Ashéninka")),
    ("cpx", _("Pu-Xian Chinese")),
    ("cpy", _("South Ucayali Ashéninka")),
    ("cqd", _("Chuanqiandian Cluster Miao")),
    ("cqu", _("Chilean Quechua")),
    ("cra", _("Chara")),
    ("crb", _("Island Carib")),
    ("crc", _("Lonwolwol")),
    ("crd", _("Coeur d'Alene")),
    ("crf", _("Caramanta")),
    ("crg", _("Michif")),
    ("crh", _("Crimean Tatar")),
    ("cri", _("Sãotomense")),
    ("crj", _("Southern East Cree")),
    ("crk", _("Plains Cree")),
    ("crl", _("Northern East Cree")),
    ("crm", _("Moose Cree")),
    ("crn", _("El Nayar Cora")),
    ("cro", _("Crow")),
    ("crp", _("Creoles and pidgins")),
    ("crq", _("Iyo'wujwa Chorote")),
    ("crr", _("Carolina Algonquian")),
    ("crs", _("Seselwa Creole French")),
    ("crt", _("Iyojwa'ja Chorote")),
    ("crv", _("Chaura")),
    ("crw", _("Chrau")),
    ("crx", _("Carrier")),
    ("cry", _("Cori")),
    ("crz", _("Cruzeño")),
    ("csa", _("Chiltepec Chinantec")),
    ("csb", _("Kashubian")),
    ("csc", _("Catalan Sign Language")),
    ("csd", _("Chiangmai Sign Language")),
    ("cse", _("Czech Sign Language")),
    ("csf", _("Cuba Sign Language")),
    ("csg", _("Chilean Sign Language")),
    ("csh", _("Asho Chin")),
    ("csi", _("Coast Miwok")),
    ("csj", _("Songlai Chin")),
    ("csk", _("Jola-Kasa")),
    ("csl", _("Chinese Sign Language")),
    ("csm", _("Central Sierra Miwok")),
    ("csn", _("Colombian Sign Language")),
    ("cso", _("Sochiapam Chinantec")),
    ("csp", _("Southern Ping Chinese")),
    ("csq", _("Croatia Sign Language")),
    ("csr", _("Costa Rican Sign Language")),
    ("css", _("Southern Ohlone")),
    ("cst", _("Northern Ohlone")),
    ("csu", _("Central Sudanic languages")),
    ("csv", _("Sumtu Chin")),
    ("csw", _("Swampy Cree")),
    ("csx", _("Cambodian Sign Language")),
    ("csy", _("Siyin Chin")),
    ("csz", _("Coos")),
    ("cta", _("Tataltepec Chatino")),
    ("ctc", _("Chetco")),
    ("ctd", _("Tedim Chin")),
    ("cte", _("Tepinapa Chinantec")),
    ("ctg", _("Chittagonian")),
    ("cth", _("Thaiphum Chin")),
    ("ctl", _("Tlacoatzintepec Chinantec")),
    ("ctm", _("Chitimacha")),
    ("ctn", _("Chhintange")),
    ("cto", _("Emberá-Catío")),
    ("ctp", _("Western Highland Chatino")),
    ("cts", _("Northern Catanduanes Bikol")),
    ("ctt", _("Wayanad Chetti")),
    ("ctu", _("Chol")),
    ("cty", _("Moundadan Chetty")),
    ("ctz", _("Zacatepec Chatino")),
    ("cua", _("Cua")),
    ("cub", _("Cubeo")),
    ("cuc", _("Usila Chinantec")),
    ("cug", _("Chungmboko")),
    ("cuh", _("Chuka")),
    ("cui", _("Cuiba")),
    ("cuj", _("Mashco Piro")),
    ("cuk", _("San Blas Kuna")),
    ("cul", _("Culina")),
    ("cum", _("Cumeral")),
    ("cuo", _("Cumanagoto")),
    ("cup", _("Cupeño")),
    ("cuq", _("Cun")),
    ("cur", _("Chhulung")),
    ("cus", _("Cushitic languages")),
    ("cut", _("Teutila Cuicatec")),
    ("cuu", _("Tai Ya")),
    ("cuv", _("Cuvok")),
    ("cuw", _("Chukwa")),
    ("cux", _("Tepeuxila Cuicatec")),
    ("cuy", _("Cuitlatec")),
    ("cvg", _("Chug")),
    ("cvn", _("Valle Nacional Chinantec")),
    ("cwa", _("Kabwa")),
    ("cwb", _("Maindo")),
    ("cwd", _("Woods Cree")),
    ("cwe", _("Kwere")),
    ("cwg", _("Chewong")),
    ("cwt", _("Kuwaataay")),
    ("cya", _("Nopala Chatino")),
    ("cyb", _("Cayubaba")),
    ("cyo", _("Cuyonon")),
    ("czh", _("Huizhou Chinese")),
    ("czk", _("Knaanic")),
    ("czn", _("Zenzontepec Chatino")),
    ("czo", _("Min Zhong Chinese")),
    ("czt", _("Zotung Chin")),
    ("daa", _("Dangaléat")),
    ("dac", _("Dambi")),
    ("dad", _("Marik")),
    ("dae", _("Duupa")),
    ("daf", _("Dan")),
    ("dag", _("Dagbani")),
    ("dah", _("Gwahatike")),
    ("dai", _("Day")),
    ("daj", _("Dar Fur Daju")),
    ("dak", _("Dakota")),
    ("dal", _("Dahalo")),
    ("dam", _("Damakawa")),
    ("dao", _("Daai Chin")),
    ("dap", _("Nisi")),
    ("daq", _("Dandami Maria")),
    ("dar", _("Dargwa")),
    ("das", _("Daho-Doo")),
    ("dau", _("Dar Sila Daju")),
    ("dav", _("Taita")),
    ("daw", _("Davawenyo")),
    ("dax", _("Dayi")),
    ("day", _("Land Dayak languages")),
    ("daz", _("Dao")),
    ("dba", _("Bangime")),
    ("dbb", _("Deno")),
    ("dbd", _("Dadiya")),
    ("dbe", _("Dabe")),
    ("dbf", _("Edopi")),
    ("dbg", _("Dogul Dom Dogon")),
    ("dbi", _("Doka")),
    ("dbj", _("Ida'an")),
    ("dbl", _("Dyirbal")),
    ("dbm", _("Duguri")),
    ("dbn", _("Duriankere")),
    ("dbo", _("Dulbu")),
    ("dbp", _("Duwai")),
    ("dbq", _("Daba")),
    ("dbr", _("Dabarre")),
    ("dbt", _("Ben Tey Dogon")),
    ("dbu", _("Bondum Dom Dogon")),
    ("dbv", _("Dungu")),
    ("dbw", _("Bankan Tey Dogon")),
    ("dby", _("Dibiyaso")),
    ("dcc", _("Deccan")),
    ("dcr", _("Negerhollands")),
    ("dda", _("Dadi Dadi")),
    ("ddd", _("Dongotono")),
    ("dde", _("Doondo")),
    ("ddg", _("Fataluku")),
    ("ddi", _("West Goodenough")),
    ("ddj", _("Jaru")),
    ("ddn", _("Dendi")),
    ("ddo", _("Dido")),
    ("ddr", _("Dhudhuroa")),
    ("dds", _("Donno So Dogon")),
    ("ddw", _("Dawera-Daweloor")),
    ("dec", _("Dagik")),
    ("ded", _("Dedua")),
    ("dee", _("Dewoin")),
    ("def", _("Dezfuli")),
    ("deg", _("Degema")),
    ("deh", _("Dehwari")),
    ("dei", _("Demisa")),
    ("dek", _("Dek")),
    ("del", _("Delaware")),
    ("dem", _("Dem")),
    ("den", _("Slave")),
    ("dep", _("Pidgin Delaware")),
    ("deq", _("Dendi")),
    ("der", _("Deori")),
    ("des", _("Desano")),
    ("dev", _("Domung")),
    ("dez", _("Dengese")),
    ("dga", _("Southern Dagaare")),
    ("dgb", _("Bunoge Dogon")),
    ("dgc", _("Casiguran Dumagat Agta")),
    ("dgd", _("Dagaari Dioula")),
    ("dge", _("Degenan")),
    ("dgg", _("Doga")),
    ("dgh", _("Dghwede")),
    ("dgi", _("Northern Dagara")),
    ("dgk", _("Dagba")),
    ("dgl", _("Andaandi")),
    ("dgn", _("Dagoman")),
    ("dgo", _("Dogri")),
    ("dgr", _("Dogrib")),
    ("dgs", _("Dogoso")),
    ("dgt", _("Ndra'ngith")),
    ("dgu", _("Degaru")),
    ("dgw", _("Daungwurrung")),
    ("dgx", _("Doghoro")),
    ("dgz", _("Daga")),
    ("dha", _("Dhanwar")),
    ("dhd", _("Dhundari")),
    ("dhg", _("Dhangu-Djangu")),
    ("dhi", _("Dhimal")),
    ("dhl", _("Dhalandji")),
    ("dhm", _("Zemba")),
    ("dhn", _("Dhanki")),
    ("dho", _("Dhodia")),
    ("dhr", _("Dhargari")),
    ("dhs", _("Dhaiso")),
    ("dhu", _("Dhurga")),
    ("dhv", _("Dehu")),
    ("dhw", _("Dhanwar")),
    ("dhx", _("Dhungaloo")),
    ("dia", _("Dia")),
    ("dib", _("South Central Dinka")),
    ("dic", _("Lakota Dida")),
    ("did", _("Didinga")),
    ("dif", _("Dieri")),
    ("dig", _("Digo")),
    ("dih", _("Kumiai")),
    ("dii", _("Dimbong")),
    ("dij", _("Dai")),
    ("dik", _("Southwestern Dinka")),
    ("dil", _("Dilling")),
    ("dim", _("Dime")),
    ("din", _("Dinka")),
    ("dio", _("Dibo")),
    ("dip", _("Northeastern Dinka")),
    ("diq", _("Dimli")),
    ("dir", _("Dirim")),
    ("dis", _("Dimasa")),
    ("dit", _("Dirari")),
    ("diu", _("Diriku")),
    ("diw", _("Northwestern Dinka")),
    ("dix", _("Dixon Reef")),
    ("diy", _("Diuwe")),
    ("diz", _("Ding")),
    ("dja", _("Djadjawurrung")),
    ("djb", _("Djinba")),
    ("djc", _("Dar Daju Daju")),
    ("djd", _("Djamindjung")),
    ("dje", _("Zarma")),
    ("djf", _("Djangun")),
    ("dji", _("Djinang")),
    ("djj", _("Djeebbana")),
    ("djk", _("Eastern Maroon Creole")),
    ("djl", _("Djiwarli")),
    ("djm", _("Jamsay Dogon")),
    ("djn", _("Jawoyn")),
    ("djo", _("Jangkang")),
    ("djr", _("Djambarrpuyngu")),
    ("dju", _("Kapriman")),
    ("djw", _("Djawi")),
    ("dka", _("Dakpakha")),
    ("dkg", _("Kadung")),
    ("dkk", _("Dakka")),
    ("dkl", _("Kolum So Dogon")),
    ("dkr", _("Kuijau")),
    ("dks", _("Southeastern Dinka")),
    ("dkx", _("Mazagway")),
    ("dlg", _("Dolgan")),
    ("dlk", _("Dahalik")),
    ("dlm", _("Dalmatian")),
    ("dln", _("Darlong")),
    ("dma", _("Duma")),
    ("dmb", _("Mombo Dogon")),
    ("dmc", _("Gavak")),
    ("dmd", _("Madhi Madhi")),
    ("dme", _("Dugwor")),
    ("dmf", _("Medefaidrin")),
    ("dmg", _("Upper Kinabatangan")),
    ("dmk", _("Domaaki")),
    ("dml", _("Dameli")),
    ("dmm", _("Dama")),
    ("dmn", _("Mande languages")),
    ("dmo", _("Kemedzung")),
    ("dmr", _("East Damar")),
    ("dms", _("Dampelas")),
    ("dmu", _("Dubu")),
    ("dmv", _("Dumpas")),
    ("dmw", _("Mudburra")),
    ("dmx", _("Dema")),
    ("dmy", _("Demta")),
    ("dna", _("Upper Grand Valley Dani")),
    ("dnd", _("Daonda")),
    ("dne", _("Ndendeule")),
    ("dng", _("Dungan")),
    ("dni", _("Lower Grand Valley Dani")),
    ("dnj", _("Dan")),
    ("dnk", _("Dengka")),
    ("dnn", _("Dzùùngoo")),
    ("dno", _("Ndrulo")),
    ("dnr", _("Danaru")),
    ("dnt", _("Mid Grand Valley Dani")),
    ("dnu", _("Danau")),
    ("dnv", _("Danu")),
    ("dnw", _("Western Dani")),
    ("dny", _("Dení")),
    ("doa", _("Dom")),
    ("dob", _("Dobu")),
    ("doc", _("Northern Dong")),
    ("doe", _("Doe")),
    ("dof", _("Domu")),
    ("doh", _("Dong")),
    ("doi", _("Dogri")),
    ("dok", _("Dondo")),
    ("dol", _("Doso")),
    ("don", _("Toura")),
    ("doo", _("Dongo")),
    ("dop", _("Lukpa")),
    ("doq", _("Dominican Sign Language")),
    ("dor", _("Dori'o")),
    ("dos", _("Dogosé")),
    ("dot", _("Dass")),
    ("dov", _("Dombe")),
    ("dow", _("Doyayo")),
    ("dox", _("Bussa")),
    ("doy", _("Dompo")),
    ("doz", _("Dorze")),
    ("dpp", _("Papar")),
    ("dra", _("Dravidian languages")),
    ("drb", _("Dair")),
    ("drc", _("Minderico")),
    ("drd", _("Darmiya")),
    ("dre", _("Dolpo")),
    ("drg", _("Rungus")),
    ("drh", _("Darkhat")),
    ("dri", _("C'Lela")),
    ("drl", _("Paakantyi")),
    ("drn", _("West Damar")),
    ("dro", _("Daro-Matu Melanau")),
    ("drq", _("Dura")),
    ("drr", _("Dororo")),
    ("drs", _("Gedeo")),
    ("drt", _("Drents")),
    ("dru", _("Rukai")),
    ("drw", _("Darwazi")),
    ("dry", _("Darai")),
    ("dsb", _("Lower Sorbian")),
    ("dse", _("Dutch Sign Language")),
    ("dsh", _("Daasanach")),
    ("dsi", _("Disa")),
    ("dsl", _("Danish Sign Language")),
    ("dsn", _("Dusner")),
    ("dso", _("Desiya")),
    ("dsq", _("Tadaksahak")),
    ("dta", _("Daur")),
    ("dtb", _("Labuk-Kinabatangan Kadazan")),
    ("dtd", _("Ditidaht")),
    ("dth", _("Adithinngithigh")),
    ("dti", _("Ana Tinga Dogon")),
    ("dtk", _("Tene Kan Dogon")),
    ("dtm", _("Tomo Kan Dogon")),
    ("dtn", _("Daatsʼíin")),
    ("dto", _("Tommo So Dogon")),
    ("dtp", _("Kadazan Dusun")),
    ("dtr", _("Lotud")),
    ("dts", _("Toro So Dogon")),
    ("dtt", _("Toro Tegu Dogon")),
    ("dtu", _("Tebul Ure Dogon")),
    ("dty", _("Dotyali")),
    ("dua", _("Duala")),
    ("dub", _("Dubli")),
    ("duc", _("Duna")),
    ("dud", _("Hun-Saare")),
    ("due", _("Umiray Dumaget Agta")),
    ("duf", _("Dumbea")),
    ("dug", _("Duruma")),
    ("duh", _("Dungra Bhil")),
    ("dui", _("Dumun")),
    ("duj", _("Dhuwal")),
    ("duk", _("Uyajitaya")),
    ("dul", _("Alabat Island Agta")),
    ("dum", _("Middle Dutch")),
    ("dun", _("Dusun Deyah")),
    ("duo", _("Dupaninan Agta")),
    ("dup", _("Duano")),
    ("duq", _("Dusun Malang")),
    ("dur", _("Dii")),
    ("dus", _("Dumi")),
    ("duu", _("Drung")),
    ("duv", _("Duvle")),
    ("duw", _("Dusun Witu")),
    ("dux", _("Duungooma")),
    ("duy", _("Dicamay Agta")),
    ("duz", _("Duli-Gey")),
    ("dva", _("Duau")),
    ("dwa", _("Diri")),
    ("dwk", _("Dawik Kui")),
    ("dwl", _("Walo Kumbe Dogon")),
    ("dwr", _("Dawro")),
    ("dws", _("Dutton World Speedwords")),
    ("dwu", _("Dhuwal")),
    ("dww", _("Dawawa")),
    ("dwy", _("Dhuwaya")),
    ("dwz", _("Dewas Rai")),
    ("dya", _("Dyan")),
    ("dyb", _("Dyaberdyaber")),
    ("dyd", _("Dyugun")),
    ("dyg", _("Villa Viciosa Agta")),
    ("dyi", _("Djimini Senoufo")),
    ("dym", _("Yanda Dom Dogon")),
    ("dyn", _("Dyangadi")),
    ("dyo", _("Jola-Fonyi")),
    ("dyu", _("Dyula")),
    ("dyy", _("Djabugay")),
    ("dza", _("Tunzu")),
    ("dzd", _("Daza")),
    ("dze", _("Djiwarli")),
    ("dzg", _("Dazaga")),
    ("dzl", _("Dzalakha")),
    ("dzn", _("Dzando")),
    ("eaa", _("Karenggapa")),
    ("ebc", _("Beginci")),
    ("ebg", _("Ebughu")),
    ("ebk", _("Eastern Bontok")),
    ("ebo", _("Teke-Ebo")),
    ("ebr", _("Ebrié")),
    ("ebu", _("Embu")),
    ("ecr", _("Eteocretan")),
    ("ecs", _("Ecuadorian Sign Language")),
    ("ecy", _("Eteocypriot")),
    ("eee", _("E")),
    ("efa", _("Efai")),
    ("efe", _("Efe")),
    ("efi", _("Efik")),
    ("ega", _("Ega")),
    ("egl", _("Emilian")),
    ("ego", _("Eggon")),
    ("egx", _("Egyptian languages")),
    ("egy", _("Egyptian")),
    ("ehs", _("Miyakubo Sign Language")),
    ("ehu", _("Ehueun")),
    ("eip", _("Eipomek")),
    ("eit", _("Eitiep")),
    ("eiv", _("Askopan")),
    ("eja", _("Ejamat")),
    ("eka", _("Ekajuk")),
    ("ekc", _("Eastern Karnic")),
    ("eke", _("Ekit")),
    ("ekg", _("Ekari")),
    ("eki", _("Eki")),
    ("ekk", _("Standard Estonian")),
    ("ekl", _("Kol")),
    ("ekm", _("Elip")),
    ("eko", _("Koti")),
    ("ekp", _("Ekpeye")),
    ("ekr", _("Yace")),
    ("eky", _("Eastern Kayah")),
    ("ele", _("Elepi")),
    ("elh", _("El Hugeirat")),
    ("eli", _("Nding")),
    ("elk", _("Elkei")),
    ("elm", _("Eleme")),
    ("elo", _("El Molo")),
    ("elp", _("Elpaputih")),
    ("elu", _("Elu")),
    ("elx", _("Elamite")),
    ("ema", _("Emai-Iuleha-Ora")),
    ("emb", _("Embaloh")),
    ("eme", _("Emerillon")),
    ("emg", _("Eastern Meohang")),
    ("emi", _("Mussau-Emira")),
    ("emk", _("Eastern Maninkakan")),
    ("emm", _("Mamulique")),
    ("emn", _("Eman")),
    ("emo", _("Emok")),
    ("emp", _("Northern Emberá")),
    ("emq", _("Eastern Minyag")),
    ("ems", _("Pacific Gulf Yupik")),
    ("emu", _("Eastern Muria")),
    ("emw", _("Emplawas")),
    ("emx", _("Erromintxela")),
    ("emy", _("Epigraphic Mayan")),
    ("emz", _("Mbessa")),
    ("ena", _("Apali")),
    ("enb", _("Markweeta")),
    ("enc", _("En")),
    ("end", _("Ende")),
    ("enf", _("Forest Enets")),
    ("enh", _("Tundra Enets")),
    ("enl", _("Enlhet")),
    ("enm", _("Middle English")),
    ("enn", _("Engenni")),
    ("eno", _("Enggano")),
    ("enq", _("Enga")),
    ("enr", _("Emumu")),
    ("enu", _("Enu")),
    ("env", _("Enwan")),
    ("enw", _("Enwan")),
    ("enx", _("Enxet")),
    ("eot", _("Beti")),
    ("epi", _("Epie")),
    ("era", _("Eravallan")),
    ("erg", _("Sie")),
    ("erh", _("Eruwa")),
    ("eri", _("Ogea")),
    ("erk", _("South Efate")),
    ("ero", _("Horpa")),
    ("err", _("Erre")),
    ("ers", _("Ersu")),
    ("ert", _("Eritai")),
    ("erw", _("Erokwanas")),
    ("ese", _("Ese Ejja")),
    ("esg", _("Aheri Gondi")),
    ("esh", _("Eshtehardi")),
    ("esi", _("North Alaskan Inupiatun")),
    ("esk", _("Northwest Alaska Inupiatun")),
    ("esl", _("Egypt Sign Language")),
    ("esm", _("Esuma")),
    ("esn", _("Salvadoran Sign Language")),
    ("eso", _("Estonian Sign Language")),
    ("esq", _("Esselen")),
    ("ess", _("Central Siberian Yupik")),
    ("esu", _("Central Yupik")),
    ("esx", _("Eskimo-Aleut languages")),
    ("esy", _("Eskayan")),
    ("etb", _("Etebi")),
    ("etc", _("Etchemin")),
    ("eth", _("Ethiopian Sign Language")),
    ("etn", _("Eton")),
    ("eto", _("Eton")),
    ("etr", _("Edolo")),
    ("ets", _("Yekhee")),
    ("ett", _("Etruscan")),
    ("etu", _("Ejagham")),
    ("etx", _("Eten")),
    ("etz", _("Semimi")),
    ("euq", _("Basque")),
    ("eve", _("Even")),
    ("evh", _("Uvbie")),
    ("evn", _("Evenki")),
    ("ewo", _("Ewondo")),
    ("ext", _("Extremaduran")),
    ("eya", _("Eyak")),
    ("eyo", _("Keiyo")),
    ("eza", _("Ezaa")),
    ("eze", _("Uzekwe")),
    ("faa", _("Fasu")),
    ("fab", _("Fa d'Ambu")),
    ("fad", _("Wagi")),
    ("faf", _("Fagani")),
    ("fag", _("Finongan")),
    ("fah", _("Baissa Fali")),
    ("fai", _("Faiwol")),
    ("faj", _("Faita")),
    ("fak", _("Fang")),
    ("fal", _("South Fali")),
    ("fam", _("Fam")),
    ("fan", _("Fang")),
    ("fap", _("Paloor")),
    ("far", _("Fataleka")),
    ("fat", _("Fanti")),
    ("fau", _("Fayu")),
    ("fax", _("Fala")),
    ("fay", _("Southwestern Fars")),
    ("faz", _("Northwestern Fars")),
    ("fbl", _("West Albay Bikol")),
    ("fcs", _("Quebec Sign Language")),
    ("fer", _("Feroge")),
    ("ffi", _("Foia Foia")),
    ("ffm", _("Maasina Fulfulde")),
    ("fgr", _("Fongoro")),
    ("fia", _("Nobiin")),
    ("fie", _("Fyer")),
    ("fif", _("Faifi")),
    ("fil", _("Filipino")),
    ("fip", _("Fipa")),
    ("fir", _("Firan")),
    ("fit", _("Tornedalen Finnish")),
    ("fiu", _("Finno-Ugrian languages")),
    ("fiw", _("Fiwaga")),
    ("fkk", _("Kirya-Konzəl")),
    ("fkv", _("Kven Finnish")),
    ("fla", _("Kalispel-Pend d'Oreille")),
    ("flh", _("Foau")),
    ("fli", _("Fali")),
    ("fll", _("North Fali")),
    ("fln", _("Flinders Island")),
    ("flr", _("Fuliiru")),
    ("fly", _("Flaaitaal")),
    ("fmp", _("Fe'fe'")),
    ("fmu", _("Far Western Muria")),
    ("fnb", _("Fanbak")),
    ("fng", _("Fanagalo")),
    ("fni", _("Fania")),
    ("fod", _("Foodo")),
    ("foi", _("Foi")),
    ("fom", _("Foma")),
    ("fon", _("Fon")),
    ("for", _("Fore")),
    ("fos", _("Siraya")),
    ("fox", _("Formosan languages")),
    ("fpe", _("Fernando Po Creole English")),
    ("fqs", _("Fas")),
    ("frc", _("Cajun French")),
    ("frd", _("Fordata")),
    ("frk", _("Frankish")),
    ("frm", _("Middle French")),
    ("fro", _("Old French")),
    ("frp", _("Arpitan")),
    ("frq", _("Forak")),
    ("frr", _("Northern Frisian")),
    ("frs", _("Eastern Frisian")),
    ("frt", _("Fortsenal")),
    ("fse", _("Finnish Sign Language")),
    ("fsl", _("French Sign Language")),
    ("fss", _("Finland-Swedish Sign Language")),
    ("fub", _("Adamawa Fulfulde")),
    ("fuc", _("Pulaar")),
    ("fud", _("East Futuna")),
    ("fue", _("Borgu Fulfulde")),
    ("fuf", _("Pular")),
    ("fuh", _("Western Niger Fulfulde")),
    ("fui", _("Bagirmi Fulfulde")),
    ("fuj", _("Ko")),
    ("fum", _("Fum")),
    ("fun", _("Fulniô")),
    ("fuq", _("Central-Eastern Niger Fulfulde")),
    ("fur", _("Friulian")),
    ("fut", _("Futuna-Aniwa")),
    ("fuu", _("Furu")),
    ("fuv", _("Nigerian Fulfulde")),
    ("fuy", _("Fuyug")),
    ("fvr", _("Fur")),
    ("fwa", _("Fwâi")),
    ("fwe", _("Fwe")),
    ("gaa", _("Ga")),
    ("gab", _("Gabri")),
    ("gac", _("Mixed Great Andamanese")),
    ("gad", _("Gaddang")),
    ("gae", _("Guarequena")),
    ("gaf", _("Gende")),
    ("gag", _("Gagauz")),
    ("gah", _("Alekano")),
    ("gai", _("Borei")),
    ("gaj", _("Gadsup")),
    ("gak", _("Gamkonora")),
    ("gal", _("Galolen")),
    ("gam", _("Kandawo")),
    ("gan", _("Gan Chinese")),
    ("gao", _("Gants")),
    ("gap", _("Gal")),
    ("gaq", _("Gata'")),
    ("gar", _("Galeya")),
    ("gas", _("Adiwasi Garasia")),
    ("gat", _("Kenati")),
    ("gau", _("Mudhili Gadaba")),
    ("gav", _("Gabutamon")),
    ("gaw", _("Nobonob")),
    ("gax", _("Borana-Arsi-Guji Oromo")),
    ("gay", _("Gayo")),
    ("gaz", _("West Central Oromo")),
    ("gba", _("Gbaya")),
    ("gbb", _("Kaytetye")),
    ("gbc", _("Garawa")),
    ("gbd", _("Karajarri")),
    ("gbe", _("Niksek")),
    ("gbf", _("Gaikundi")),
    ("gbg", _("Gbanziri")),
    ("gbh", _("Defi Gbe")),
    ("gbi", _("Galela")),
    ("gbj", _("Bodo Gadaba")),
    ("gbk", _("Gaddi")),
    ("gbl", _("Gamit")),
    ("gbm", _("Garhwali")),
    ("gbn", _("Mo'da")),
    ("gbo", _("Northern Grebo")),
    ("gbp", _("Gbaya-Bossangoa")),
    ("gbq", _("Gbaya-Bozoum")),
    ("gbr", _("Gbagyi")),
    ("gbs", _("Gbesi Gbe")),
    ("gbu", _("Gagadu")),
    ("gbv", _("Gbanu")),
    ("gbw", _("Gabi-Gabi")),
    ("gbx", _("Eastern Xwla Gbe")),
    ("gby", _("Gbari")),
    ("gbz", _("Zoroastrian Dari")),
    ("gcc", _("Mali")),
    ("gcd", _("Ganggalida")),
    ("gce", _("Galice")),
    ("gcf", _("Guadeloupean Creole French")),
    ("gcl", _("Grenadian Creole English")),
    ("gcn", _("Gaina")),
    ("gcr", _("Guianese Creole French")),
    ("gct", _("Colonia Tovar German")),
    ("gda", _("Gade Lohar")),
    ("gdb", _("Pottangi Ollar Gadaba")),
    ("gdc", _("Gugu Badhun")),
    ("gdd", _("Gedaged")),
    ("gde", _("Gude")),
    ("gdf", _("Guduf-Gava")),
    ("gdg", _("Ga'dang")),
    ("gdh", _("Gadjerawang")),
    ("gdi", _("Gundi")),
    ("gdj", _("Gurdjar")),
    ("gdk", _("Gadang")),
    ("gdl", _("Dirasha")),
    ("gdm", _("Laal")),
    ("gdn", _("Umanakaina")),
    ("gdo", _("Ghodoberi")),
    ("gdq", _("Mehri")),
    ("gdr", _("Wipi")),
    ("gds", _("Ghandruk Sign Language")),
    ("gdt", _("Kungardutyi")),
    ("gdu", _("Gudu")),
    ("gdx", _("Godwari")),
    ("gea", _("Geruma")),
    ("geb", _("Kire")),
    ("gec", _("Gboloo Grebo")),
    ("ged", _("Gade")),
    ("gef", _("Gerai")),
    ("geg", _("Gengle")),
    ("geh", _("Hutterite German")),
    ("gei", _("Gebe")),
    ("gej", _("Gen")),
    ("gek", _("Ywom")),
    ("gel", _("ut-Ma'in")),
    ("gem", _("Germanic languages")),
    ("geq", _("Geme")),
    ("ges", _("Geser-Gorom")),
    ("gev", _("Eviya")),
    ("gew", _("Gera")),
    ("gex", _("Garre")),
    ("gey", _("Enya")),
    ("gez", _("Geez")),
    ("gfk", _("Patpatar")),
    ("gft", _("Gafat")),
    ("gfx", _("Mangetti Dune ǃXung")),
    ("gga", _("Gao")),
    ("ggb", _("Gbii")),
    ("ggd", _("Gugadj")),
    ("gge", _("Gurr-goni")),
    ("ggg", _("Gurgula")),
    ("ggk", _("Kungarakany")),
    ("ggl", _("Ganglau")),
    ("ggn", _("Eastern Gurung")),
    ("ggo", _("Southern Gondi")),
    ("ggr", _("Aghu Tharnggalu")),
    ("ggt", _("Gitua")),
    ("ggu", _("Gagu")),
    ("ggw", _("Gogodala")),
    ("gha", _("Ghadamès")),
    ("ghc", _("Hiberno-Scottish Gaelic")),
    ("ghe", _("Southern Ghale")),
    ("ghh", _("Northern Ghale")),
    ("ghk", _("Geko Karen")),
    ("ghl", _("Ghulfan")),
    ("ghn", _("Ghanongga")),
    ("gho", _("Ghomara")),
    ("ghr", _("Ghera")),
    ("ghs", _("Guhu-Samane")),
    ("ght", _("Kuke")),
    ("gia", _("Kija")),
    ("gib", _("Gibanawa")),
    ("gic", _("Gail")),
    ("gid", _("Gidar")),
    ("gie", _("Gaɓogbo")),
    ("gig", _("Goaria")),
    ("gih", _("Githabul")),
    ("gii", _("Girirra")),
    ("gil", _("Gilbertese")),
    ("gim", _("Gimi")),
    ("gin", _("Hinukh")),
    ("gio", _("Gelao")),
    ("gip", _("Gimi")),
    ("giq", _("Green Gelao")),
    ("gir", _("Red Gelao")),
    ("gis", _("North Giziga")),
    ("git", _("Gitxsan")),
    ("giu", _("Mulao")),
    ("giw", _("White Gelao")),
    ("gix", _("Gilima")),
    ("giy", _("Giyug")),
    ("giz", _("South Giziga")),
    ("gji", _("Geji")),
    ("gjk", _("Kachi Koli")),
    ("gjm", _("Gunditjmara")),
    ("gjn", _("Gonja")),
    ("gjr", _("Gurindji Kriol")),
    ("gju", _("Gujari")),
    ("gka", _("Guya")),
    ("gkd", _("Magɨ")),
    ("gke", _("Ndai")),
    ("gkn", _("Gokana")),
    ("gko", _("Kok-Nar")),
    ("gkp", _("Guinea Kpelle")),
    ("gku", _("ǂUngkue")),
    ("glb", _("Belning")),
    ("glc", _("Bon Gula")),
    ("gld", _("Nanai")),
    ("glh", _("Northwest Pashai")),
    ("gli", _("Guliguli")),
    ("glj", _("Gula Iro")),
    ("glk", _("Gilaki")),
    ("gll", _("Garlali")),
    ("glo", _("Galambu")),
    ("glr", _("Glaro-Twabo")),
    ("glu", _("Gula")),
    ("glw", _("Glavda")),
    ("gly", _("Gule")),
    ("gma", _("Gambera")),
    ("gmb", _("Gula'alaa")),
    ("gmd", _("Mághdì")),
    ("gme", _("East Germanic languages")),
    ("gmg", _("Magɨyi")),
    ("gmh", _("Middle High German")),
    ("gml", _("Middle Low German")),
    ("gmm", _("Gbaya-Mbodomo")),
    ("gmn", _("Gimnime")),
    ("gmq", _("North Germanic languages")),
    ("gmr", _("Mirning")),
    ("gmu", _("Gumalu")),
    ("gmv", _("Gamo")),
    ("gmw", _("West Germanic languages")),
    ("gmx", _("Magoma")),
    ("gmy", _("Mycenaean Greek")),
    ("gmz", _("Mgbolizhia")),
    ("gna", _("Kaansa")),
    ("gnb", _("Gangte")),
    ("gnc", _("Guanche")),
    ("gnd", _("Zulgo-Gemzek")),
    ("gne", _("Ganang")),
    ("gng", _("Ngangam")),
    ("gnh", _("Lere")),
    ("gni", _("Gooniyandi")),
    ("gnj", _("Ngen")),
    ("gnk", _("ǁGana")),
    ("gnl", _("Gangulu")),
    ("gnm", _("Ginuman")),
    ("gnn", _("Gumatj")),
    ("gno", _("Northern Gondi")),
    ("gnq", _("Gana")),
    ("gnr", _("Gureng Gureng")),
    ("gnt", _("Guntai")),
    ("gnu", _("Gnau")),
    ("gnw", _("Western Bolivian Guaraní")),
    ("gnz", _("Ganzi")),
    ("goa", _("Guro")),
    ("gob", _("Playero")),
    ("goc", _("Gorakor")),
    ("god", _("Godié")),
    ("goe", _("Gongduk")),
    ("gof", _("Gofa")),
    ("gog", _("Gogo")),
    ("goh", _("Old High German")),
    ("goi", _("Gobasi")),
    ("goj", _("Gowlan")),
    ("gok", _("Gowli")),
    ("gol", _("Gola")),
    ("gom", _("Goan Konkani")),
    ("gon", _("Gondi")),
    ("goo", _("Gone Dau")),
    ("gop", _("Yeretuar")),
    ("goq", _("Gorap")),
    ("gor", _("Gorontalo")),
    ("gos", _("Gronings")),
    ("got", _("Gothic")),
    ("gou", _("Gavar")),
    ("gow", _("Gorowa")),
    ("gox", _("Gobu")),
    ("goy", _("Goundo")),
    ("goz", _("Gozarkhani")),
    ("gpa", _("Gupa-Abawa")),
    ("gpe", _("Ghanaian Pidgin English")),
    ("gpn", _("Taiap")),
    ("gqa", _("Ga'anda")),
    ("gqi", _("Guiqiong")),
    ("gqn", _("Guana")),
    ("gqr", _("Gor")),
    ("gqu", _("Qau")),
    ("gra", _("Rajput Garasia")),
    ("grb", _("Grebo")),
    ("grc", _("Ancient Greek")),
    ("grd", _("Guruntum-Mbaaru")),
    ("grg", _("Madi")),
    ("grh", _("Gbiri-Niragu")),
    ("gri", _("Ghari")),
    ("grj", _("Southern Grebo")),
    ("grk", _("Greek languages")),
    ("grm", _("Kota Marudu Talantang")),
    ("gro", _("Groma")),
    ("grq", _("Gorovu")),
    ("grr", _("Taznatit")),
    ("grs", _("Gresi")),
    ("grt", _("Garo")),
    ("gru", _("Kistane")),
    ("grv", _("Central Grebo")),
    ("grw", _("Gweda")),
    ("grx", _("Guriaso")),
    ("gry", _("Barclayville Grebo")),
    ("grz", _("Guramalum")),
    ("gse", _("Ghanaian Sign Language")),
    ("gsg", _("German Sign Language")),
    ("gsl", _("Gusilay")),
    ("gsm", _("Guatemalan Sign Language")),
    ("gsn", _("Nema")),
    ("gso", _("Southwest Gbaya")),
    ("gsp", _("Wasembo")),
    ("gss", _("Greek Sign Language")),
    ("gsw", _("Swiss German")),
    ("gta", _("Guató")),
    ("gti", _("Gbati-ri")),
    ("gtu", _("Aghu-Tharnggala")),
    ("gua", _("Shiki")),
    ("gub", _("Guajajára")),
    ("guc", _("Wayuu")),
    ("gud", _("Yocoboué Dida")),
    ("gue", _("Gurindji")),
    ("guf", _("Gupapuyngu")),
    ("gug", _("Paraguayan Guaraní")),
    ("guh", _("Guahibo")),
    ("gui", _("Eastern Bolivian Guaraní")),
    ("guk", _("Gumuz")),
    ("gul", _("Sea Island Creole English")),
    ("gum", _("Guambiano")),
    ("gun", _("Mbyá Guaraní")),
    ("guo", _("Guayabero")),
    ("gup", _("Gunwinggu")),
    ("guq", _("Aché")),
    ("gur", _("Farefare")),
    ("gus", _("Guinean Sign Language")),
    ("gut", _("Maléku Jaíka")),
    ("guu", _("Yanomamö")),
    ("guv", _("Gey")),
    ("guw", _("Gun")),
    ("gux", _("Gourmanchéma")),
    ("guz", _("Gusii")),
    ("gva", _("Guana")),
    ("gvc", _("Guanano")),
    ("gve", _("Duwet")),
    ("gvf", _("Golin")),
    ("gvj", _("Guajá")),
    ("gvl", _("Gulay")),
    ("gvm", _("Gurmana")),
    ("gvn", _("Kuku-Yalanji")),
    ("gvo", _("Gavião Do Jiparaná")),
    ("gvp", _("Pará Gavião")),
    ("gvr", _("Gurung")),
    ("gvs", _("Gumawana")),
    ("gvy", _("Guyani")),
    ("gwa", _("Mbato")),
    ("gwb", _("Gwa")),
    ("gwc", _("Gawri")),
    ("gwd", _("Gawwada")),
    ("gwe", _("Gweno")),
    ("gwf", _("Gowro")),
    ("gwg", _("Moo")),
    ("gwi", _("Gwichʼin")),
    ("gwj", _("ǀGwi")),
    ("gwm", _("Awngthim")),
    ("gwn", _("Gwandara")),
    ("gwr", _("Gwere")),
    ("gwt", _("Gawar-Bati")),
    ("gwu", _("Guwamu")),
    ("gww", _("Kwini")),
    ("gwx", _("Gua")),
    ("gxx", _("Wè Southern")),
    ("gya", _("Northwest Gbaya")),
    ("gyb", _("Garus")),
    ("gyd", _("Kayardild")),
    ("gye", _("Gyem")),
    ("gyf", _("Gungabula")),
    ("gyg", _("Gbayi")),
    ("gyi", _("Gyele")),
    ("gyl", _("Gayil")),
    ("gym", _("Ngäbere")),
    ("gyn", _("Guyanese Creole English")),
    ("gyo", _("Gyalsumdo")),
    ("gyr", _("Guarayu")),
    ("gyy", _("Gunya")),
    ("gyz", _("Geji")),
    ("gza", _("Ganza")),
    ("gzi", _("Gazi")),
    ("gzn", _("Gane")),
    ("haa", _("Han")),
    ("hab", _("Hanoi Sign Language")),
    ("hac", _("Gurani")),
    ("had", _("Hatam")),
    ("hae", _("Eastern Oromo")),
    ("haf", _("Haiphong Sign Language")),
    ("hag", _("Hanga")),
    ("hah", _("Hahon")),
    ("hai", _("Haida")),
    ("haj", _("Hajong")),
    ("hak", _("Hakka Chinese")),
    ("hal", _("Halang")),
    ("ham", _("Hewa")),
    ("han", _("Hangaza")),
    ("hao", _("Hakö")),
    ("hap", _("Hupla")),
    ("haq", _("Ha")),
    ("har", _("Harari")),
    ("has", _("Haisla")),
    ("hav", _("Havu")),
    ("haw", _("Hawaiian")),
    ("hax", _("Southern Haida")),
    ("hay", _("Haya")),
    ("haz", _("Hazaragi")),
    ("hba", _("Hamba")),
    ("hbb", _("Huba")),
    ("hbn", _("Heiban")),
    ("hbo", _("Ancient Hebrew")),
    ("hbu", _("Habu")),
    ("hca", _("Andaman Creole Hindi")),
    ("hch", _("Huichol")),
    ("hdn", _("Northern Haida")),
    ("hds", _("Honduras Sign Language")),
    ("hdy", _("Hadiyya")),
    ("hea", _("Northern Qiandong Miao")),
    ("hed", _("Herdé")),
    ("heg", _("Helong")),
    ("heh", _("Hehe")),
    ("hei", _("Heiltsuk")),
    ("hem", _("Hemba")),
    ("hgm", _("Haiǁom")),
    ("hgw", _("Haigwai")),
    ("hhi", _("Hoia Hoia")),
    ("hhr", _("Kerak")),
    ("hhy", _("Hoyahoya")),
    ("hia", _("Lamang")),
    ("hib", _("Hibito")),
    ("hid", _("Hidatsa")),
    ("hif", _("Fiji Hindi")),
    ("hig", _("Kamwe")),
    ("hih", _("Pamosu")),
    ("hii", _("Hinduri")),
    ("hij", _("Hijuk")),
    ("hik", _("Seit-Kaitetu")),
    ("hil", _("Hiligaynon")),
    ("him", _("Himachali languages")),
    ("hio", _("Tsoa")),
    ("hir", _("Himarimã")),
    ("hit", _("Hittite")),
    ("hiw", _("Hiw")),
    ("hix", _("Hixkaryána")),
    ("hji", _("Haji")),
    ("hka", _("Kahe")),
    ("hke", _("Hunde")),
    ("hkh", _("Khah")),
    ("hkk", _("Hunjara-Kaina Ke")),
    ("hkn", _("Mel-Khaonh")),
    ("hks", _("Hong Kong Sign Language")),
    ("hla", _("Halia")),
    ("hlb", _("Halbi")),
    ("hld", _("Halang Doan")),
    ("hle", _("Hlersu")),
    ("hlt", _("Matu Chin")),
    ("hlu", _("Hieroglyphic Luwian")),
    ("hma", _("Southern Mashan Hmong")),
    ("hmb", _("Humburi Senni Songhay")),
    ("hmc", _("Central Huishui Hmong")),
    ("hmd", _("Large Flowery Miao")),
    ("hme", _("Eastern Huishui Hmong")),
    ("hmf", _("Hmong Don")),
    ("hmg", _("Southwestern Guiyang Hmong")),
    ("hmh", _("Southwestern Huishui Hmong")),
    ("hmi", _("Northern Huishui Hmong")),
    ("hmj", _("Ge")),
    ("hmk", _("Maek")),
    ("hml", _("Luopohe Hmong")),
    ("hmm", _("Central Mashan Hmong")),
    ("hmn", _("Hmong")),
    ("hmp", _("Northern Mashan Hmong")),
    ("hmq", _("Eastern Qiandong Miao")),
    ("hmr", _("Hmar")),
    ("hms", _("Southern Qiandong Miao")),
    ("hmt", _("Hamtai")),
    ("hmu", _("Hamap")),
    ("hmv", _("Hmong Dô")),
    ("hmw", _("Western Mashan Hmong")),
    ("hmx", _("Hmong-Mien languages")),
    ("hmy", _("Southern Guiyang Hmong")),
    ("hmz", _("Hmong Shua")),
    ("hna", _("Mina")),
    ("hnd", _("Southern Hindko")),
    ("hne", _("Chhattisgarhi")),
    ("hng", _("Hungu")),
    ("hnh", _("ǁAni")),
    ("hni", _("Hani")),
    ("hnj", _("Hmong Njua")),
    ("hnn", _("Hanunoo")),
    ("hno", _("Northern Hindko")),
    ("hns", _("Caribbean Hindustani")),
    ("hnu", _("Hung")),
    ("hoa", _("Hoava")),
    ("hob", _("Mari")),
    ("hoc", _("Ho")),
    ("hod", _("Holma")),
    ("hoe", _("Horom")),
    ("hoh", _("Hobyót")),
    ("hoi", _("Holikachuk")),
    ("hoj", _("Hadothi")),
    ("hok", _("Hokan languages")),
    ("hol", _("Holu")),
    ("hom", _("Homa")),
    ("hoo", _("Holoholo")),
    ("hop", _("Hopi")),
    ("hor", _("Horo")),
    ("hos", _("Ho Chi Minh City Sign Language")),
    ("hot", _("Hote")),
    ("hov", _("Hovongan")),
    ("how", _("Honi")),
    ("hoy", _("Holiya")),
    ("hoz", _("Hozo")),
    ("hpo", _("Hpon")),
    ("hps", _("Hawai'i Sign Language")),
    ("hra", _("Hrangkhol")),
    ("hrc", _("Niwer Mil")),
    ("hre", _("Hre")),
    ("hrk", _("Haruku")),
    ("hrm", _("Horned Miao")),
    ("hro", _("Haroi")),
    ("hrp", _("Nhirrpi")),
    ("hrr", _("Horuru")),
    ("hrt", _("Hértevin")),
    ("hru", _("Hruso")),
    ("hrw", _("Warwar Feni")),
    ("hrx", _("Hunsrik")),
    ("hrz", _("Harzani")),
    ("hsb", _("Upper Sorbian")),
    ("hsh", _("Hungarian Sign Language")),
    ("hsl", _("Hausa Sign Language")),
    ("hsn", _("Xiang Chinese")),
    ("hss", _("Harsusi")),
    ("hti", _("Hoti")),
    ("hto", _("Minica Huitoto")),
    ("hts", _("Hadza")),
    ("htu", _("Hitu")),
    ("htx", _("Middle Hittite")),
    ("hub", _("Huambisa")),
    ("huc", _("ǂHua")),
    ("hud", _("Huaulu")),
    ("hue", _("San Francisco Del Mar Huave")),
    ("huf", _("Humene")),
    ("hug", _("Huachipaeri")),
    ("huh", _("Huilliche")),
    ("hui", _("Huli")),
    ("huj", _("Northern Guiyang Hmong")),
    ("huk", _("Hulung")),
    ("hul", _("Hula")),
    ("hum", _("Hungana")),
    ("huo", _("Hu")),
    ("hup", _("Hupa")),
    ("huq", _("Tsat")),
    ("hur", _("Halkomelem")),
    ("hus", _("Huastec")),
    ("hut", _("Humla")),
    ("huu", _("Murui Huitoto")),
    ("huv", _("San Mateo Del Mar Huave")),
    ("huw", _("Hukumina")),
    ("hux", _("Nüpode Huitoto")),
    ("huy", _("Hulaulá")),
    ("huz", _("Hunzib")),
    ("hvc", _("Haitian Vodoun Culture Language")),
    ("hve", _("San Dionisio Del Mar Huave")),
    ("hvk", _("Haveke")),
    ("hvn", _("Sabu")),
    ("hvv", _("Santa María Del Mar Huave")),
    ("hwa", _("Wané")),
    ("hwc", _("Hawai'i Creole English")),
    ("hwo", _("Hwana")),
    ("hya", _("Hya")),
    ("hyw", _("Western Armenian")),
    ("hyx", _("Armenian")),
    ("iai", _("Iaai")),
    ("ian", _("Iatmul")),
    ("iap", _("Iapama")),
    ("iar", _("Purari")),
    ("iba", _("Iban")),
    ("ibb", _("Ibibio")),
    ("ibd", _("Iwaidja")),
    ("ibe", _("Akpes")),
    ("ibg", _("Ibanag")),
    ("ibh", _("Bih")),
    ("ibi", _("Ibilo")),
    ("ibl", _("Ibaloi")),
    ("ibm", _("Agoi")),
    ("ibn", _("Ibino")),
    ("ibr", _("Ibuoro")),
    ("ibu", _("Ibu")),
    ("iby", _("Ibani")),
    ("ica", _("Ede Ica")),
    ("ich", _("Etkywan")),
    ("icl", _("Icelandic Sign Language")),
    ("icr", _("Islander Creole English")),
    ("ida", _("Idakho-Isukha-Tiriki")),
    ("idb", _("Indo-Portuguese")),
    ("idc", _("Idon")),
    ("idd", _("Ede Idaca")),
    ("ide", _("Idere")),
    ("idi", _("Idi")),
    ("idr", _("Indri")),
    ("ids", _("Idesa")),
    ("idt", _("Idaté")),
    ("idu", _("Idoma")),
    ("ifa", _("Amganad Ifugao")),
    ("ifb", _("Batad Ifugao")),
    ("ife", _("Ifè")),
    ("iff", _("Ifo")),
    ("ifk", _("Tuwali Ifugao")),
    ("ifm", _("Teke-Fuumu")),
    ("ifu", _("Mayoyao Ifugao")),
    ("ify", _("Keley-I Kallahan")),
    ("igb", _("Ebira")),
    ("ige", _("Igede")),
    ("igg", _("Igana")),
    ("igl", _("Igala")),
    ("igm", _("Kanggape")),
    ("ign", _("Ignaciano")),
    ("igo", _("Isebe")),
    ("igs", _("Interglossa")),
    ("igw", _("Igwe")),
    ("ihb", _("Iha Based Pidgin")),
    ("ihi", _("Ihievbe")),
    ("ihp", _("Iha")),
    ("ihw", _("Bidhawal")),
    ("iin", _("Thiin")),
    ("iir", _("Indo-Iranian languages")),
    ("ijc", _("Izon")),
    ("ije", _("Biseni")),
    ("ijj", _("Ede Ije")),
    ("ijn", _("Kalabari")),
    ("ijo", _("Ijo languages")),
    ("ijs", _("Southeast Ijo")),
    ("ike", _("Eastern Canadian Inuktitut")),
    ("iki", _("Iko")),
    ("ikk", _("Ika")),
    ("ikl", _("Ikulu")),
    ("iko", _("Olulumo-Ikom")),
    ("ikp", _("Ikpeshi")),
    ("ikr", _("Ikaranggal")),
    ("iks", _("Inuit Sign Language")),
    ("ikt", _("Inuinnaqtun")),
    ("ikv", _("Iku-Gora-Ankwa")),
    ("ikw", _("Ikwere")),
    ("ikx", _("Ik")),
    ("ikz", _("Ikizu")),
    ("ila", _("Ile Ape")),
    ("ilb", _("Ila")),
    ("ilg", _("Garig-Ilgar")),
    ("ili", _("Ili Turki")),
    ("ilk", _("Ilongot")),
    ("ill", _("Iranun")),
    ("ilm", _("Iranun")),
    ("ilo", _("Iloko")),
    ("ilp", _("Iranun")),
    ("ils", _("International Sign")),
    ("ilu", _("Ili'uun")),
    ("ilv", _("Ilue")),
    ("ilw", _("Talur")),
    ("ima", _("Mala Malasar")),
    ("ime", _("Imeraguen")),
    ("imi", _("Anamgura")),
    ("iml", _("Miluk")),
    ("imn", _("Imonda")),
    ("imo", _("Imbongu")),
    ("imr", _("Imroing")),
    ("ims", _("Marsian")),
    ("imy", _("Milyan")),
    ("inb", _("Inga")),
    ("inc", _("Indic languages")),
    ("ine", _("Indo-European languages")),
    ("ing", _("Degexit'an")),
    ("inh", _("Ingush")),
    ("inj", _("Jungle Inga")),
    ("inl", _("Indonesian Sign Language")),
    ("inm", _("Minaean")),
    ("inn", _("Isinai")),
    ("ino", _("Inoke-Yate")),
    ("inp", _("Iñapari")),
    ("ins", _("Indian Sign Language")),
    ("int", _("Intha")),
    ("inz", _("Ineseño")),
    ("ior", _("Inor")),
    ("iou", _("Tuma-Irumu")),
    ("iow", _("Iowa-Oto")),
    ("ipi", _("Ipili")),
    ("ipo", _("Ipiko")),
    ("iqu", _("Iquito")),
    ("iqw", _("Ikwo")),
    ("ira", _("Iranian languages")),
    ("ire", _("Iresim")),
    ("irh", _("Irarutu")),
    ("iri", _("Rigwe")),
    ("irk", _("Iraqw")),
    ("irn", _("Irántxe")),
    ("iro", _("Iroquoian languages")),
    ("irr", _("Ir")),
    ("iru", _("Irula")),
    ("irx", _("Kamberau")),
    ("iry", _("Iraya")),
    ("isa", _("Isabi")),
    ("isc", _("Isconahua")),
    ("isd", _("Isnag")),
    ("ise", _("Italian Sign Language")),
    ("isg", _("Irish Sign Language")),
    ("ish", _("Esan")),
    ("isi", _("Nkem-Nkum")),
    ("isk", _("Ishkashimi")),
    ("ism", _("Masimasi")),
    ("isn", _("Isanzu")),
    ("iso", _("Isoko")),
    ("isr", _("Israeli Sign Language")),
    ("ist", _("Istriot")),
    ("isu", _("Isu")),
    ("itb", _("Binongan Itneg")),
    ("itc", _("Italic languages")),
    ("itd", _("Southern Tidung")),
    ("ite", _("Itene")),
    ("iti", _("Inlaod Itneg")),
    ("itk", _("Judeo-Italian")),
    ("itl", _("Itelmen")),
    ("itm", _("Itu Mbon Uzo")),
    ("ito", _("Itonama")),
    ("itr", _("Iteri")),
    ("its", _("Isekiri")),
    ("itt", _("Maeng Itneg")),
    ("itv", _("Itawit")),
    ("itw", _("Ito")),
    ("itx", _("Itik")),
    ("ity", _("Moyadan Itneg")),
    ("itz", _("Itzá")),
    ("ium", _("Iu Mien")),
    ("ivb", _("Ibatan")),
    ("ivv", _("Ivatan")),
    ("iwk", _("I-Wak")),
    ("iwm", _("Iwam")),
    ("iwo", _("Iwur")),
    ("iws", _("Sepik Iwam")),
    ("ixc", _("Ixcatec")),
    ("ixl", _("Ixil")),
    ("iya", _("Iyayu")),
    ("iyo", _("Mesaka")),
    ("iyx", _("Yaka")),
    ("izh", _("Ingrian")),
    ("izi", _("Izi-Ezaa-Ikwo-Mgbo")),
    ("izr", _("Izere")),
    ("izz", _("Izii")),
    ("jaa", _("Jamamadí")),
    ("jab", _("Hyam")),
    ("jac", _("Popti'")),
    ("jad", _("Jahanka")),
    ("jae", _("Yabem")),
    ("jaf", _("Jara")),
    ("jah", _("Jah Hut")),
    ("jaj", _("Zazao")),
    ("jak", _("Jakun")),
    ("jal", _("Yalahatan")),
    ("jam", _("Jamaican Creole English")),
    ("jan", _("Jandai")),
    ("jao", _("Yanyuwa")),
    ("jaq", _("Yaqay")),
    ("jar", _("Jarawa")),
    ("jas", _("New Caledonian Javanese")),
    ("jat", _("Jakati")),
    ("jau", _("Yaur")),
    ("jax", _("Jambi Malay")),
    ("jay", _("Yan-nhangu")),
    ("jaz", _("Jawe")),
    ("jbe", _("Judeo-Berber")),
    ("jbi", _("Badjiri")),
    ("jbj", _("Arandai")),
    ("jbk", _("Barikewa")),
    ("jbm", _("Bijim")),
    ("jbn", _("Nafusi")),
    ("jbo", _("Lojban")),
    ("jbr", _("Jofotek-Bromnya")),
    ("jbt", _("Jabutí")),
    ("jbu", _("Jukun Takum")),
    ("jbw", _("Yawijibaya")),
    ("jcs", _("Jamaican Country Sign Language")),
    ("jct", _("Krymchak")),
    ("jda", _("Jad")),
    ("jdg", _("Jadgali")),
    ("jdt", _("Judeo-Tat")),
    ("jeb", _("Jebero")),
    ("jee", _("Jerung")),
    ("jeg", _("Jeng")),
    ("jeh", _("Jeh")),
    ("jei", _("Yei")),
    ("jek", _("Jeri Kuo")),
    ("jel", _("Yelmek")),
    ("jen", _("Dza")),
    ("jer", _("Jere")),
    ("jet", _("Manem")),
    ("jeu", _("Jonkor Bourmataguil")),
    ("jgb", _("Ngbee")),
    ("jge", _("Judeo-Georgian")),
    ("jgk", _("Gwak")),
    ("jgo", _("Ngomba")),
    ("jhi", _("Jehai")),
    ("jhs", _("Jhankot Sign Language")),
    ("jia", _("Jina")),
    ("jib", _("Jibu")),
    ("jic", _("Tol")),
    ("jid", _("Bu")),
    ("jie", _("Jilbe")),
    ("jig", _("Jingulu")),
    ("jih", _("sTodsde")),
    ("jii", _("Jiiddu")),
    ("jil", _("Jilim")),
    ("jim", _("Jimi")),
    ("jio", _("Jiamao")),
    ("jiq", _("Guanyinqiao")),
    ("jit", _("Jita")),
    ("jiu", _("Youle Jinuo")),
    ("jiv", _("Shuar")),
    ("jiy", _("Buyuan Jinuo")),
    ("jje", _("Jejueo")),
    ("jjr", _("Bankal")),
    ("jka", _("Kaera")),
    ("jkm", _("Mobwa Karen")),
    ("jko", _("Kubo")),
    ("jkp", _("Paku Karen")),
    ("jkr", _("Koro")),
    ("jks", _("Amami Koniya Sign Language")),
    ("jku", _("Labir")),
    ("jle", _("Ngile")),
    ("jls", _("Jamaican Sign Language")),
    ("jma", _("Dima")),
    ("jmb", _("Zumbun")),
    ("jmc", _("Machame")),
    ("jmd", _("Yamdena")),
    ("jmi", _("Jimi")),
    ("jml", _("Jumli")),
    ("jmn", _("Makuri Naga")),
    ("jmr", _("Kamara")),
    ("jms", _("Mashi")),
    ("jmw", _("Mouwase")),
    ("jmx", _("Western Juxtlahuaca Mixtec")),
    ("jna", _("Jangshung")),
    ("jnd", _("Jandavra")),
    ("jng", _("Yangman")),
    ("jni", _("Janji")),
    ("jnj", _("Yemsa")),
    ("jnl", _("Rawat")),
    ("jns", _("Jaunsari")),
    ("job", _("Joba")),
    ("jod", _("Wojenaka")),
    ("jog", _("Jogi")),
    ("jor", _("Jorá")),
    ("jos", _("Jordanian Sign Language")),
    ("jow", _("Jowulu")),
    ("jpa", _("Jewish Palestinian Aramaic")),
    ("jpr", _("Judeo-Persian")),
    ("jpx", _("Japanese")),
    ("jqr", _("Jaqaru")),
    ("jra", _("Jarai")),
    ("jrb", _("Judeo-Arabic")),
    ("jrr", _("Jiru")),
    ("jrt", _("Jakattoe")),
    ("jru", _("Japrería")),
    ("jsl", _("Japanese Sign Language")),
    ("jua", _("Júma")),
    ("jub", _("Wannu")),
    ("juc", _("Jurchen")),
    ("jud", _("Worodougou")),
    ("juh", _("Hõne")),
    ("jui", _("Ngadjuri")),
    ("juk", _("Wapan")),
    ("jul", _("Jirel")),
    ("jum", _("Jumjum")),
    ("jun", _("Juang")),
    ("juo", _("Jiba")),
    ("jup", _("Hupdë")),
    ("jur", _("Jurúna")),
    ("jus", _("Jumla Sign Language")),
    ("jut", _("Jutish")),
    ("juu", _("Ju")),
    ("juw", _("Wãpha")),
    ("juy", _("Juray")),
    ("jvd", _("Javindo")),
    ("jvn", _("Caribbean Javanese")),
    ("jwi", _("Jwira-Pepesa")),
    ("jya", _("Jiarong")),
    ("jye", _("Judeo-Yemeni Arabic")),
    ("jyy", _("Jaya")),
    ("kaa", _("Kara-Kalpak")),
    ("kab", _("Kabyle")),
    ("kac", _("Kachin")),
    ("kad", _("Adara")),
    ("kae", _("Ketangalan")),
    ("kaf", _("Katso")),
    ("kag", _("Kajaman")),
    ("kah", _("Kara")),
    ("kai", _("Karekare")),
    ("kaj", _("Jju")),
    ("kak", _("Kalanguya")),
    ("kam", _("Kamba")),
    ("kao", _("Xaasongaxango")),
    ("kap", _("Bezhta")),
    ("kaq", _("Capanahua")),
    ("kar", _("Karen languages")),
    ("kav", _("Katukína")),
    ("kaw", _("Kawi")),
    ("kax", _("Kao")),
    ("kay", _("Kamayurá")),
    ("kba", _("Kalarko")),
    ("kbb", _("Kaxuiâna")),
    ("kbc", _("Kadiwéu")),
    ("kbd", _("Kabardian")),
    ("kbe", _("Kanju")),
    ("kbf", _("Kakauhua")),
    ("kbg", _("Khamba")),
    ("kbh", _("Camsá")),
    ("kbi", _("Kaptiau")),
    ("kbj", _("Kari")),
    ("kbk", _("Grass Koiari")),
    ("kbl", _("Kanembu")),
    ("kbm", _("Iwal")),
    ("kbn", _("Kare")),
    ("kbo", _("Keliko")),
    ("kbp", _("Kabiyè")),
    ("kbq", _("Kamano")),
    ("kbr", _("Kafa")),
    ("kbs", _("Kande")),
    ("kbt", _("Abadi")),
    ("kbu", _("Kabutra")),
    ("kbv", _("Dera")),
    ("kbw", _("Kaiep")),
    ("kbx", _("Ap Ma")),
    ("kby", _("Manga Kanuri")),
    ("kbz", _("Duhwa")),
    ("kca", _("Khanty")),
    ("kcb", _("Kawacha")),
    ("kcc", _("Lubila")),
    ("kcd", _("Ngkâlmpw Kanum")),
    ("kce", _("Kaivi")),
    ("kcf", _("Ukaan")),
    ("kcg", _("Tyap")),
    ("kch", _("Vono")),
    ("kci", _("Kamantan")),
    ("kcj", _("Kobiana")),
    ("kck", _("Kalanga")),
    ("kcl", _("Kela")),
    ("kcm", _("Gula")),
    ("kcn", _("Nubi")),
    ("kco", _("Kinalakna")),
    ("kcp", _("Kanga")),
    ("kcq", _("Kamo")),
    ("kcr", _("Katla")),
    ("kcs", _("Koenoem")),
    ("kct", _("Kaian")),
    ("kcu", _("Kami")),
    ("kcv", _("Kete")),
    ("kcw", _("Kabwari")),
    ("kcx", _("Kachama-Ganjule")),
    ("kcy", _("Korandje")),
    ("kcz", _("Konongo")),
    ("kda", _("Worimi")),
    ("kdc", _("Kutu")),
    ("kdd", _("Yankunytjatjara")),
    ("kde", _("Makonde")),
    ("kdf", _("Mamusi")),
    ("kdg", _("Seba")),
    ("kdh", _("Tem")),
    ("kdi", _("Kumam")),
    ("kdj", _("Karamojong")),
    ("kdk", _("Numèè")),
    ("kdl", _("Tsikimba")),
    ("kdm", _("Kagoma")),
    ("kdn", _("Kunda")),
    ("kdo", _("Kordofanian languages")),
    ("kdp", _("Kaningdon-Nindem")),
    ("kdq", _("Koch")),
    ("kdr", _("Karaim")),
    ("kdt", _("Kuy")),
    ("kdu", _("Kadaru")),
    ("kdv", _("Kado")),
    ("kdw", _("Koneraw")),
    ("kdx", _("Kam")),
    ("kdy", _("Keder")),
    ("kdz", _("Kwaja")),
    ("kea", _("Kabuverdianu")),
    ("keb", _("Kélé")),
    ("kec", _("Keiga")),
    ("ked", _("Kerewe")),
    ("kee", _("Eastern Keres")),
    ("kef", _("Kpessi")),
    ("keg", _("Tese")),
    ("keh", _("Keak")),
    ("kei", _("Kei")),
    ("kej", _("Kadar")),
    ("kek", _("Kekchí")),
    ("kel", _("Kela")),
    ("kem", _("Kemak")),
    ("ken", _("Kenyang")),
    ("keo", _("Kakwa")),
    ("kep", _("Kaikadi")),
    ("keq", _("Kamar")),
    ("ker", _("Kera")),
    ("kes", _("Kugbo")),
    ("ket", _("Ket")),
    ("keu", _("Akebu")),
    ("kev", _("Kanikkaran")),
    ("kew", _("West Kewa")),
    ("kex", _("Kukna")),
    ("key", _("Kupia")),
    ("kez", _("Kukele")),
    ("kfa", _("Kodava")),
    ("kfb", _("Northwestern Kolami")),
    ("kfc", _("Konda-Dora")),
    ("kfd", _("Korra Koraga")),
    ("kfe", _("Kota")),
    ("kff", _("Koya")),
    ("kfg", _("Kudiya")),
    ("kfh", _("Kurichiya")),
    ("kfi", _("Kannada Kurumba")),
    ("kfj", _("Kemiehua")),
    ("kfk", _("Kinnauri")),
    ("kfl", _("Kung")),
    ("kfm", _("Khunsari")),
    ("kfn", _("Kuk")),
    ("kfo", _("Koro")),
    ("kfp", _("Korwa")),
    ("kfq", _("Korku")),
    ("kfr", _("Kachhi")),
    ("kfs", _("Bilaspuri")),
    ("kft", _("Kanjari")),
    ("kfu", _("Katkari")),
    ("kfv", _("Kurmukar")),
    ("kfw", _("Kharam Naga")),
    ("kfx", _("Kullu Pahari")),
    ("kfy", _("Kumaoni")),
    ("kfz", _("Koromfé")),
    ("kga", _("Koyaga")),
    ("kgb", _("Kawe")),
    ("kgc", _("Kasseng")),
    ("kgd", _("Kataang")),
    ("kge", _("Komering")),
    ("kgf", _("Kube")),
    ("kgg", _("Kusunda")),
    ("kgh", _("Upper Tanudan Kalinga")),
    ("kgi", _("Selangor Sign Language")),
    ("kgj", _("Gamale Kham")),
    ("kgk", _("Kaiwá")),
    ("kgl", _("Kunggari")),
    ("kgm", _("Karipúna")),
    ("kgn", _("Karingani")),
    ("kgo", _("Krongo")),
    ("kgp", _("Kaingang")),
    ("kgq", _("Kamoro")),
    ("kgr", _("Abun")),
    ("kgs", _("Kumbainggar")),
    ("kgt", _("Somyev")),
    ("kgu", _("Kobol")),
    ("kgv", _("Karas")),
    ("kgw", _("Karon Dori")),
    ("kgx", _("Kamaru")),
    ("kgy", _("Kyerung")),
    ("kha", _("Khasi")),
    ("khb", _("Lü")),
    ("khc", _("Tukang Besi North")),
    ("khd", _("Bädi Kanum")),
    ("khe", _("Korowai")),
    ("khf", _("Khuen")),
    ("khg", _("Khams Tibetan")),
    ("khh", _("Kehu")),
    ("khi", _("Khoisan languages")),
    ("khj", _("Kuturmi")),
    ("khk", _("Halh Mongolian")),
    ("khl", _("Lusi")),
    ("khn", _("Khandesi")),
    ("kho", _("Khotanese")),
    ("khp", _("Kapori")),
    ("khq", _("Koyra Chiini Songhay")),
    ("khr", _("Kharia")),
    ("khs", _("Kasua")),
    ("kht", _("Khamti")),
    ("khu", _("Nkhumbi")),
    ("khv", _("Khvarshi")),
    ("khw", _("Khowar")),
    ("khx", _("Kanu")),
    ("khy", _("Kele")),
    ("khz", _("Keapara")),
    ("kia", _("Kim")),
    ("kib", _("Koalib")),
    ("kic", _("Kickapoo")),
    ("kid", _("Koshin")),
    ("kie", _("Kibet")),
    ("kif", _("Eastern Parbate Kham")),
    ("kig", _("Kimaama")),
    ("kih", _("Kilmeri")),
    ("kii", _("Kitsai")),
    ("kij", _("Kilivila")),
    ("kil", _("Kariya")),
    ("kim", _("Karagas")),
    ("kio", _("Kiowa")),
    ("kip", _("Sheshi Kham")),
    ("kiq", _("Kosadle")),
    ("kis", _("Kis")),
    ("kit", _("Agob")),
    ("kiu", _("Kirmanjki")),
    ("kiv", _("Kimbu")),
    ("kiw", _("Northeast Kiwai")),
    ("kix", _("Khiamniungan Naga")),
    ("kiy", _("Kirikiri")),
    ("kiz", _("Kisi")),
    ("kja", _("Mlap")),
    ("kjb", _("Q'anjob'al")),
    ("kjc", _("Coastal Konjo")),
    ("kjd", _("Southern Kiwai")),
    ("kje", _("Kisar")),
    ("kjf", _("Khalaj [Indo-Iranian]")),
    ("kjg", _("Khmu")),
    ("kjh", _("Khakas")),
    ("kji", _("Zabana")),
    ("kjj", _("Khinalugh")),
    ("kjk", _("Highland Konjo")),
    ("kjl", _("Western Parbate Kham")),
    ("kjm", _("Kháng")),
    ("kjn", _("Kunjen")),
    ("kjo", _("Harijan Kinnauri")),
    ("kjp", _("Pwo Eastern Karen")),
    ("kjq", _("Western Keres")),
    ("kjr", _("Kurudu")),
    ("kjs", _("East Kewa")),
    ("kjt", _("Phrae Pwo Karen")),
    ("kju", _("Kashaya")),
    ("kjv", _("Kaikavian Literary Language")),
    ("kjx", _("Ramopa")),
    ("kjy", _("Erave")),
    ("kjz", _("Bumthangkha")),
    ("kka", _("Kakanda")),
    ("kkb", _("Kwerisa")),
    ("kkc", _("Odoodee")),
    ("kkd", _("Kinuku")),
    ("kke", _("Kakabe")),
    ("kkf", _("Kalaktang Monpa")),
    ("kkg", _("Mabaka Valley Kalinga")),
    ("kkh", _("Khün")),
    ("kki", _("Kagulu")),
    ("kkj", _("Kako")),
    ("kkk", _("Kokota")),
    ("kkl", _("Kosarek Yale")),
    ("kkm", _("Kiong")),
    ("kkn", _("Kon Keu")),
    ("kko", _("Karko")),
    ("kkp", _("Gugubera")),
    ("kkq", _("Kaeku")),
    ("kkr", _("Kir-Balar")),
    ("kks", _("Giiwo")),
    ("kkt", _("Koi")),
    ("kku", _("Tumi")),
    ("kkv", _("Kangean")),
    ("kkw", _("Teke-Kukuya")),
    ("kkx", _("Kohin")),
    ("kky", _("Guugu Yimidhirr")),
    ("kkz", _("Kaska")),
    ("kla", _("Klamath-Modoc")),
    ("klb", _("Kiliwa")),
    ("klc", _("Kolbila")),
    ("kld", _("Gamilaraay")),
    ("kle", _("Kulung")),
    ("klf", _("Kendeje")),
    ("klg", _("Tagakaulo")),
    ("klh", _("Weliki")),
    ("kli", _("Kalumpang")),
    ("klj", _("Khalaj")),
    ("klk", _("Kono")),
    ("kll", _("Kagan Kalagan")),
    ("klm", _("Migum")),
    ("kln", _("Kalenjin")),
    ("klo", _("Kapya")),
    ("klp", _("Kamasa")),
    ("klq", _("Rumu")),
    ("klr", _("Khaling")),
    ("kls", _("Kalasha")),
    ("klt", _("Nukna")),
    ("klu", _("Klao")),
    ("klv", _("Maskelynes")),
    ("klw", _("Tado")),
    ("klx", _("Koluwawa")),
    ("kly", _("Kalao")),
    ("klz", _("Kabola")),
    ("kma", _("Konni")),
    ("kmb", _("Kimbundu")),
    ("kmc", _("Southern Dong")),
    ("kmd", _("Majukayang Kalinga")),
    ("kme", _("Bakole")),
    ("kmf", _("Kare")),
    ("kmg", _("Kâte")),
    ("kmh", _("Kalam")),
    ("kmi", _("Kami")),
    ("kmj", _("Kumarbhag Paharia")),
    ("kmk", _("Limos Kalinga")),
    ("kml", _("Tanudan Kalinga")),
    ("kmm", _("Kom")),
    ("kmn", _("Awtuw")),
    ("kmo", _("Kwoma")),
    ("kmp", _("Gimme")),
    ("kmq", _("Kwama")),
    ("kmr", _("Northern Kurdish")),
    ("kms", _("Kamasau")),
    ("kmt", _("Kemtuik")),
    ("kmu", _("Kanite")),
    ("kmv", _("Karipúna Creole French")),
    ("kmw", _("Komo")),
    ("kmx", _("Waboda")),
    ("kmy", _("Koma")),
    ("kmz", _("Khorasani Turkish")),
    ("kna", _("Dera")),
    ("knb", _("Lubuagan Kalinga")),
    ("knc", _("Central Kanuri")),
    ("knd", _("Konda")),
    ("kne", _("Kankanaey")),
    ("knf", _("Mankanya")),
    ("kng", _("Koongo")),
    ("kni", _("Kanufi")),
    ("knj", _("Western Kanjobal")),
    ("knk", _("Kuranko")),
    ("knl", _("Keninjal")),
    ("knm", _("Kanamarí")),
    ("knn", _("Konkani")),
    ("kno", _("Kono")),
    ("knp", _("Kwanja")),
    ("knq", _("Kintaq")),
    ("knr", _("Kaningra")),
    ("kns", _("Kensiu")),
    ("knt", _("Panoan Katukína")),
    ("knu", _("Kono")),
    ("knv", _("Tabo")),
    ("knw", _("Kung-Ekoka")),
    ("knx", _("Kendayan")),
    ("kny", _("Kanyok")),
    ("knz", _("Kalamsé")),
    ("koa", _("Konomala")),
    ("koc", _("Kpati")),
    ("kod", _("Kodi")),
    ("koe", _("Kacipo-Bale Suri")),
    ("kof", _("Kubi")),
    ("kog", _("Cogui")),
    ("koh", _("Koyo")),
    ("koi", _("Komi-Permyak")),
    ("koj", _("Sara Dunjo")),
    ("kok", _("Konkani")),
    ("kol", _("Kol")),
    ("koo", _("Konzo")),
    ("kop", _("Waube")),
    ("koq", _("Kota")),
    ("kos", _("Kosraean")),
    ("kot", _("Lagwan")),
    ("kou", _("Koke")),
    ("kov", _("Kudu-Camo")),
    ("kow", _("Kugama")),
    ("kox", _("Coxima")),
    ("koy", _("Koyukon")),
    ("koz", _("Korak")),
    ("kpa", _("Kutto")),
    ("kpb", _("Mullu Kurumba")),
    ("kpc", _("Curripaco")),
    ("kpd", _("Koba")),
    ("kpe", _("Kpelle")),
    ("kpf", _("Komba")),
    ("kpg", _("Kapingamarangi")),
    ("kph", _("Kplang")),
    ("kpi", _("Kofei")),
    ("kpj", _("Karajá")),
    ("kpk", _("Kpan")),
    ("kpl", _("Kpala")),
    ("kpm", _("Koho")),
    ("kpn", _("Kepkiriwát")),
    ("kpo", _("Ikposo")),
    ("kpp", _("Paku Karen")),
    ("kpq", _("Korupun-Sela")),
    ("kpr", _("Korafe-Yegha")),
    ("kps", _("Tehit")),
    ("kpt", _("Karata")),
    ("kpu", _("Kafoa")),
    ("kpv", _("Komi-Zyrian")),
    ("kpw", _("Kobon")),
    ("kpx", _("Mountain Koiali")),
    ("kpy", _("Koryak")),
    ("kpz", _("Kupsabiny")),
    ("kqa", _("Mum")),
    ("kqb", _("Kovai")),
    ("kqc", _("Doromu-Koki")),
    ("kqd", _("Koy Sanjaq Surat")),
    ("kqe", _("Kalagan")),
    ("kqf", _("Kakabai")),
    ("kqg", _("Khe")),
    ("kqh", _("Kisankasa")),
    ("kqi", _("Koitabu")),
    ("kqj", _("Koromira")),
    ("kqk", _("Kotafon Gbe")),
    ("kql", _("Kyenele")),
    ("kqm", _("Khisa")),
    ("kqn", _("Kaonde")),
    ("kqo", _("Eastern Krahn")),
    ("kqp", _("Kimré")),
    ("kqq", _("Krenak")),
    ("kqr", _("Kimaragang")),
    ("kqs", _("Northern Kissi")),
    ("kqt", _("Klias River Kadazan")),
    ("kqu", _("Seroa")),
    ("kqv", _("Okolod")),
    ("kqw", _("Kandas")),
    ("kqx", _("Mser")),
    ("kqy", _("Koorete")),
    ("kqz", _("Korana")),
    ("kra", _("Kumhali")),
    ("krb", _("Karkin")),
    ("krc", _("Karachay-Balkar")),
    ("krd", _("Kairui-Midiki")),
    ("kre", _("Panará")),
    ("krf", _("Koro")),
    ("krh", _("Kurama")),
    ("kri", _("Krio")),
    ("krj", _("Kinaray-A")),
    ("krk", _("Kerek")),
    ("krl", _("Karelian")),
    ("krm", _("Krim")),
    ("krn", _("Sapo")),
    ("kro", _("Kru languages")),
    ("krp", _("Korop")),
    ("krr", _("Krung")),
    ("krs", _("Gbaya")),
    ("krt", _("Tumari Kanuri")),
    ("kru", _("Kurukh")),
    ("krv", _("Kavet")),
    ("krw", _("Western Krahn")),
    ("krx", _("Karon")),
    ("kry", _("Kryts")),
    ("krz", _("Sota Kanum")),
    ("ksa", _("Shuwa-Zamani")),
    ("ksb", _("Shambala")),
    ("ksc", _("Southern Kalinga")),
    ("ksd", _("Kuanua")),
    ("kse", _("Kuni")),
    ("ksf", _("Bafia")),
    ("ksg", _("Kusaghe")),
    ("ksh", _("Kölsch")),
    ("ksi", _("Krisa")),
    ("ksj", _("Uare")),
    ("ksk", _("Kansa")),
    ("ksl", _("Kumalu")),
    ("ksm", _("Kumba")),
    ("ksn", _("Kasiguranin")),
    ("kso", _("Kofa")),
    ("ksp", _("Kaba")),
    ("ksq", _("Kwaami")),
    ("ksr", _("Borong")),
    ("kss", _("Southern Kisi")),
    ("kst", _("Winyé")),
    ("ksu", _("Khamyang")),
    ("ksv", _("Kusu")),
    ("ksw", _("S'gaw Karen")),
    ("ksx", _("Kedang")),
    ("ksy", _("Kharia Thar")),
    ("ksz", _("Kodaku")),
    ("kta", _("Katua")),
    ("ktb", _("Kambaata")),
    ("ktc", _("Kholok")),
    ("ktd", _("Kokata")),
    ("kte", _("Nubri")),
    ("ktf", _("Kwami")),
    ("ktg", _("Kalkutung")),
    ("kth", _("Karanga")),
    ("kti", _("North Muyu")),
    ("ktj", _("Plapo Krumen")),
    ("ktk", _("Kaniet")),
    ("ktl", _("Koroshi")),
    ("ktm", _("Kurti")),
    ("ktn", _("Karitiâna")),
    ("kto", _("Kuot")),
    ("ktp", _("Kaduo")),
    ("ktq", _("Katabaga")),
    ("ktr", _("Kota Marudu Tinagas")),
    ("kts", _("South Muyu")),
    ("ktt", _("Ketum")),
    ("ktu", _("Kituba")),
    ("ktv", _("Eastern Katu")),
    ("ktw", _("Kato")),
    ("ktx", _("Kaxararí")),
    ("kty", _("Kango")),
    ("ktz", _("Juǀʼhoan")),
    ("kub", _("Kutep")),
    ("kuc", _("Kwinsu")),
    ("kud", _("'Auhelawa")),
    ("kue", _("Kuman")),
    ("kuf", _("Western Katu")),
    ("kug", _("Kupa")),
    ("kuh", _("Kushi")),
    ("kui", _("Kuikúro-Kalapálo")),
    ("kuj", _("Kuria")),
    ("kuk", _("Kepo'")),
    ("kul", _("Kulere")),
    ("kum", _("Kumyk")),
    ("kun", _("Kunama")),
    ("kuo", _("Kumukio")),
    ("kup", _("Kunimaipa")),
    ("kuq", _("Karipuna")),
    ("kus", _("Kusaal")),
    ("kut", _("Kutenai")),
    ("kuu", _("Upper Kuskokwim")),
    ("kuv", _("Kur")),
    ("kuw", _("Kpagua")),
    ("kux", _("Kukatja")),
    ("kuy", _("Kuuku-Ya'u")),
    ("kuz", _("Kunza")),
    ("kva", _("Bagvalal")),
    ("kvb", _("Kubu")),
    ("kvc", _("Kove")),
    ("kvd", _("Kui")),
    ("kve", _("Kalabakan")),
    ("kvf", _("Kabalai")),
    ("kvg", _("Kuni-Boazi")),
    ("kvh", _("Komodo")),
    ("kvi", _("Kwang")),
    ("kvj", _("Psikye")),
    ("kvk", _("Korean Sign Language")),
    ("kvl", _("Kayaw")),
    ("kvm", _("Kendem")),
    ("kvn", _("Border Kuna")),
    ("kvo", _("Dobel")),
    ("kvp", _("Kompane")),
    ("kvq", _("Geba Karen")),
    ("kvr", _("Kerinci")),
    ("kvs", _("Kunggara")),
    ("kvt", _("Lahta Karen")),
    ("kvu", _("Yinbaw Karen")),
    ("kvv", _("Kola")),
    ("kvw", _("Wersing")),
    ("kvx", _("Parkari Koli")),
    ("kvy", _("Yintale Karen")),
    ("kvz", _("Tsakwambo")),
    ("kwa", _("Dâw")),
    ("kwb", _("Kwa")),
    ("kwc", _("Likwala")),
    ("kwd", _("Kwaio")),
    ("kwe", _("Kwerba")),
    ("kwf", _("Kwara'ae")),
    ("kwg", _("Sara Kaba Deme")),
    ("kwh", _("Kowiai")),
    ("kwi", _("Awa-Cuaiquer")),
    ("kwj", _("Kwanga")),
    ("kwk", _("Kwakiutl")),
    ("kwl", _("Kofyar")),
    ("kwm", _("Kwambi")),
    ("kwn", _("Kwangali")),
    ("kwo", _("Kwomtari")),
    ("kwp", _("Kodia")),
    ("kwq", _("Kwak")),
    ("kwr", _("Kwer")),
    ("kws", _("Kwese")),
    ("kwt", _("Kwesten")),
    ("kwu", _("Kwakum")),
    ("kwv", _("Sara Kaba Náà")),
    ("kww", _("Kwinti")),
    ("kwx", _("Khirwar")),
    ("kwy", _("San Salvador Kongo")),
    ("kwz", _("Kwadi")),
    ("kxa", _("Kairiru")),
    ("kxb", _("Krobu")),
    ("kxc", _("Konso")),
    ("kxd", _("Brunei")),
    ("kxe", _("Kakihum")),
    ("kxf", _("Manumanaw Karen")),
    ("kxh", _("Karo")),
    ("kxi", _("Keningau Murut")),
    ("kxj", _("Kulfa")),
    ("kxk", _("Zayein Karen")),
    ("kxl", _("Nepali Kurux")),
    ("kxm", _("Northern Khmer")),
    ("kxn", _("Kanowit-Tanjong Melanau")),
    ("kxo", _("Kanoé")),
    ("kxp", _("Wadiyara Koli")),
    ("kxq", _("Smärky Kanum")),
    ("kxr", _("Koro")),
    ("kxs", _("Kangjia")),
    ("kxt", _("Koiwat")),
    ("kxu", _("Kui")),
    ("kxv", _("Kuvi")),
    ("kxw", _("Konai")),
    ("kxx", _("Likuba")),
    ("kxy", _("Kayong")),
    ("kxz", _("Kerewo")),
    ("kya", _("Kwaya")),
    ("kyb", _("Butbut Kalinga")),
    ("kyc", _("Kyaka")),
    ("kyd", _("Karey")),
    ("kye", _("Krache")),
    ("kyf", _("Kouya")),
    ("kyg", _("Keyagana")),
    ("kyh", _("Karok")),
    ("kyi", _("Kiput")),
    ("kyj", _("Karao")),
    ("kyk", _("Kamayo")),
    ("kyl", _("Kalapuya")),
    ("kym", _("Kpatili")),
    ("kyn", _("Northern Binukidnon")),
    ("kyo", _("Kelon")),
    ("kyp", _("Kang")),
    ("kyq", _("Kenga")),
    ("kyr", _("Kuruáya")),
    ("kys", _("Baram Kayan")),
    ("kyt", _("Kayagar")),
    ("kyu", _("Western Kayah")),
    ("kyv", _("Kayort")),
    ("kyw", _("Kudmali")),
    ("kyx", _("Rapoisi")),
    ("kyy", _("Kambaira")),
    ("kyz", _("Kayabí")),
    ("kza", _("Western Karaboro")),
    ("kzb", _("Kaibobo")),
    ("kzc", _("Bondoukou Kulango")),
    ("kzd", _("Kadai")),
    ("kze", _("Kosena")),
    ("kzf", _("Da'a Kaili")),
    ("kzg", _("Kikai")),
    ("kzh", _("Kenuzi-Dongola")),
    ("kzi", _("Kelabit")),
    ("kzj", _("Coastal Kadazan")),
    ("kzk", _("Kazukuru")),
    ("kzl", _("Kayeli")),
    ("kzm", _("Kais")),
    ("kzn", _("Kokola")),
    ("kzo", _("Kaningi")),
    ("kzp", _("Kaidipang")),
    ("kzq", _("Kaike")),
    ("kzr", _("Karang")),
    ("kzs", _("Sugut Dusun")),
    ("kzt", _("Tambunan Dusun")),
    ("kzu", _("Kayupulau")),
    ("kzv", _("Komyandaret")),
    ("kzw", _("Karirí-Xocó")),
    ("kzx", _("Kamarian")),
    ("kzy", _("Kango")),
    ("kzz", _("Kalabra")),
    ("laa", _("Southern Subanen")),
    ("lab", _("Linear A")),
    ("lac", _("Lacandon")),
    ("lad", _("Ladino")),
    ("lae", _("Pattani")),
    ("laf", _("Lafofa")),
    ("lag", _("Langi")),
    ("lah", _("Lahnda")),
    ("lai", _("Lambya")),
    ("laj", _("Lango")),
    ("lak", _("Laka")),
    ("lal", _("Lalia")),
    ("lam", _("Lamba")),
    ("lan", _("Laru")),
    ("lap", _("Laka")),
    ("laq", _("Qabiao")),
    ("lar", _("Larteh")),
    ("las", _("Lama")),
    ("lau", _("Laba")),
    ("law", _("Lauje")),
    ("lax", _("Tiwa")),
    ("lay", _("Lama Bai")),
    ("laz", _("Aribwatsa")),
    ("lba", _("Lui")),
    ("lbb", _("Label")),
    ("lbc", _("Lakkia")),
    ("lbe", _("Lak")),
    ("lbf", _("Tinani")),
    ("lbg", _("Laopang")),
    ("lbi", _("La'bi")),
    ("lbj", _("Ladakhi")),
    ("lbk", _("Central Bontok")),
    ("lbl", _("Libon Bikol")),
    ("lbm", _("Lodhi")),
    ("lbn", _("Rmeet")),
    ("lbo", _("Laven")),
    ("lbq", _("Wampar")),
    ("lbr", _("Lohorung")),
    ("lbs", _("Libyan Sign Language")),
    ("lbt", _("Lachi")),
    ("lbu", _("Labu")),
    ("lbv", _("Lavatbura-Lamusong")),
    ("lbw", _("Tolaki")),
    ("lbx", _("Lawangan")),
    ("lby", _("Lamalama")),
    ("lbz", _("Lardil")),
    ("lcc", _("Legenyem")),
    ("lcd", _("Lola")),
    ("lce", _("Loncong")),
    ("lcf", _("Lubu")),
    ("lch", _("Luchazi")),
    ("lcl", _("Lisela")),
    ("lcm", _("Tungag")),
    ("lcp", _("Western Lawa")),
    ("lcq", _("Luhu")),
    ("lcs", _("Lisabata-Nuniali")),
    ("lda", _("Kla-Dan")),
    ("ldb", _("Dũya")),
    ("ldd", _("Luri")),
    ("ldg", _("Lenyima")),
    ("ldh", _("Lamja-Dengsa-Tola")),
    ("ldi", _("Laari")),
    ("ldj", _("Lemoro")),
    ("ldk", _("Leelau")),
    ("ldl", _("Kaan")),
    ("ldm", _("Landoma")),
    ("ldn", _("Láadan")),
    ("ldo", _("Loo")),
    ("ldp", _("Tso")),
    ("ldq", _("Lufu")),
    ("lea", _("Lega-Shabunda")),
    ("leb", _("Lala-Bisa")),
    ("lec", _("Leco")),
    ("led", _("Lendu")),
    ("lee", _("Lyélé")),
    ("lef", _("Lelemi")),
    ("leg", _("Lengua")),
    ("leh", _("Lenje")),
    ("lei", _("Lemio")),
    ("lej", _("Lengola")),
    ("lek", _("Leipon")),
    ("lel", _("Lele")),
    ("lem", _("Nomaande")),
    ("len", _("Lenca")),
    ("leo", _("Leti")),
    ("lep", _("Lepcha")),
    ("leq", _("Lembena")),
    ("ler", _("Lenkau")),
    ("les", _("Lese")),
    ("let", _("Lesing-Gelimi")),
    ("leu", _("Kara")),
    ("lev", _("Lamma")),
    ("lew", _("Ledo Kaili")),
    ("lex", _("Luang")),
    ("ley", _("Lemolang")),
    ("lez", _("Lezghian")),
    ("lfa", _("Lefa")),
    ("lfn", _("Lingua Franca Nova")),
    ("lga", _("Lungga")),
    ("lgb", _("Laghu")),
    ("lgg", _("Lugbara")),
    ("lgh", _("Laghuu")),
    ("lgi", _("Lengilu")),
    ("lgk", _("Lingarak")),
    ("lgl", _("Wala")),
    ("lgm", _("Lega-Mwenga")),
    ("lgn", _("T'apo")),
    ("lgq", _("Logba")),
    ("lgr", _("Lengo")),
    ("lgt", _("Pahi")),
    ("lgu", _("Longgu")),
    ("lgz", _("Ligenza")),
    ("lha", _("Laha")),
    ("lhh", _("Laha")),
    ("lhi", _("Lahu Shi")),
    ("lhl", _("Lahul Lohar")),
    ("lhm", _("Lhomi")),
    ("lhn", _("Lahanan")),
    ("lhp", _("Lhokpu")),
    ("lhs", _("Mlahsö")),
    ("lht", _("Lo-Toga")),
    ("lhu", _("Lahu")),
    ("lia", _("West-Central Limba")),
    ("lib", _("Likum")),
    ("lic", _("Hlai")),
    ("lid", _("Nyindrou")),
    ("lie", _("Likila")),
    ("lif", _("Limbu")),
    ("lig", _("Ligbi")),
    ("lih", _("Lihir")),
    ("lii", _("Lingkhim")),
    ("lij", _("Ligurian")),
    ("lik", _("Lika")),
    ("lil", _("Lillooet")),
    ("lio", _("Liki")),
    ("lip", _("Sekpele")),
    ("liq", _("Libido")),
    ("lir", _("Liberian English")),
    ("lis", _("Lisu")),
    ("liu", _("Logorik")),
    ("liv", _("Liv")),
    ("liw", _("Col")),
    ("lix", _("Liabuku")),
    ("liy", _("Banda-Bambari")),
    ("liz", _("Libinza")),
    ("lja", _("Golpa")),
    ("lje", _("Rampi")),
    ("lji", _("Laiyolo")),
    ("ljl", _("Li'o")),
    ("ljp", _("Lampung Api")),
    ("ljw", _("Yirandali")),
    ("ljx", _("Yuru")),
    ("lka", _("Lakalei")),
    ("lkb", _("Kabras")),
    ("lkc", _("Kucong")),
    ("lkd", _("Lakondê")),
    ("lke", _("Kenyi")),
    ("lkh", _("Lakha")),
    ("lki", _("Laki")),
    ("lkj", _("Remun")),
    ("lkl", _("Laeko-Libuat")),
    ("lkm", _("Kalaamaya")),
    ("lkn", _("Lakon")),
    ("lko", _("Khayo")),
    ("lkr", _("Päri")),
    ("lks", _("Kisa")),
    ("lkt", _("Lakota")),
    ("lku", _("Kungkari")),
    ("lky", _("Lokoya")),
    ("lla", _("Lala-Roba")),
    ("llb", _("Lolo")),
    ("llc", _("Lele")),
    ("lld", _("Ladin")),
    ("lle", _("Lele")),
    ("llf", _("Hermit")),
    ("llg", _("Lole")),
    ("llh", _("Lamu")),
    ("lli", _("Teke-Laali")),
    ("llj", _("Ladji Ladji")),
    ("llk", _("Lelak")),
    ("lll", _("Lilau")),
    ("llm", _("Lasalimu")),
    ("lln", _("Lele")),
    ("llo", _("Khlor")),
    ("llp", _("North Efate")),
    ("llq", _("Lolak")),
    ("lls", _("Lithuanian Sign Language")),
    ("llu", _("Lau")),
    ("llx", _("Lauan")),
    ("lma", _("East Limba")),
    ("lmb", _("Merei")),
    ("lmc", _("Limilngan")),
    ("lmd", _("Lumun")),
    ("lme", _("Pévé")),
    ("lmf", _("South Lembata")),
    ("lmg", _("Lamogai")),
    ("lmh", _("Lambichhong")),
    ("lmi", _("Lombi")),
    ("lmj", _("West Lembata")),
    ("lmk", _("Lamkang")),
    ("lml", _("Hano")),
    ("lmm", _("Lamam")),
    ("lmn", _("Lambadi")),
    ("lmo", _("Lombard")),
    ("lmp", _("Limbum")),
    ("lmq", _("Lamatuka")),
    ("lmr", _("Lamalera")),
    ("lmu", _("Lamenu")),
    ("lmv", _("Lomaiviti")),
    ("lmw", _("Lake Miwok")),
    ("lmx", _("Laimbue")),
    ("lmy", _("Lamboya")),
    ("lmz", _("Lumbee")),
    ("lna", _("Langbashe")),
    ("lnb", _("Mbalanhu")),
    ("lnd", _("Lundayeh")),
    ("lng", _("Langobardic")),
    ("lnh", _("Lanoh")),
    ("lni", _("Daantanai'")),
    ("lnj", _("Leningitij")),
    ("lnl", _("South Central Banda")),
    ("lnm", _("Langam")),
    ("lnn", _("Lorediakarkar")),
    ("lno", _("Lango")),
    ("lns", _("Lamnso'")),
    ("lnu", _("Longuda")),
    ("lnw", _("Lanima")),
    ("lnz", _("Lonzo")),
    ("loa", _("Loloda")),
    ("lob", _("Lobi")),
    ("loc", _("Inonhan")),
    ("loe", _("Saluan")),
    ("lof", _("Logol")),
    ("log", _("Logo")),
    ("loh", _("Narim")),
    ("loi", _("Loma")),
    ("loj", _("Lou")),
    ("lok", _("Loko")),
    ("lol", _("Mongo")),
    ("lom", _("Loma")),
    ("lon", _("Malawi Lomwe")),
    ("loo", _("Lombo")),
    ("lop", _("Lopa")),
    ("loq", _("Lobala")),
    ("lor", _("Téén")),
    ("los", _("Loniu")),
    ("lot", _("Otuho")),
    ("lou", _("Louisiana Creole")),
    ("lov", _("Lopi")),
    ("low", _("Tampias Lobu")),
    ("lox", _("Loun")),
    ("loy", _("Loke")),
    ("loz", _("Lozi")),
    ("lpa", _("Lelepa")),
    ("lpe", _("Lepki")),
    ("lpn", _("Long Phuri Naga")),
    ("lpo", _("Lipo")),
    ("lpx", _("Lopit")),
    ("lra", _("Rara Bakati'")),
    ("lrc", _("Northern Luri")),
    ("lre", _("Laurentian")),
    ("lrg", _("Laragia")),
    ("lri", _("Marachi")),
    ("lrk", _("Loarki")),
    ("lrl", _("Lari")),
    ("lrm", _("Marama")),
    ("lrn", _("Lorang")),
    ("lro", _("Laro")),
    ("lrr", _("Southern Yamphu")),
    ("lrt", _("Larantuka Malay")),
    ("lrv", _("Larevat")),
    ("lrz", _("Lemerig")),
    ("lsa", _("Lasgerdi")),
    ("lsb", _("Burundian Sign Language")),
    ("lsd", _("Lishana Deni")),
    ("lse", _("Lusengo")),
    ("lsg", _("Lyons Sign Language")),
    ("lsh", _("Lish")),
    ("lsi", _("Lashi")),
    ("lsl", _("Latvian Sign Language")),
    ("lsm", _("Saamia")),
    ("lsn", _("Tibetan Sign Language")),
    ("lso", _("Laos Sign Language")),
    ("lsp", _("Panamanian Sign Language")),
    ("lsr", _("Aruop")),
    ("lss", _("Lasi")),
    ("lst", _("Trinidad and Tobago Sign Language")),
    ("lsv", _("Sivia Sign Language")),
    ("lsy", _("Mauritian Sign Language")),
    ("ltc", _("Late Middle Chinese")),
    ("ltg", _("Latgalian")),
    ("lth", _("Thur")),
    ("lti", _("Leti")),
    ("ltn", _("Latundê")),
    ("lto", _("Tsotso")),
    ("lts", _("Tachoni")),
    ("ltu", _("Latu")),
    ("lua", _("Luba-Lulua")),
    ("luc", _("Aringa")),
    ("lud", _("Ludian")),
    ("lue", _("Luvale")),
    ("luf", _("Laua")),
    ("lui", _("Luiseno")),
    ("luj", _("Luna")),
    ("luk", _("Lunanakha")),
    ("lul", _("Olu'bo")),
    ("lum", _("Luimbi")),
    ("lun", _("Lunda")),
    ("luo", _("Luo")),
    ("lup", _("Lumbu")),
    ("luq", _("Lucumi")),
    ("lur", _("Laura")),
    ("lus", _("Lushai")),
    ("lut", _("Lushootseed")),
    ("luu", _("Lumba-Yakkha")),
    ("luv", _("Luwati")),
    ("luw", _("Luo")),
    ("luy", _("Luyia")),
    ("luz", _("Southern Luri")),
    ("lva", _("Maku'a")),
    ("lvi", _("Lavi")),
    ("lvk", _("Lavukaleve")),
    ("lvs", _("Standard Latvian")),
    ("lvu", _("Levuka")),
    ("lwa", _("Lwalu")),
    ("lwe", _("Lewo Eleng")),
    ("lwg", _("Wanga")),
    ("lwh", _("White Lachi")),
    ("lwl", _("Eastern Lawa")),
    ("lwm", _("Laomian")),
    ("lwo", _("Luwo")),
    ("lws", _("Malawian Sign Language")),
    ("lwt", _("Lewotobi")),
    ("lwu", _("Lawu")),
    ("lww", _("Lewo")),
    ("lxm", _("Lakurumau")),
    ("lya", _("Layakha")),
    ("lyg", _("Lyngngam")),
    ("lyn", _("Luyana")),
    ("lzh", _("Literary Chinese")),
    ("lzl", _("Litzlitz")),
    ("lzn", _("Leinong Naga")),
    ("lzz", _("Laz")),
    ("maa", _("San Jerónimo Tecóatl Mazatec")),
    ("mab", _("Yutanduchi Mixtec")),
    ("mad", _("Madurese")),
    ("mae", _("Bo-Rukul")),
    ("maf", _("Mafa")),
    ("mag", _("Magahi")),
    ("mai", _("Maithili")),
    ("maj", _("Jalapa De Díaz Mazatec")),
    ("mak", _("Makasar")),
    ("mam", _("Mam")),
    ("man", _("Mandingo")),
    ("map", _("Austronesian languages")),
    ("maq", _("Chiquihuitlán Mazatec")),
    ("mas", _("Masai")),
    ("mat", _("San Francisco Matlatzinca")),
    ("mau", _("Huautla Mazatec")),
    ("mav", _("Sateré-Mawé")),
    ("maw", _("Mampruli")),
    ("max", _("North Moluccan Malay")),
    ("maz", _("Central Mazahua")),
    ("mba", _("Higaonon")),
    ("mbb", _("Western Bukidnon Manobo")),
    ("mbc", _("Macushi")),
    ("mbd", _("Dibabawon Manobo")),
    ("mbe", _("Molale")),
    ("mbf", _("Baba Malay")),
    ("mbh", _("Mangseng")),
    ("mbi", _("Ilianen Manobo")),
    ("mbj", _("Nadëb")),
    ("mbk", _("Malol")),
    ("mbl", _("Maxakalí")),
    ("mbm", _("Ombamba")),
    ("mbn", _("Macaguán")),
    ("mbo", _("Mbo")),
    ("mbp", _("Malayo")),
    ("mbq", _("Maisin")),
    ("mbr", _("Nukak Makú")),
    ("mbs", _("Sarangani Manobo")),
    ("mbt", _("Matigsalug Manobo")),
    ("mbu", _("Mbula-Bwazza")),
    ("mbv", _("Mbulungish")),
    ("mbw", _("Maring")),
    ("mbx", _("Mari")),
    ("mby", _("Memoni")),
    ("mbz", _("Amoltepec Mixtec")),
    ("mca", _("Maca")),
    ("mcb", _("Machiguenga")),
    ("mcc", _("Bitur")),
    ("mcd", _("Sharanahua")),
    ("mce", _("Itundujia Mixtec")),
    ("mcf", _("Matsés")),
    ("mcg", _("Mapoyo")),
    ("mch", _("Maquiritari")),
    ("mci", _("Mese")),
    ("mcj", _("Mvanip")),
    ("mck", _("Mbunda")),
    ("mcl", _("Macaguaje")),
    ("mcm", _("Malaccan Creole Portuguese")),
    ("mcn", _("Masana")),
    ("mco", _("Coatlán Mixe")),
    ("mcp", _("Makaa")),
    ("mcq", _("Ese")),
    ("mcr", _("Menya")),
    ("mcs", _("Mambai")),
    ("mct", _("Mengisa")),
    ("mcu", _("Cameroon Mambila")),
    ("mcv", _("Minanibai")),
    ("mcw", _("Mawa")),
    ("mcx", _("Mpiemo")),
    ("mcy", _("South Watut")),
    ("mcz", _("Mawan")),
    ("mda", _("Mada")),
    ("mdb", _("Morigi")),
    ("mdc", _("Male")),
    ("mdd", _("Mbum")),
    ("mde", _("Maba")),
    ("mdf", _("Moksha")),
    ("mdg", _("Massalat")),
    ("mdh", _("Maguindanaon")),
    ("mdi", _("Mamvu")),
    ("mdj", _("Mangbetu")),
    ("mdk", _("Mangbutu")),
    ("mdl", _("Maltese Sign Language")),
    ("mdm", _("Mayogo")),
    ("mdn", _("Mbati")),
    ("mdp", _("Mbala")),
    ("mdq", _("Mbole")),
    ("mdr", _("Mandar")),
    ("mds", _("Maria")),
    ("mdt", _("Mbere")),
    ("mdu", _("Mboko")),
    ("mdv", _("Santa Lucía Monteverde Mixtec")),
    ("mdw", _("Mbosi")),
    ("mdx", _("Dizin")),
    ("mdy", _("Male")),
    ("mdz", _("Suruí Do Pará")),
    ("mea", _("Menka")),
    ("meb", _("Ikobi")),
    ("mec", _("Marra")),
    ("med", _("Melpa")),
    ("mee", _("Mengen")),
    ("mef", _("Megam")),
    ("meg", _("Mea")),
    ("meh", _("Southwestern Tlaxiaco Mixtec")),
    ("mei", _("Midob")),
    ("mej", _("Meyah")),
    ("mek", _("Mekeo")),
    ("mel", _("Central Melanau")),
    ("mem", _("Mangala")),
    ("men", _("Mende")),
    ("meo", _("Kedah Malay")),
    ("mep", _("Miriwoong")),
    ("meq", _("Merey")),
    ("mer", _("Meru")),
    ("mes", _("Masmaje")),
    ("met", _("Mato")),
    ("meu", _("Motu")),
    ("mev", _("Mano")),
    ("mew", _("Maaka")),
    ("mey", _("Hassaniyya")),
    ("mez", _("Menominee")),
    ("mfa", _("Pattani Malay")),
    ("mfb", _("Bangka")),
    ("mfc", _("Mba")),
    ("mfd", _("Mendankwe-Nkwen")),
    ("mfe", _("Morisyen")),
    ("mff", _("Naki")),
    ("mfg", _("Mogofin")),
    ("mfh", _("Matal")),
    ("mfi", _("Wandala")),
    ("mfj", _("Mefele")),
    ("mfk", _("North Mofu")),
    ("mfl", _("Putai")),
    ("mfm", _("Marghi South")),
    ("mfn", _("Cross River Mbembe")),
    ("mfo", _("Mbe")),
    ("mfp", _("Makassar Malay")),
    ("mfq", _("Moba")),
    ("mfr", _("Marrithiyel")),
    ("mfs", _("Mexican Sign Language")),
    ("mft", _("Mokerang")),
    ("mfu", _("Mbwela")),
    ("mfv", _("Mandjak")),
    ("mfw", _("Mulaha")),
    ("mfx", _("Melo")),
    ("mfy", _("Mayo")),
    ("mfz", _("Mabaan")),
    ("mga", _("Middle Irish")),
    ("mgb", _("Mararit")),
    ("mgc", _("Morokodo")),
    ("mgd", _("Moru")),
    ("mge", _("Mango")),
    ("mgf", _("Maklew")),
    ("mgg", _("Mpumpong")),
    ("mgh", _("Makhuwa-Meetto")),
    ("mgi", _("Lijili")),
    ("mgj", _("Abureni")),
    ("mgk", _("Mawes")),
    ("mgl", _("Maleu-Kilenge")),
    ("mgm", _("Mambae")),
    ("mgn", _("Mbangi")),
    ("mgo", _("Meta'")),
    ("mgp", _("Eastern Magar")),
    ("mgq", _("Malila")),
    ("mgr", _("Mambwe-Lungu")),
    ("mgs", _("Manda")),
    ("mgt", _("Mongol")),
    ("mgu", _("Mailu")),
    ("mgv", _("Matengo")),
    ("mgw", _("Matumbi")),
    ("mgx", _("Omati")),
    ("mgy", _("Mbunga")),
    ("mgz", _("Mbugwe")),
    ("mha", _("Manda")),
    ("mhb", _("Mahongwe")),
    ("mhc", _("Mocho")),
    ("mhd", _("Mbugu")),
    ("mhe", _("Besisi")),
    ("mhf", _("Mamaa")),
    ("mhg", _("Margu")),
    ("mhh", _("Maskoy Pidgin")),
    ("mhi", _("Ma'di")),
    ("mhj", _("Mogholi")),
    ("mhk", _("Mungaka")),
    ("mhl", _("Mauwake")),
    ("mhm", _("Makhuwa-Moniga")),
    ("mhn", _("Mócheno")),
    ("mho", _("Mashi")),
    ("mhp", _("Balinese Malay")),
    ("mhq", _("Mandan")),
    ("mhr", _("Eastern Mari")),
    ("mhs", _("Buru")),
    ("mht", _("Mandahuaca")),
    ("mhu", _("Digaro-Mishmi")),
    ("mhw", _("Mbukushu")),
    ("mhx", _("Maru")),
    ("mhy", _("Ma'anyan")),
    ("mhz", _("Mor")),
    ("mia", _("Miami")),
    ("mib", _("Atatláhuca Mixtec")),
    ("mic", _("Mi'kmaq")),
    ("mid", _("Mandaic")),
    ("mie", _("Ocotepec Mixtec")),
    ("mif", _("Mofu-Gudur")),
    ("mig", _("San Miguel El Grande Mixtec")),
    ("mih", _("Chayuco Mixtec")),
    ("mii", _("Chigmecatitlán Mixtec")),
    ("mij", _("Abar")),
    ("mik", _("Mikasuki")),
    ("mil", _("Peñoles Mixtec")),
    ("mim", _("Alacatlatzala Mixtec")),
    ("min", _("Minangkabau")),
    ("mio", _("Pinotepa Nacional Mixtec")),
    ("mip", _("Apasco-Apoala Mixtec")),
    ("miq", _("Mískito")),
    ("mir", _("Isthmus Mixe")),
    ("mis", _("Uncoded languages")),
    ("mit", _("Southern Puebla Mixtec")),
    ("miu", _("Cacaloxtepec Mixtec")),
    ("miw", _("Akoye")),
    ("mix", _("Mixtepec Mixtec")),
    ("miy", _("Ayutla Mixtec")),
    ("miz", _("Coatzospan Mixtec")),
    ("mja", _("Mahei")),
    ("mjb", _("Makalero")),
    ("mjc", _("San Juan Colorado Mixtec")),
    ("mjd", _("Northwest Maidu")),
    ("mje", _("Muskum")),
    ("mjg", _("Tu")),
    ("mjh", _("Mwera")),
    ("mji", _("Kim Mun")),
    ("mjj", _("Mawak")),
    ("mjk", _("Matukar")),
    ("mjl", _("Mandeali")),
    ("mjm", _("Medebur")),
    ("mjn", _("Ma")),
    ("mjo", _("Malankuravan")),
    ("mjp", _("Malapandaram")),
    ("mjq", _("Malaryan")),
    ("mjr", _("Malavedan")),
    ("mjs", _("Miship")),
    ("mjt", _("Sauria Paharia")),
    ("mju", _("Manna-Dora")),
    ("mjv", _("Mannan")),
    ("mjw", _("Karbi")),
    ("mjx", _("Mahali")),
    ("mjy", _("Mahican")),
    ("mjz", _("Majhi")),
    ("mka", _("Mbre")),
    ("mkb", _("Mal Paharia")),
    ("mkc", _("Siliput")),
    ("mke", _("Mawchi")),
    ("mkf", _("Miya")),
    ("mkg", _("Mak")),
    ("mkh", _("Mon-Khmer languages")),
    ("mki", _("Dhatki")),
    ("mkj", _("Mokilese")),
    ("mkk", _("Byep")),
    ("mkl", _("Mokole")),
    ("mkm", _("Moklen")),
    ("mkn", _("Kupang Malay")),
    ("mko", _("Mingang Doso")),
    ("mkp", _("Moikodi")),
    ("mkq", _("Bay Miwok")),
    ("mkr", _("Malas")),
    ("mks", _("Silacayoapan Mixtec")),
    ("mkt", _("Vamale")),
    ("mku", _("Konyanka Maninka")),
    ("mkv", _("Mafea")),
    ("mkw", _("Kituba")),
    ("mkx", _("Kinamiging Manobo")),
    ("mky", _("East Makian")),
    ("mkz", _("Makasae")),
    ("mla", _("Malo")),
    ("mlb", _("Mbule")),
    ("mlc", _("Cao Lan")),
    ("mld", _("Malakhel")),
    ("mle", _("Manambu")),
    ("mlf", _("Mal")),
    ("mlh", _("Mape")),
    ("mli", _("Malimpung")),
    ("mlj", _("Miltu")),
    ("mlk", _("Ilwana")),
    ("mll", _("Malua Bay")),
    ("mlm", _("Mulam")),
    ("mln", _("Malango")),
    ("mlo", _("Mlomp")),
    ("mlp", _("Bargam")),
    ("mlq", _("Western Maninkakan")),
    ("mlr", _("Vame")),
    ("mls", _("Masalit")),
    ("mlu", _("To'abaita")),
    ("mlv", _("Motlav")),
    ("mlw", _("Moloko")),
    ("mlx", _("Malfaxal")),
    ("mlz", _("Malaynon")),
    ("mma", _("Mama")),
    ("mmb", _("Momina")),
    ("mmc", _("Michoacán Mazahua")),
    ("mmd", _("Maonan")),
    ("mme", _("Mae")),
    ("mmf", _("Mundat")),
    ("mmg", _("North Ambrym")),
    ("mmh", _("Mehináku")),
    ("mmi", _("Musar")),
    ("mmj", _("Majhwar")),
    ("mmk", _("Mukha-Dora")),
    ("mml", _("Man Met")),
    ("mmm", _("Maii")),
    ("mmn", _("Mamanwa")),
    ("mmo", _("Mangga Buang")),
    ("mmp", _("Siawi")),
    ("mmq", _("Musak")),
    ("mmr", _("Western Xiangxi Miao")),
    ("mmt", _("Malalamai")),
    ("mmu", _("Mmaala")),
    ("mmv", _("Miriti")),
    ("mmw", _("Emae")),
    ("mmx", _("Madak")),
    ("mmy", _("Migaama")),
    ("mmz", _("Mabaale")),
    ("mna", _("Mbula")),
    ("mnb", _("Muna")),
    ("mnc", _("Manchu")),
    ("mnd", _("Mondé")),
    ("mne", _("Naba")),
    ("mnf", _("Mundani")),
    ("mng", _("Eastern Mnong")),
    ("mnh", _("Mono")),
    ("mni", _("Manipuri")),
    ("mnj", _("Munji")),
    ("mnk", _("Mandinka")),
    ("mnl", _("Tiale")),
    ("mnm", _("Mapena")),
    ("mnn", _("Southern Mnong")),
    ("mno", _("Manobo languages")),
    ("mnp", _("Min Bei Chinese")),
    ("mnq", _("Minriq")),
    ("mnr", _("Mono")),
    ("mns", _("Mansi")),
    ("mnt", _("Maykulan")),
    ("mnu", _("Mer")),
    ("mnv", _("Rennell-Bellona")),
    ("mnw", _("Mon")),
    ("mnx", _("Manikion")),
    ("mny", _("Manyawa")),
    ("mnz", _("Moni")),
    ("moa", _("Mwan")),
    ("moc", _("Mocoví")),
    ("mod", _("Mobilian")),
    ("moe", _("Innu")),
    ("mof", _("Mohegan-Montauk-Narragansett")),
    ("mog", _("Mongondow")),
    ("moh", _("Mohawk")),
    ("moi", _("Mboi")),
    ("moj", _("Monzombo")),
    ("mok", _("Morori")),
    ("mom", _("Mangue")),
    ("moo", _("Monom")),
    ("mop", _("Mopán Maya")),
    ("moq", _("Mor")),
    ("mor", _("Moro")),
    ("mos", _("Mossi")),
    ("mot", _("Barí")),
    ("mou", _("Mogum")),
    ("mov", _("Mohave")),
    ("mow", _("Moi")),
    ("mox", _("Molima")),
    ("moy", _("Shekkacho")),
    ("moz", _("Mukulu")),
    ("mpa", _("Mpoto")),
    ("mpb", _("Malak Malak")),
    ("mpc", _("Mangarrayi")),
    ("mpd", _("Machinere")),
    ("mpe", _("Majang")),
    ("mpg", _("Marba")),
    ("mph", _("Maung")),
    ("mpi", _("Mpade")),
    ("mpj", _("Martu Wangka")),
    ("mpk", _("Mbara")),
    ("mpl", _("Middle Watut")),
    ("mpm", _("Yosondúa Mixtec")),
    ("mpn", _("Mindiri")),
    ("mpo", _("Miu")),
    ("mpp", _("Migabac")),
    ("mpq", _("Matís")),
    ("mpr", _("Vangunu")),
    ("mps", _("Dadibi")),
    ("mpt", _("Mian")),
    ("mpu", _("Makuráp")),
    ("mpv", _("Mungkip")),
    ("mpw", _("Mapidian")),
    ("mpx", _("Misima-Panaeati")),
    ("mpy", _("Mapia")),
    ("mpz", _("Mpi")),
    ("mqa", _("Maba")),
    ("mqb", _("Mbuko")),
    ("mqc", _("Mangole")),
    ("mqe", _("Matepi")),
    ("mqf", _("Momuna")),
    ("mqg", _("Kota Bangun Kutai Malay")),
    ("mqh", _("Tlazoyaltepec Mixtec")),
    ("mqi", _("Mariri")),
    ("mqj", _("Mamasa")),
    ("mqk", _("Rajah Kabunsuwan Manobo")),
    ("mql", _("Mbelime")),
    ("mqm", _("South Marquesan")),
    ("mqn", _("Moronene")),
    ("mqo", _("Modole")),
    ("mqp", _("Manipa")),
    ("mqq", _("Minokok")),
    ("mqr", _("Mander")),
    ("mqs", _("West Makian")),
    ("mqt", _("Mok")),
    ("mqu", _("Mandari")),
    ("mqv", _("Mosimo")),
    ("mqw", _("Murupi")),
    ("mqx", _("Mamuju")),
    ("mqy", _("Manggarai")),
    ("mqz", _("Pano")),
    ("mra", _("Mlabri")),
    ("mrb", _("Marino")),
    ("mrc", _("Maricopa")),
    ("mrd", _("Western Magar")),
    ("mre", _("Martha's Vineyard Sign Language")),
    ("mrf", _("Elseng")),
    ("mrg", _("Mising")),
    ("mrh", _("Mara Chin")),
    ("mrj", _("Western Mari")),
    ("mrk", _("Hmwaveke")),
    ("mrl", _("Mortlockese")),
    ("mrm", _("Merlav")),
    ("mrn", _("Cheke Holo")),
    ("mro", _("Mru")),
    ("mrp", _("Morouas")),
    ("mrq", _("North Marquesan")),
    ("mrr", _("Maria")),
    ("mrs", _("Maragus")),
    ("mrt", _("Marghi Central")),
    ("mru", _("Mono")),
    ("mrv", _("Mangareva")),
    ("mrw", _("Maranao")),
    ("mrx", _("Maremgi")),
    ("mry", _("Mandaya")),
    ("mrz", _("Marind")),
    ("msb", _("Masbatenyo")),
    ("msc", _("Sankaran Maninka")),
    ("msd", _("Yucatec Maya Sign Language")),
    ("mse", _("Musey")),
    ("msf", _("Mekwei")),
    ("msg", _("Moraid")),
    ("msh", _("Masikoro Malagasy")),
    ("msi", _("Sabah Malay")),
    ("msj", _("Ma")),
    ("msk", _("Mansaka")),
    ("msl", _("Molof")),
    ("msm", _("Agusan Manobo")),
    ("msn", _("Vurës")),
    ("mso", _("Mombum")),
    ("msp", _("Maritsauá")),
    ("msq", _("Caac")),
    ("msr", _("Mongolian Sign Language")),
    ("mss", _("West Masela")),
    ("mst", _("Cataelano Mandaya")),
    ("msu", _("Musom")),
    ("msv", _("Maslam")),
    ("msw", _("Mansoanka")),
    ("msx", _("Moresada")),
    ("msy", _("Aruamu")),
    ("msz", _("Momare")),
    ("mta", _("Cotabato Manobo")),
    ("mtb", _("Anyin Morofo")),
    ("mtc", _("Munit")),
    ("mtd", _("Mualang")),
    ("mte", _("Mono")),
    ("mtf", _("Murik")),
    ("mtg", _("Una")),
    ("mth", _("Munggui")),
    ("mti", _("Maiwa")),
    ("mtj", _("Moskona")),
    ("mtk", _("Mbe'")),
    ("mtl", _("Montol")),
    ("mtm", _("Mator")),
    ("mtn", _("Matagalpa")),
    ("mto", _("Totontepec Mixe")),
    ("mtp", _("Wichí Lhamtés Nocten")),
    ("mtq", _("Muong")),
    ("mtr", _("Mewari")),
    ("mts", _("Yora")),
    ("mtt", _("Mota")),
    ("mtu", _("Tututepec Mixtec")),
    ("mtv", _("Asaro'o")),
    ("mtw", _("Southern Binukidnon")),
    ("mtx", _("Tidaá Mixtec")),
    ("mty", _("Nabi")),
    ("mua", _("Mundang")),
    ("mub", _("Mubi")),
    ("muc", _("Ajumbu")),
    ("mud", _("Mednyj Aleut")),
    ("mue", _("Media Lengua")),
    ("mug", _("Musgu")),
    ("muh", _("Mündü")),
    ("mui", _("Musi")),
    ("muj", _("Mabire")),
    ("muk", _("Mugom")),
    ("mul", _("Multiple languages")),
    ("mum", _("Maiwala")),
    ("mun", _("Munda languages")),
    ("muo", _("Nyong")),
    ("mup", _("Malvi")),
    ("muq", _("Eastern Xiangxi Miao")),
    ("mur", _("Murle")),
    ("mus", _("Creek")),
    ("mut", _("Western Muria")),
    ("muu", _("Yaaku")),
    ("muv", _("Muthuvan")),
    ("mux", _("Bo-Ung")),
    ("muy", _("Muyang")),
    ("muz", _("Mursi")),
    ("mva", _("Manam")),
    ("mvb", _("Mattole")),
    ("mvd", _("Mamboru")),
    ("mve", _("Marwari")),
    ("mvf", _("Peripheral Mongolian")),
    ("mvg", _("Yucuañe Mixtec")),
    ("mvh", _("Mulgi")),
    ("mvi", _("Miyako")),
    ("mvk", _("Mekmek")),
    ("mvl", _("Mbara")),
    ("mvm", _("Muya")),
    ("mvn", _("Minaveha")),
    ("mvo", _("Marovo")),
    ("mvp", _("Duri")),
    ("mvq", _("Moere")),
    ("mvr", _("Marau")),
    ("mvs", _("Massep")),
    ("mvt", _("Mpotovoro")),
    ("mvu", _("Marfa")),
    ("mvv", _("Tagal Murut")),
    ("mvw", _("Machinga")),
    ("mvx", _("Meoswar")),
    ("mvy", _("Indus Kohistani")),
    ("mvz", _("Mesqan")),
    ("mwa", _("Mwatebu")),
    ("mwb", _("Juwal")),
    ("mwc", _("Are")),
    ("mwd", _("Mudbura")),
    ("mwe", _("Mwera")),
    ("mwf", _("Murrinh-Patha")),
    ("mwg", _("Aiklep")),
    ("mwh", _("Mouk-Aria")),
    ("mwi", _("Labo")),
    ("mwj", _("Maligo")),
    ("mwk", _("Kita Maninkakan")),
    ("mwl", _("Mirandese")),
    ("mwm", _("Sar")),
    ("mwn", _("Nyamwanga")),
    ("mwo", _("Central Maewo")),
    ("mwp", _("Kala Lagaw Ya")),
    ("mwq", _("Mün Chin")),
    ("mwr", _("Marwari")),
    ("mws", _("Mwimbi-Muthambi")),
    ("mwt", _("Moken")),
    ("mwu", _("Mittu")),
    ("mwv", _("Mentawai")),
    ("mww", _("Hmong Daw")),
    ("mwx", _("Mediak")),
    ("mwy", _("Mosiro")),
    ("mwz", _("Moingi")),
    ("mxa", _("Northwest Oaxaca Mixtec")),
    ("mxb", _("Tezoatlán Mixtec")),
    ("mxc", _("Manyika")),
    ("mxd", _("Modang")),
    ("mxe", _("Mele-Fila")),
    ("mxf", _("Malgbe")),
    ("mxg", _("Mbangala")),
    ("mxh", _("Mvuba")),
    ("mxi", _("Mozarabic")),
    ("mxj", _("Miju-Mishmi")),
    ("mxk", _("Monumbo")),
    ("mxl", _("Maxi Gbe")),
    ("mxm", _("Meramera")),
    ("mxn", _("Moi")),
    ("mxo", _("Mbowe")),
    ("mxp", _("Tlahuitoltepec Mixe")),
    ("mxq", _("Juquila Mixe")),
    ("mxr", _("Murik")),
    ("mxs", _("Huitepec Mixtec")),
    ("mxt", _("Jamiltepec Mixtec")),
    ("mxu", _("Mada")),
    ("mxv", _("Metlatónoc Mixtec")),
    ("mxw", _("Namo")),
    ("mxx", _("Mahou")),
    ("mxy", _("Southeastern Nochixtlán Mixtec")),
    ("mxz", _("Central Masela")),
    ("myb", _("Mbay")),
    ("myc", _("Mayeka")),
    ("myd", _("Maramba")),
    ("mye", _("Myene")),
    ("myf", _("Bambassi")),
    ("myg", _("Manta")),
    ("myh", _("Makah")),
    ("myi", _("Mina")),
    ("myj", _("Mangayat")),
    ("myk", _("Mamara Senoufo")),
    ("myl", _("Moma")),
    ("mym", _("Me'en")),
    ("myn", _("Mayan languages")),
    ("myo", _("Anfillo")),
    ("myp", _("Pirahã")),
    ("myq", _("Forest Maninka")),
    ("myr", _("Muniche")),
    ("mys", _("Mesmes")),
    ("myt", _("Sangab Mandaya")),
    ("myu", _("Mundurukú")),
    ("myv", _("Erzya")),
    ("myw", _("Muyuw")),
    ("myx", _("Masaaba")),
    ("myy", _("Macuna")),
    ("myz", _("Classical Mandaic")),
    ("mza", _("Santa María Zacatepec Mixtec")),
    ("mzb", _("Tumzabt")),
    ("mzc", _("Madagascar Sign Language")),
    ("mzd", _("Malimba")),
    ("mze", _("Morawa")),
    ("mzg", _("Monastic Sign Language")),
    ("mzh", _("Wichí Lhamtés Güisnay")),
    ("mzi", _("Ixcatlán Mazatec")),
    ("mzj", _("Manya")),
    ("mzk", _("Nigeria Mambila")),
    ("mzl", _("Mazatlán Mixe")),
    ("mzm", _("Mumuye")),
    ("mzn", _("Mazanderani")),
    ("mzo", _("Matipuhy")),
    ("mzp", _("Movima")),
    ("mzq", _("Mori Atas")),
    ("mzr", _("Marúbo")),
    ("mzs", _("Macanese")),
    ("mzt", _("Mintil")),
    ("mzu", _("Inapang")),
    ("mzv", _("Manza")),
    ("mzw", _("Deg")),
    ("mzx", _("Mawayana")),
    ("mzy", _("Mozambican Sign Language")),
    ("mzz", _("Maiadomu")),
    ("naa", _("Namla")),
    ("nab", _("Southern Nambikuára")),
    ("nac", _("Narak")),
    ("nad", _("Nijadali")),
    ("nae", _("Naka'ela")),
    ("naf", _("Nabak")),
    ("nag", _("Naga Pidgin")),
    ("nah", _("Nahuatl languages")),
    ("nai", _("North American Indian languages")),
    ("naj", _("Nalu")),
    ("nak", _("Nakanai")),
    ("nal", _("Nalik")),
    ("nam", _("Ngan'gityemerri")),
    ("nan", _("Min Nan Chinese")),
    ("nao", _("Naaba")),
    ("nap", _("Neapolitan")),
    ("naq", _("Khoekhoe")),
    ("nar", _("Iguta")),
    ("nas", _("Naasioi")),
    ("nat", _("Ca̱hungwa̱rya̱")),
    ("naw", _("Nawuri")),
    ("nax", _("Nakwi")),
    ("nay", _("Ngarrindjeri")),
    ("naz", _("Coatepec Nahuatl")),
    ("nba", _("Nyemba")),
    ("nbb", _("Ndoe")),
    ("nbc", _("Chang Naga")),
    ("nbd", _("Ngbinda")),
    ("nbe", _("Konyak Naga")),
    ("nbf", _("Naxi")),
    ("nbg", _("Nagarchal")),
    ("nbh", _("Ngamo")),
    ("nbi", _("Mao Naga")),
    ("nbj", _("Ngarinyman")),
    ("nbk", _("Nake")),
    ("nbm", _("Ngbaka Ma'bo")),
    ("nbn", _("Kuri")),
    ("nbo", _("Nkukoli")),
    ("nbp", _("Nnam")),
    ("nbq", _("Nggem")),
    ("nbr", _("Numana")),
    ("nbs", _("Namibian Sign Language")),
    ("nbt", _("Na")),
    ("nbu", _("Rongmei Naga")),
    ("nbv", _("Ngamambo")),
    ("nbw", _("Southern Ngbandi")),
    ("nbx", _("Ngura")),
    ("nby", _("Ningera")),
    ("nca", _("Iyo")),
    ("ncb", _("Central Nicobarese")),
    ("ncc", _("Ponam")),
    ("ncd", _("Nachering")),
    ("nce", _("Yale")),
    ("ncf", _("Notsi")),
    ("ncg", _("Nisga'a")),
    ("nch", _("Central Huasteca Nahuatl")),
    ("nci", _("Classical Nahuatl")),
    ("ncj", _("Northern Puebla Nahuatl")),
    ("nck", _("Na-kara")),
    ("ncl", _("Michoacán Nahuatl")),
    ("ncm", _("Nambo")),
    ("ncn", _("Nauna")),
    ("nco", _("Sibe")),
    ("ncp", _("Ndaktup")),
    ("ncq", _("Northern Katang")),
    ("ncr", _("Ncane")),
    ("ncs", _("Nicaraguan Sign Language")),
    ("nct", _("Chothe Naga")),
    ("ncu", _("Chumburung")),
    ("ncx", _("Central Puebla Nahuatl")),
    ("ncz", _("Natchez")),
    ("nda", _("Ndasa")),
    ("ndb", _("Kenswei Nsei")),
    ("ndc", _("Ndau")),
    ("ndd", _("Nde-Nsele-Nta")),
    ("ndf", _("Nadruvian")),
    ("ndg", _("Ndengereko")),
    ("ndh", _("Ndali")),
    ("ndi", _("Samba Leko")),
    ("ndj", _("Ndamba")),
    ("ndk", _("Ndaka")),
    ("ndl", _("Ndolo")),
    ("ndm", _("Ndam")),
    ("ndn", _("Ngundi")),
    ("ndp", _("Ndo")),
    ("ndq", _("Ndombe")),
    ("ndr", _("Ndoola")),
    ("nds", _("Low German")),
    ("ndt", _("Ndunga")),
    ("ndu", _("Dugun")),
    ("ndv", _("Ndut")),
    ("ndw", _("Ndobo")),
    ("ndx", _("Nduga")),
    ("ndy", _("Lutos")),
    ("ndz", _("Ndogo")),
    ("nea", _("Eastern Ngad'a")),
    ("neb", _("Toura")),
    ("nec", _("Nedebang")),
    ("ned", _("Nde-Gbite")),
    ("nee", _("Nêlêmwa-Nixumwak")),
    ("nef", _("Nefamese")),
    ("neg", _("Negidal")),
    ("neh", _("Nyenkha")),
    ("nei", _("Neo-Hittite")),
    ("nej", _("Neko")),
    ("nek", _("Neku")),
    ("nem", _("Nemi")),
    ("nen", _("Nengone")),
    ("neo", _("Ná-Meo")),
    ("neq", _("North Central Mixe")),
    ("ner", _("Yahadian")),
    ("nes", _("Bhoti Kinnauri")),
    ("net", _("Nete")),
    ("neu", _("Neo")),
    ("nev", _("Nyaheun")),
    ("new", _("Newari")),
    ("nex", _("Neme")),
    ("ney", _("Neyo")),
    ("nez", _("Nez Perce")),
    ("nfa", _("Dhao")),
    ("nfd", _("Ahwai")),
    ("nfl", _("Ayiwo")),
    ("nfr", _("Nafaanra")),
    ("nfu", _("Mfumte")),
    ("nga", _("Ngbaka")),
    ("ngb", _("Northern Ngbandi")),
    ("ngc", _("Ngombe")),
    ("ngd", _("Ngando")),
    ("nge", _("Ngemba")),
    ("ngf", _("Trans-New Guinea languages")),
    ("ngg", _("Ngbaka Manza")),
    ("ngh", _("Nǁng")),
    ("ngi", _("Ngizim")),
    ("ngj", _("Ngie")),
    ("ngk", _("Dalabon")),
    ("ngl", _("Lomwe")),
    ("ngm", _("Ngatik Men's Creole")),
    ("ngn", _("Ngwo")),
    ("ngo", _("Ngoni")),
    ("ngp", _("Ngulu")),
    ("ngq", _("Ngurimi")),
    ("ngr", _("Engdewu")),
    ("ngs", _("Gvoko")),
    ("ngt", _("Kriang")),
    ("ngu", _("Guerrero Nahuatl")),
    ("ngv", _("Nagumi")),
    ("ngw", _("Ngwaba")),
    ("ngx", _("Nggwahyi")),
    ("ngy", _("Tibea")),
    ("ngz", _("Ngungwel")),
    ("nha", _("Nhanda")),
    ("nhb", _("Beng")),
    ("nhc", _("Tabasco Nahuatl")),
    ("nhd", _("Chiripá")),
    ("nhe", _("Eastern Huasteca Nahuatl")),
    ("nhf", _("Nhuwala")),
    ("nhg", _("Tetelcingo Nahuatl")),
    ("nhh", _("Nahari")),
    ("nhi", _("Zacatlán-Ahuacatlán-Tepetzintla Nahuatl")),
    ("nhk", _("Isthmus-Cosoleacaque Nahuatl")),
    ("nhm", _("Morelos Nahuatl")),
    ("nhn", _("Central Nahuatl")),
    ("nho", _("Takuu")),
    ("nhp", _("Isthmus-Pajapan Nahuatl")),
    ("nhq", _("Huaxcaleca Nahuatl")),
    ("nhr", _("Naro")),
    ("nht", _("Ometepec Nahuatl")),
    ("nhu", _("Noone")),
    ("nhv", _("Temascaltepec Nahuatl")),
    ("nhw", _("Western Huasteca Nahuatl")),
    ("nhx", _("Isthmus-Mecayapan Nahuatl")),
    ("nhy", _("Northern Oaxaca Nahuatl")),
    ("nhz", _("Santa María La Alta Nahuatl")),
    ("nia", _("Nias")),
    ("nib", _("Nakame")),
    ("nic", _("Niger-Kordofanian languages")),
    ("nid", _("Ngandi")),
    ("nie", _("Niellim")),
    ("nif", _("Nek")),
    ("nig", _("Ngalakgan")),
    ("nih", _("Nyiha")),
    ("nii", _("Nii")),
    ("nij", _("Ngaju")),
    ("nik", _("Southern Nicobarese")),
    ("nil", _("Nila")),
    ("nim", _("Nilamba")),
    ("nin", _("Ninzo")),
    ("nio", _("Nganasan")),
    ("niq", _("Nandi")),
    ("nir", _("Nimboran")),
    ("nis", _("Nimi")),
    ("nit", _("Southeastern Kolami")),
    ("niu", _("Niuean")),
    ("niv", _("Gilyak")),
    ("niw", _("Nimo")),
    ("nix", _("Hema")),
    ("niy", _("Ngiti")),
    ("niz", _("Ningil")),
    ("nja", _("Nzanyi")),
    ("njb", _("Nocte Naga")),
    ("njd", _("Ndonde Hamba")),
    ("njh", _("Lotha Naga")),
    ("nji", _("Gudanji")),
    ("njj", _("Njen")),
    ("njl", _("Njalgulgule")),
    ("njm", _("Angami Naga")),
    ("njn", _("Liangmai Naga")),
    ("njo", _("Ao Naga")),
    ("njr", _("Njerep")),
    ("njs", _("Nisa")),
    ("njt", _("Ndyuka-Trio Pidgin")),
    ("nju", _("Ngadjunmaya")),
    ("njx", _("Kunyi")),
    ("njy", _("Njyem")),
    ("njz", _("Nyishi")),
    ("nka", _("Nkoya")),
    ("nkb", _("Khoibu Naga")),
    ("nkc", _("Nkongho")),
    ("nkd", _("Koireng")),
    ("nke", _("Duke")),
    ("nkf", _("Inpui Naga")),
    ("nkg", _("Nekgini")),
    ("nkh", _("Khezha Naga")),
    ("nki", _("Thangal Naga")),
    ("nkj", _("Nakai")),
    ("nkk", _("Nokuku")),
    ("nkm", _("Namat")),
    ("nkn", _("Nkangala")),
    ("nko", _("Nkonya")),
    ("nkp", _("Niuatoputapu")),
    ("nkq", _("Nkami")),
    ("nkr", _("Nukuoro")),
    ("nks", _("North Asmat")),
    ("nkt", _("Nyika")),
    ("nku", _("Bouna Kulango")),
    ("nkv", _("Nyika")),
    ("nkw", _("Nkutu")),
    ("nkx", _("Nkoroo")),
    ("nkz", _("Nkari")),
    ("nla", _("Ngombale")),
    ("nlc", _("Nalca")),
    ("nle", _("East Nyala")),
    ("nlg", _("Gela")),
    ("nli", _("Grangali")),
    ("nlj", _("Nyali")),
    ("nlk", _("Ninia Yali")),
    ("nll", _("Nihali")),
    ("nlm", _("Mankiyali")),
    ("nln", _("Durango Nahuatl")),
    ("nlo", _("Ngul")),
    ("nlq", _("Lao Naga")),
    ("nlr", _("Ngarla")),
    ("nlu", _("Nchumbulu")),
    ("nlv", _("Orizaba Nahuatl")),
    ("nlw", _("Walangama")),
    ("nlx", _("Nahali")),
    ("nly", _("Nyamal")),
    ("nlz", _("Nalögo")),
    ("nma", _("Maram Naga")),
    ("nmb", _("Big Nambas")),
    ("nmc", _("Ngam")),
    ("nmd", _("Ndumu")),
    ("nme", _("Mzieme Naga")),
    ("nmf", _("Tangkhul Naga")),
    ("nmg", _("Kwasio")),
    ("nmh", _("Monsang Naga")),
    ("nmi", _("Nyam")),
    ("nmj", _("Ngombe")),
    ("nmk", _("Namakura")),
    ("nml", _("Ndemli")),
    ("nmm", _("Manangba")),
    ("nmn", _("ǃXóõ")),
    ("nmo", _("Moyon Naga")),
    ("nmp", _("Nimanbur")),
    ("nmq", _("Nambya")),
    ("nmr", _("Nimbari")),
    ("nms", _("Letemboi")),
    ("nmt", _("Namonuito")),
    ("nmu", _("Northeast Maidu")),
    ("nmv", _("Ngamini")),
    ("nmw", _("Nimoa")),
    ("nmx", _("Nama")),
    ("nmy", _("Namuyi")),
    ("nmz", _("Nawdm")),
    ("nna", _("Nyangumarta")),
    ("nnb", _("Nande")),
    ("nnc", _("Nancere")),
    ("nnd", _("West Ambae")),
    ("nne", _("Ngandyera")),
    ("nnf", _("Ngaing")),
    ("nng", _("Maring Naga")),
    ("nnh", _("Ngiemboon")),
    ("nni", _("North Nuaulu")),
    ("nnj", _("Nyangatom")),
    ("nnk", _("Nankina")),
    ("nnl", _("Northern Rengma Naga")),
    ("nnm", _("Namia")),
    ("nnn", _("Ngete")),
    ("nnp", _("Wancho Naga")),
    ("nnq", _("Ngindo")),
    ("nnr", _("Narungga")),
    ("nns", _("Ningye")),
    ("nnt", _("Nanticoke")),
    ("nnu", _("Dwang")),
    ("nnv", _("Nugunu")),
    ("nnw", _("Southern Nuni")),
    ("nnx", _("Ngong")),
    ("nny", _("Nyangga")),
    ("nnz", _("Nda'nda'")),
    ("noa", _("Woun Meu")),
    ("noc", _("Nuk")),
    ("nod", _("Northern Thai")),
    ("noe", _("Nimadi")),
    ("nof", _("Nomane")),
    ("nog", _("Nogai")),
    ("noh", _("Nomu")),
    ("noi", _("Noiri")),
    ("noj", _("Nonuya")),
    ("nok", _("Nooksack")),
    ("nol", _("Nomlaki")),
    ("nom", _("Nocamán")),
    ("non", _("Old Norse")),
    ("noo", _("Nootka")),
    ("nop", _("Numanggang")),
    ("noq", _("Ngongo")),
    ("nos", _("Eastern Nisu")),
    ("not", _("Nomatsiguenga")),
    ("nou", _("Ewage-Notu")),
    ("nov", _("Novial")),
    ("now", _("Nyambo")),
    ("noy", _("Noy")),
    ("noz", _("Nayi")),
    ("npa", _("Nar Phu")),
    ("npb", _("Nupbikha")),
    ("npg", _("Ponyo-Gongwang Naga")),
    ("nph", _("Phom Naga")),
    ("npi", _("Nepali")),
    ("npl", _("Southeastern Puebla Nahuatl")),
    ("npn", _("Mondropolon")),
    ("npo", _("Pochuri Naga")),
    ("nps", _("Nipsan")),
    ("npu", _("Puimei Naga")),
    ("npx", _("Noipx")),
    ("npy", _("Napu")),
    ("nqg", _("Southern Nago")),
    ("nqk", _("Kura Ede Nago")),
    ("nql", _("Ngendelengo")),
    ("nqm", _("Ndom")),
    ("nqn", _("Nen")),
    ("nqo", _("N'Ko")),
    ("nqq", _("Kyan-Karyaw Naga")),
    ("nqt", _("Nteng")),
    ("nqy", _("Akyaung Ari Naga")),
    ("nra", _("Ngom")),
    ("nrb", _("Nara")),
    ("nrc", _("Noric")),
    ("nre", _("Southern Rengma Naga")),
    ("nrf", _("Jèrriais")),
    ("nrg", _("Narango")),
    ("nri", _("Chokri Naga")),
    ("nrk", _("Ngarla")),
    ("nrl", _("Ngarluma")),
    ("nrm", _("Narom")),
    ("nrn", _("Norn")),
    ("nrp", _("North Picene")),
    ("nrr", _("Norra")),
    ("nrt", _("Northern Kalapuya")),
    ("nru", _("Narua")),
    ("nrx", _("Ngurmbur")),
    ("nrz", _("Lala")),
    ("nsa", _("Sangtam Naga")),
    ("nsb", _("Lower Nossob")),
    ("nsc", _("Nshi")),
    ("nsd", _("Southern Nisu")),
    ("nse", _("Nsenga")),
    ("nsf", _("Northwestern Nisu")),
    ("nsg", _("Ngasa")),
    ("nsh", _("Ngoshie")),
    ("nsi", _("Nigerian Sign Language")),
    ("nsk", _("Naskapi")),
    ("nsl", _("Norwegian Sign Language")),
    ("nsm", _("Sumi Naga")),
    ("nsn", _("Nehan")),
    ("nso", _("Pedi")),
    ("nsp", _("Nepalese Sign Language")),
    ("nsq", _("Northern Sierra Miwok")),
    ("nsr", _("Maritime Sign Language")),
    ("nss", _("Nali")),
    ("nst", _("Tase Naga")),
    ("nsu", _("Sierra Negra Nahuatl")),
    ("nsv", _("Southwestern Nisu")),
    ("nsw", _("Navut")),
    ("nsx", _("Nsongo")),
    ("nsy", _("Nasal")),
    ("nsz", _("Nisenan")),
    ("ntd", _("Northern Tidung")),
    ("nte", _("Nathembo")),
    ("ntg", _("Ngantangarra")),
    ("nti", _("Natioro")),
    ("ntj", _("Ngaanyatjarra")),
    ("ntk", _("Ikoma-Nata-Isenye")),
    ("ntm", _("Nateni")),
    ("nto", _("Ntomba")),
    ("ntp", _("Northern Tepehuan")),
    ("ntr", _("Delo")),
    ("nts", _("Natagaimas")),
    ("ntu", _("Natügu")),
    ("ntw", _("Nottoway")),
    ("ntx", _("Tangkhul Naga")),
    ("nty", _("Mantsi")),
    ("ntz", _("Natanzi")),
    ("nua", _("Yuanga")),
    ("nub", _("Nubian languages")),
    ("nuc", _("Nukuini")),
    ("nud", _("Ngala")),
    ("nue", _("Ngundu")),
    ("nuf", _("Nusu")),
    ("nug", _("Nungali")),
    ("nuh", _("Ndunda")),
    ("nui", _("Ngumbi")),
    ("nuj", _("Nyole")),
    ("nuk", _("Nuu-chah-nulth")),
    ("nul", _("Nusa Laut")),
    ("num", _("Niuafo'ou")),
    ("nun", _("Anong")),
    ("nuo", _("Nguôn")),
    ("nup", _("Nupe-Nupe-Tako")),
    ("nuq", _("Nukumanu")),
    ("nur", _("Nukuria")),
    ("nus", _("Nuer")),
    ("nut", _("Nung")),
    ("nuu", _("Ngbundu")),
    ("nuv", _("Northern Nuni")),
    ("nuw", _("Nguluwan")),
    ("nux", _("Mehek")),
    ("nuy", _("Nunggubuyu")),
    ("nuz", _("Tlamacazapa Nahuatl")),
    ("nvh", _("Nasarian")),
    ("nvm", _("Namiae")),
    ("nvo", _("Nyokon")),
    ("nwa", _("Nawathinehena")),
    ("nwb", _("Nyabwa")),
    ("nwc", _("Classical Newari")),
    ("nwe", _("Ngwe")),
    ("nwg", _("Ngayawung")),
    ("nwi", _("Southwest Tanna")),
    ("nwm", _("Nyamusa-Molo")),
    ("nwo", _("Nauo")),
    ("nwr", _("Nawaru")),
    ("nwx", _("Middle Newar")),
    ("nwy", _("Nottoway-Meherrin")),
    ("nxa", _("Nauete")),
    ("nxd", _("Ngando")),
    ("nxe", _("Nage")),
    ("nxg", _("Ngad'a")),
    ("nxi", _("Nindi")),
    ("nxk", _("Koki Naga")),
    ("nxl", _("South Nuaulu")),
    ("nxm", _("Numidian")),
    ("nxn", _("Ngawun")),
    ("nxo", _("Ndambomo")),
    ("nxq", _("Naxi")),
    ("nxr", _("Ninggerum")),
    ("nxu", _("Narau")),
    ("nxx", _("Nafri")),
    ("nyb", _("Nyangbo")),
    ("nyc", _("Nyanga-li")),
    ("nyd", _("Nyore")),
    ("nye", _("Nyengo")),
    ("nyf", _("Giryama")),
    ("nyg", _("Nyindu")),
    ("nyh", _("Nyikina")),
    ("nyi", _("Ama")),
    ("nyj", _("Nyanga")),
    ("nyk", _("Nyaneka")),
    ("nyl", _("Nyeu")),
    ("nym", _("Nyamwezi")),
    ("nyn", _("Nyankole")),
    ("nyo", _("Nyoro")),
    ("nyp", _("Nyang'i")),
    ("nyq", _("Nayini")),
    ("nyr", _("Nyiha")),
    ("nys", _("Nyungar")),
    ("nyt", _("Nyawaygi")),
    ("nyu", _("Nyungwe")),
    ("nyv", _("Nyulnyul")),
    ("nyw", _("Nyaw")),
    ("nyx", _("Nganyaywana")),
    ("nyy", _("Nyakyusa-Ngonde")),
    ("nza", _("Tigon Mbembe")),
    ("nzb", _("Njebi")),
    ("nzd", _("Nzadi")),
    ("nzi", _("Nzima")),
    ("nzk", _("Nzakara")),
    ("nzm", _("Zeme Naga")),
    ("nzs", _("New Zealand Sign Language")),
    ("nzu", _("Teke-Nzikou")),
    ("nzy", _("Nzakambay")),
    ("nzz", _("Nanga Dama Dogon")),
    ("oaa", _("Orok")),
    ("oac", _("Oroch")),
    ("oar", _("Old Aramaic")),
    ("oav", _("Old Avar")),
    ("obi", _("Obispeño")),
    ("obk", _("Southern Bontok")),
    ("obl", _("Oblo")),
    ("obm", _("Moabite")),
    ("obo", _("Obo Manobo")),
    ("obr", _("Old Burmese")),
    ("obt", _("Old Breton")),
    ("obu", _("Obulom")),
    ("oca", _("Ocaina")),
    ("och", _("Old Chinese")),
    ("ocm", _("Old Cham")),
    ("oco", _("Old Cornish")),
    ("ocu", _("Atzingo Matlatzinca")),
    ("oda", _("Odut")),
    ("odk", _("Od")),
    ("odt", _("Old Dutch")),
    ("odu", _("Odual")),
    ("ofo", _("Ofo")),
    ("ofs", _("Old Frisian")),
    ("ofu", _("Efutop")),
    ("ogb", _("Ogbia")),
    ("ogc", _("Ogbah")),
    ("oge", _("Old Georgian")),
    ("ogg", _("Ogbogolo")),
    ("ogo", _("Khana")),
    ("ogu", _("Ogbronuagum")),
    ("oht", _("Old Hittite")),
    ("ohu", _("Old Hungarian")),
    ("oia", _("Oirata")),
    ("oin", _("Inebu One")),
    ("ojb", _("Northwestern Ojibwa")),
    ("ojc", _("Central Ojibwa")),
    ("ojg", _("Eastern Ojibwa")),
    ("ojp", _("Old Japanese")),
    ("ojs", _("Severn Ojibwa")),
    ("ojv", _("Ontong Java")),
    ("ojw", _("Western Ojibwa")),
    ("oka", _("Okanagan")),
    ("okb", _("Okobo")),
    ("okc", _("Kobo")),
    ("okd", _("Okodia")),
    ("oke", _("Okpe")),
    ("okg", _("Koko Babangk")),
    ("okh", _("Koresh-e Rostam")),
    ("oki", _("Okiek")),
    ("okj", _("Oko-Juwoi")),
    ("okk", _("Kwamtim One")),
    ("okl", _("Old Kentish Sign Language")),
    ("okm", _("Middle Korean")),
    ("okn", _("Oki-No-Erabu")),
    ("oko", _("Old Korean")),
    ("okr", _("Kirike")),
    ("oks", _("Oko-Eni-Osayen")),
    ("oku", _("Oku")),
    ("okv", _("Orokaiva")),
    ("okx", _("Okpe")),
    ("okz", _("Old Khmer")),
    ("ola", _("Walungge")),
    ("old", _("Mochi")),
    ("ole", _("Olekha")),
    ("olk", _("Olkol")),
    ("olm", _("Oloma")),
    ("olo", _("Livvi")),
    ("olr", _("Olrat")),
    ("olt", _("Old Lithuanian")),
    ("olu", _("Kuvale")),
    ("oma", _("Omaha-Ponca")),
    ("omb", _("East Ambae")),
    ("omc", _("Mochica")),
    ("ome", _("Omejes")),
    ("omg", _("Omagua")),
    ("omi", _("Omi")),
    ("omk", _("Omok")),
    ("oml", _("Ombo")),
    ("omn", _("Minoan")),
    ("omo", _("Utarmbung")),
    ("omp", _("Old Manipuri")),
    ("omq", _("Oto-Manguean languages")),
    ("omr", _("Old Marathi")),
    ("omt", _("Omotik")),
    ("omu", _("Omurano")),
    ("omv", _("Omotic languages")),
    ("omw", _("South Tairora")),
    ("omx", _("Old Mon")),
    ("omy", _("Old Malay")),
    ("ona", _("Ona")),
    ("onb", _("Lingao")),
    ("one", _("Oneida")),
    ("ong", _("Olo")),
    ("oni", _("Onin")),
    ("onj", _("Onjob")),
    ("onk", _("Kabore One")),
    ("onn", _("Onobasulu")),
    ("ono", _("Onondaga")),
    ("onp", _("Sartang")),
    ("onr", _("Northern One")),
    ("ons", _("Ono")),
    ("ont", _("Ontenu")),
    ("onu", _("Unua")),
    ("onw", _("Old Nubian")),
    ("onx", _("Onin Based Pidgin")),
    ("ood", _("Tohono O'odham")),
    ("oog", _("Ong")),
    ("oon", _("Önge")),
    ("oor", _("Oorlams")),
    ("oos", _("Old Ossetic")),
    ("opa", _("Okpamheri")),
    ("opk", _("Kopkaka")),
    ("opm", _("Oksapmin")),
    ("opo", _("Opao")),
    ("opt", _("Opata")),
    ("opy", _("Ofayé")),
    ("ora", _("Oroha")),
    ("orc", _("Orma")),
    ("ore", _("Orejón")),
    ("org", _("Oring")),
    ("orh", _("Oroqen")),
    ("orn", _("Orang Kanaq")),
    ("oro", _("Orokolo")),
    ("orr", _("Oruma")),
    ("ors", _("Orang Seletar")),
    ("ort", _("Adivasi Oriya")),
    ("oru", _("Ormuri")),
    ("orv", _("Old Russian")),
    ("orw", _("Oro Win")),
    ("orx", _("Oro")),
    ("ory", _("Odia")),
    ("orz", _("Ormu")),
    ("osa", _("Osage")),
    ("osc", _("Oscan")),
    ("osi", _("Osing")),
    ("osn", _("Old Sundanese")),
    ("oso", _("Ososo")),
    ("osp", _("Old Spanish")),
    ("ost", _("Osatu")),
    ("osu", _("Southern One")),
    ("osx", _("Old Saxon")),
    ("ota", _("Ottoman Turkish")),
    ("otb", _("Old Tibetan")),
    ("otd", _("Ot Danum")),
    ("ote", _("Mezquital Otomi")),
    ("oti", _("Oti")),
    ("otk", _("Old Turkish")),
    ("otl", _("Tilapa Otomi")),
    ("otm", _("Eastern Highland Otomi")),
    ("otn", _("Tenango Otomi")),
    ("oto", _("Otomian languages")),
    ("otq", _("Querétaro Otomi")),
    ("otr", _("Otoro")),
    ("ots", _("Estado de México Otomi")),
    ("ott", _("Temoaya Otomi")),
    ("otu", _("Otuke")),
    ("otw", _("Ottawa")),
    ("otx", _("Texcatepec Otomi")),
    ("oty", _("Old Tamil")),
    ("otz", _("Ixtenco Otomi")),
    ("oua", _("Tagargrent")),
    ("oub", _("Glio-Oubi")),
    ("oue", _("Oune")),
    ("oui", _("Old Uighur")),
    ("oum", _("Ouma")),
    ("oun", _("ǃOǃung")),
    ("ovd", _("Elfdalian")),
    ("owi", _("Owiniga")),
    ("owl", _("Old Welsh")),
    ("oyb", _("Oy")),
    ("oyd", _("Oyda")),
    ("oym", _("Wayampi")),
    ("oyy", _("Oya'oya")),
    ("ozm", _("Koonzime")),
    ("paa", _("Papuan languages")),
    ("pab", _("Parecís")),
    ("pac", _("Pacoh")),
    ("pad", _("Paumarí")),
    ("pae", _("Pagibete")),
    ("paf", _("Paranawát")),
    ("pag", _("Pangasinan")),
    ("pah", _("Tenharim")),
    ("pai", _("Pe")),
    ("pak", _("Parakanã")),
    ("pal", _("Pahlavi")),
    ("pam", _("Pampanga")),
    ("pao", _("Northern Paiute")),
    ("pap", _("Papiamento")),
    ("paq", _("Parya")),
    ("par", _("Panamint")),
    ("pas", _("Papasena")),
    ("pat", _("Papitalai")),
    ("pau", _("Palauan")),
    ("pav", _("Pakaásnovos")),
    ("paw", _("Pawnee")),
    ("pax", _("Pankararé")),
    ("pay", _("Pech")),
    ("paz", _("Pankararú")),
    ("pbb", _("Páez")),
    ("pbc", _("Patamona")),
    ("pbe", _("Mezontla Popoloca")),
    ("pbf", _("Coyotepec Popoloca")),
    ("pbg", _("Paraujano")),
    ("pbh", _("E'ñapa Woromaipu")),
    ("pbi", _("Parkwa")),
    ("pbl", _("Mak")),
    ("pbm", _("Puebla Mazatec")),
    ("pbn", _("Kpasam")),
    ("pbo", _("Papel")),
    ("pbp", _("Badyara")),
    ("pbr", _("Pangwa")),
    ("pbs", _("Central Pame")),
    ("pbt", _("Southern Pashto")),
    ("pbu", _("Northern Pashto")),
    ("pbv", _("Pnar")),
    ("pby", _("Pyu")),
    ("pbz", _("Palu")),
    ("pca", _("Santa Inés Ahuatempan Popoloca")),
    ("pcb", _("Pear")),
    ("pcc", _("Bouyei")),
    ("pcd", _("Picard")),
    ("pce", _("Ruching Palaung")),
    ("pcf", _("Paliyan")),
    ("pcg", _("Paniya")),
    ("pch", _("Pardhan")),
    ("pci", _("Duruwa")),
    ("pcj", _("Parenga")),
    ("pck", _("Paite Chin")),
    ("pcl", _("Pardhi")),
    ("pcm", _("Nigerian Pidgin")),
    ("pcn", _("Piti")),
    ("pcp", _("Pacahuara")),
    ("pcr", _("Panang")),
    ("pcw", _("Pyapun")),
    ("pda", _("Anam")),
    ("pdc", _("Pennsylvania German")),
    ("pdi", _("Pa Di")),
    ("pdn", _("Podena")),
    ("pdo", _("Padoe")),
    ("pdt", _("Plautdietsch")),
    ("pdu", _("Kayan")),
    ("pea", _("Peranakan Indonesian")),
    ("peb", _("Eastern Pomo")),
    ("ped", _("Mala")),
    ("pee", _("Taje")),
    ("pef", _("Northeastern Pomo")),
    ("peg", _("Pengo")),
    ("peh", _("Bonan")),
    ("pei", _("Chichimeca-Jonaz")),
    ("pej", _("Northern Pomo")),
    ("pek", _("Penchal")),
    ("pel", _("Pekal")),
    ("pem", _("Phende")),
    ("peo", _("Old Persian")),
    ("pep", _("Kunja")),
    ("peq", _("Southern Pomo")),
    ("pes", _("Iranian Persian")),
    ("pev", _("Pémono")),
    ("pex", _("Petats")),
    ("pey", _("Petjo")),
    ("pez", _("Eastern Penan")),
    ("pfa", _("Pááfang")),
    ("pfe", _("Pere")),
    ("pfl", _("Pfaelzisch")),
    ("pga", _("Sudanese Creole Arabic")),
    ("pgd", _("Gāndhārī")),
    ("pgg", _("Pangwali")),
    ("pgi", _("Pagi")),
    ("pgk", _("Rerep")),
    ("pgl", _("Primitive Irish")),
    ("pgn", _("Paelignian")),
    ("pgs", _("Pangseng")),
    ("pgu", _("Pagu")),
    ("pgy", _("Pongyong")),
    ("pgz", _("Papua New Guinean Sign Language")),
    ("pha", _("Pa-Hng")),
    ("phd", _("Phudagi")),
    ("phg", _("Phuong")),
    ("phh", _("Phukha")),
    ("phi", _("Philippine languages")),
    ("phk", _("Phake")),
    ("phl", _("Phalura")),
    ("phm", _("Phimbi")),
    ("phn", _("Phoenician")),
    ("pho", _("Phunoi")),
    ("phq", _("Phana'")),
    ("phr", _("Pahari-Potwari")),
    ("pht", _("Phu Thai")),
    ("phu", _("Phuan")),
    ("phv", _("Pahlavani")),
    ("phw", _("Phangduwali")),
    ("pia", _("Pima Bajo")),
    ("pib", _("Yine")),
    ("pic", _("Pinji")),
    ("pid", _("Piaroa")),
    ("pie", _("Piro")),
    ("pif", _("Pingelapese")),
    ("pig", _("Pisabo")),
    ("pih", _("Pitcairn-Norfolk")),
    ("pii", _("Pini")),
    ("pij", _("Pijao")),
    ("pil", _("Yom")),
    ("pim", _("Powhatan")),
    ("pin", _("Piame")),
    ("pio", _("Piapoco")),
    ("pip", _("Pero")),
    ("pir", _("Piratapuyo")),
    ("pis", _("Pijin")),
    ("pit", _("Pitta Pitta")),
    ("piu", _("Pintupi-Luritja")),
    ("piv", _("Pileni")),
    ("piw", _("Pimbwe")),
    ("pix", _("Piu")),
    ("piy", _("Piya-Kwonci")),
    ("piz", _("Pije")),
    ("pjt", _("Pitjantjatjara")),
    ("pka", _("Ardhamāgadhī Prākrit")),
    ("pkb", _("Pokomo")),
    ("pkc", _("Paekche")),
    ("pkg", _("Pak-Tong")),
    ("pkh", _("Pankhu")),
    ("pkn", _("Pakanha")),
    ("pko", _("Pökoot")),
    ("pkp", _("Pukapuka")),
    ("pkr", _("Attapady Kurumba")),
    ("pks", _("Pakistan Sign Language")),
    ("pkt", _("Maleng")),
    ("pku", _("Paku")),
    ("pla", _("Miani")),
    ("plb", _("Polonombauk")),
    ("plc", _("Central Palawano")),
    ("pld", _("Polari")),
    ("ple", _("Palu'e")),
    ("plf", _("Central Malayo-Polynesian languages")),
    ("plg", _("Pilagá")),
    ("plh", _("Paulohi")),
    ("plj", _("Polci")),
    ("plk", _("Kohistani Shina")),
    ("pll", _("Shwe Palaung")),
    ("pln", _("Palenquero")),
    ("plo", _("Oluta Popoluca")),
    ("plp", _("Palpa")),
    ("plq", _("Palaic")),
    ("plr", _("Palaka Senoufo")),
    ("pls", _("San Marcos Tlacoyalco Popoloca")),
    ("plt", _("Plateau Malagasy")),
    ("plu", _("Palikúr")),
    ("plv", _("Southwest Palawano")),
    ("plw", _("Brooke's Point Palawano")),
    ("ply", _("Bolyu")),
    ("plz", _("Paluan")),
    ("pma", _("Paama")),
    ("pmb", _("Pambia")),
    ("pmc", _("Palumata")),
    ("pmd", _("Pallanganmiddang")),
    ("pme", _("Pwaamei")),
    ("pmf", _("Pamona")),
    ("pmh", _("Māhārāṣṭri Prākrit")),
    ("pmi", _("Northern Pumi")),
    ("pmj", _("Southern Pumi")),
    ("pmk", _("Pamlico")),
    ("pml", _("Lingua Franca")),
    ("pmm", _("Pomo")),
    ("pmn", _("Pam")),
    ("pmo", _("Pom")),
    ("pmq", _("Northern Pame")),
    ("pmr", _("Paynamar")),
    ("pms", _("Piemontese")),
    ("pmt", _("Tuamotuan")),
    ("pmu", _("Mirpur Panjabi")),
    ("pmw", _("Plains Miwok")),
    ("pmx", _("Poumei Naga")),
    ("pmy", _("Papuan Malay")),
    ("pmz", _("Southern Pame")),
    ("pna", _("Punan Bah-Biau")),
    ("pnb", _("Western Panjabi")),
    ("pnc", _("Pannei")),
    ("pnd", _("Mpinda")),
    ("pne", _("Western Penan")),
    ("png", _("Pangu")),
    ("pnh", _("Penrhyn")),
    ("pni", _("Aoheng")),
    ("pnj", _("Pinjarup")),
    ("pnk", _("Paunaka")),
    ("pnl", _("Paleni")),
    ("pnm", _("Punan Batu 1")),
    ("pnn", _("Pinai-Hagahai")),
    ("pno", _("Panobo")),
    ("pnp", _("Pancana")),
    ("pnq", _("Pana")),
    ("pnr", _("Panim")),
    ("pns", _("Ponosakan")),
    ("pnt", _("Pontic")),
    ("pnu", _("Jiongnai Bunu")),
    ("pnv", _("Pinigura")),
    ("pnw", _("Banyjima")),
    ("pnx", _("Phong-Kniang")),
    ("pny", _("Pinyin")),
    ("pnz", _("Pana")),
    ("poc", _("Poqomam")),
    ("pod", _("Ponares")),
    ("poe", _("San Juan Atzingo Popoloca")),
    ("pof", _("Poke")),
    ("pog", _("Potiguára")),
    ("poh", _("Poqomchi'")),
    ("poi", _("Highland Popoluca")),
    ("pok", _("Pokangá")),
    ("pom", _("Southeastern Pomo")),
    ("pon", _("Pohnpeian")),
    ("poo", _("Central Pomo")),
    ("pop", _("Pwapwâ")),
    ("poq", _("Texistepec Popoluca")),
    ("pos", _("Sayula Popoluca")),
    ("pot", _("Potawatomi")),
    ("pov", _("Upper Guinea Crioulo")),
    ("pow", _("San Felipe Otlaltepec Popoloca")),
    ("pox", _("Polabian")),
    ("poy", _("Pogolo")),
    ("poz", _("Malayo-Polynesian languages")),
    ("ppa", _("Pao")),
    ("ppe", _("Papi")),
    ("ppi", _("Paipai")),
    ("ppk", _("Uma")),
    ("ppl", _("Pipil")),
    ("ppm", _("Papuma")),
    ("ppn", _("Papapana")),
    ("ppo", _("Folopa")),
    ("ppp", _("Pelende")),
    ("ppq", _("Pei")),
    ("ppr", _("Piru")),
    ("pps", _("San Luís Temalacayuca Popoloca")),
    ("ppt", _("Pare")),
    ("ppu", _("Papora")),
    ("pqa", _("Pa'a")),
    ("pqe", _("Eastern Malayo-Polynesian languages")),
    ("pqm", _("Malecite-Passamaquoddy")),
    ("pqw", _("Western Malayo-Polynesian languages")),
    ("pra", _("Prakrit languages")),
    ("prb", _("Lua'")),
    ("prc", _("Parachi")),
    ("prd", _("Parsi-Dari")),
    ("pre", _("Principense")),
    ("prf", _("Paranan")),
    ("prg", _("Prussian")),
    ("prh", _("Porohanon")),
    ("pri", _("Paicî")),
    ("prk", _("Parauk")),
    ("prl", _("Peruvian Sign Language")),
    ("prm", _("Kibiri")),
    ("prn", _("Prasuni")),
    ("pro", _("Old Provençal")),
    ("prp", _("Parsi")),
    ("prq", _("Ashéninka Perené")),
    ("prr", _("Puri")),
    ("prs", _("Dari")),
    ("prt", _("Phai")),
    ("pru", _("Puragi")),
    ("prw", _("Parawen")),
    ("prx", _("Purik")),
    ("pry", _("Pray 3")),
    ("prz", _("Providencia Sign Language")),
    ("psa", _("Asue Awyu")),
    ("psc", _("Persian Sign Language")),
    ("psd", _("Plains Indian Sign Language")),
    ("pse", _("Central Malay")),
    ("psg", _("Penang Sign Language")),
    ("psh", _("Southwest Pashai")),
    ("psi", _("Southeast Pashai")),
    ("psl", _("Puerto Rican Sign Language")),
    ("psm", _("Pauserna")),
    ("psn", _("Panasuan")),
    ("pso", _("Polish Sign Language")),
    ("psp", _("Philippine Sign Language")),
    ("psq", _("Pasi")),
    ("psr", _("Portuguese Sign Language")),
    ("pss", _("Kaulong")),
    ("pst", _("Central Pashto")),
    ("psu", _("Sauraseni Prākrit")),
    ("psw", _("Port Sandwich")),
    ("psy", _("Piscataway")),
    ("pta", _("Pai Tavytera")),
    ("pth", _("Pataxó Hã-Ha-Hãe")),
    ("pti", _("Pindiini")),
    ("ptn", _("Patani")),
    ("pto", _("Zo'é")),
    ("ptp", _("Patep")),
    ("ptq", _("Pattapu")),
    ("ptr", _("Piamatsina")),
    ("ptt", _("Enrekang")),
    ("ptu", _("Bambam")),
    ("ptv", _("Port Vato")),
    ("ptw", _("Pentlatch")),
    ("pty", _("Pathiya")),
    ("pua", _("Western Highland Purepecha")),
    ("pub", _("Purum")),
    ("puc", _("Punan Merap")),
    ("pud", _("Punan Aput")),
    ("pue", _("Puelche")),
    ("puf", _("Punan Merah")),
    ("pug", _("Phuie")),
    ("pui", _("Puinave")),
    ("puj", _("Punan Tubu")),
    ("puk", _("Pu Ko")),
    ("pum", _("Puma")),
    ("puo", _("Puoc")),
    ("pup", _("Pulabu")),
    ("puq", _("Puquina")),
    ("pur", _("Puruborá")),
    ("put", _("Putoh")),
    ("puu", _("Punu")),
    ("puw", _("Puluwatese")),
    ("pux", _("Puare")),
    ("puy", _("Purisimeño")),
    ("puz", _("Purum Naga")),
    ("pwa", _("Pawaia")),
    ("pwb", _("Panawa")),
    ("pwg", _("Gapapaiwa")),
    ("pwi", _("Patwin")),
    ("pwm", _("Molbog")),
    ("pwn", _("Paiwan")),
    ("pwo", _("Pwo Western Karen")),
    ("pwr", _("Powari")),
    ("pww", _("Pwo Northern Karen")),
    ("pxm", _("Quetzaltepec Mixe")),
    ("pye", _("Pye Krumen")),
    ("pym", _("Fyam")),
    ("pyn", _("Poyanáwa")),
    ("pys", _("Paraguayan Sign Language")),
    ("pyu", _("Puyuma")),
    ("pyx", _("Pyu")),
    ("pyy", _("Pyen")),
    ("pzn", _("Para Naga")),
    ("qua", _("Quapaw")),
    ("qub", _("Huallaga Huánuco Quechua")),
    ("quc", _("K'iche'")),
    ("qud", _("Calderón Highland Quichua")),
    ("quf", _("Lambayeque Quechua")),
    ("qug", _("Chimborazo Highland Quichua")),
    ("quh", _("South Bolivian Quechua")),
    ("qui", _("Quileute")),
    ("quk", _("Chachapoyas Quechua")),
    ("qul", _("North Bolivian Quechua")),
    ("qum", _("Sipacapense")),
    ("qun", _("Quinault")),
    ("qup", _("Southern Pastaza Quechua")),
    ("quq", _("Quinqui")),
    ("qur", _("Yanahuanca Pasco Quechua")),
    ("qus", _("Santiago del Estero Quichua")),
    ("quv", _("Sacapulteco")),
    ("quw", _("Tena Lowland Quichua")),
    ("qux", _("Yauyos Quechua")),
    ("quy", _("Ayacucho Quechua")),
    ("quz", _("Cusco Quechua")),
    ("qva", _("Ambo-Pasco Quechua")),
    ("qvc", _("Cajamarca Quechua")),
    ("qve", _("Eastern Apurímac Quechua")),
    ("qvh", _("Huamalíes-Dos de Mayo Huánuco Quechua")),
    ("qvi", _("Imbabura Highland Quichua")),
    ("qvj", _("Loja Highland Quichua")),
    ("qvl", _("Cajatambo North Lima Quechua")),
    ("qvm", _("Margos-Yarowilca-Lauricocha Quechua")),
    ("qvn", _("North Junín Quechua")),
    ("qvo", _("Napo Lowland Quechua")),
    ("qvp", _("Pacaraos Quechua")),
    ("qvs", _("San Martín Quechua")),
    ("qvw", _("Huaylla Wanca Quechua")),
    ("qvy", _("Queyu")),
    ("qvz", _("Northern Pastaza Quichua")),
    ("qwa", _("Corongo Ancash Quechua")),
    ("qwc", _("Classical Quechua")),
    ("qwe", _("Quechuan")),
    ("qwh", _("Huaylas Ancash Quechua")),
    ("qwm", _("Kuman")),
    ("qws", _("Sihuas Ancash Quechua")),
    ("qwt", _("Kwalhioqua-Tlatskanai")),
    ("qxa", _("Chiquián Ancash Quechua")),
    ("qxc", _("Chincha Quechua")),
    ("qxh", _("Panao Huánuco Quechua")),
    ("qxl", _("Salasaca Highland Quichua")),
    ("qxn", _("Northern Conchucos Ancash Quechua")),
    ("qxo", _("Southern Conchucos Ancash Quechua")),
    ("qxp", _("Puno Quechua")),
    ("qxq", _("Qashqa'i")),
    ("qxr", _("Cañar Highland Quichua")),
    ("qxs", _("Southern Qiang")),
    ("qxt", _("Santa Ana de Tusi Pasco Quechua")),
    ("qxu", _("Arequipa-La Unión Quechua")),
    ("qxw", _("Jauja Wanca Quechua")),
    ("qya", _("Quenya")),
    ("qyp", _("Quiripi")),
    ("raa", _("Dungmali")),
    ("rab", _("Camling")),
    ("rac", _("Rasawa")),
    ("rad", _("Rade")),
    ("raf", _("Western Meohang")),
    ("rag", _("Logooli")),
    ("rah", _("Rabha")),
    ("rai", _("Ramoaaina")),
    ("raj", _("Rajasthani")),
    ("rak", _("Tulu-Bohuai")),
    ("ral", _("Ralte")),
    ("ram", _("Canela")),
    ("ran", _("Riantana")),
    ("rao", _("Rao")),
    ("rap", _("Rapanui")),
    ("raq", _("Saam")),
    ("rar", _("Rarotongan")),
    ("ras", _("Tegali")),
    ("rat", _("Razajerdi")),
    ("rau", _("Raute")),
    ("rav", _("Sampang")),
    ("raw", _("Rawang")),
    ("rax", _("Rang")),
    ("ray", _("Rapa")),
    ("raz", _("Rahambuu")),
    ("rbb", _("Rumai Palaung")),
    ("rbk", _("Northern Bontok")),
    ("rbl", _("Miraya Bikol")),
    ("rbp", _("Barababaraba")),
    ("rcf", _("Réunion Creole French")),
    ("rdb", _("Rudbari")),
    ("rea", _("Rerau")),
    ("reb", _("Rembong")),
    ("ree", _("Rejang Kayan")),
    ("reg", _("Kara")),
    ("rei", _("Reli")),
    ("rej", _("Rejang")),
    ("rel", _("Rendille")),
    ("rem", _("Remo")),
    ("ren", _("Rengao")),
    ("rer", _("Rer Bare")),
    ("res", _("Reshe")),
    ("ret", _("Retta")),
    ("rey", _("Reyesano")),
    ("rga", _("Roria")),
    ("rge", _("Romano-Greek")),
    ("rgk", _("Rangkas")),
    ("rgn", _("Romagnol")),
    ("rgr", _("Resígaro")),
    ("rgs", _("Southern Roglai")),
    ("rgu", _("Ringgou")),
    ("rhg", _("Rohingya")),
    ("rhp", _("Yahang")),
    ("ria", _("Riang")),
    ("rie", _("Rien")),
    ("rif", _("Tarifit")),
    ("ril", _("Riang Lang")),
    ("rim", _("Nyaturu")),
    ("rin", _("Nungu")),
    ("rir", _("Ribun")),
    ("rit", _("Ritharrngu")),
    ("riu", _("Riung")),
    ("rjg", _("Rajong")),
    ("rji", _("Raji")),
    ("rjs", _("Rajbanshi")),
    ("rka", _("Kraol")),
    ("rkb", _("Rikbaktsa")),
    ("rkh", _("Rakahanga-Manihiki")),
    ("rki", _("Rakhine")),
    ("rkm", _("Marka")),
    ("rkt", _("Rangpuri")),
    ("rkw", _("Arakwal")),
    ("rma", _("Rama")),
    ("rmb", _("Rembarrnga")),
    ("rmc", _("Carpathian Romani")),
    ("rmd", _("Traveller Danish")),
    ("rme", _("Angloromani")),
    ("rmf", _("Kalo Finnish Romani")),
    ("rmg", _("Traveller Norwegian")),
    ("rmh", _("Murkim")),
    ("rmi", _("Lomavren")),
    ("rmk", _("Romkun")),
    ("rml", _("Baltic Romani")),
    ("rmm", _("Roma")),
    ("rmn", _("Balkan Romani")),
    ("rmo", _("Sinte Romani")),
    ("rmp", _("Rempi")),
    ("rmq", _("Caló")),
    ("rmr", _("Caló")),
    ("rms", _("Romanian Sign Language")),
    ("rmt", _("Domari")),
    ("rmu", _("Tavringer Romani")),
    ("rmv", _("Romanova")),
    ("rmw", _("Welsh Romani")),
    ("rmx", _("Romam")),
    ("rmy", _("Vlax Romani")),
    ("rmz", _("Marma")),
    ("rna", _("Runa")),
    ("rnd", _("Ruund")),
    ("rng", _("Ronga")),
    ("rnl", _("Ranglong")),
    ("rnn", _("Roon")),
    ("rnp", _("Rongpo")),
    ("rnr", _("Nari Nari")),
    ("rnw", _("Rungwa")),
    ("roa", _("Romance languages")),
    ("rob", _("Tae'")),
    ("roc", _("Cacgia Roglai")),
    ("rod", _("Rogo")),
    ("roe", _("Ronji")),
    ("rof", _("Rombo")),
    ("rog", _("Northern Roglai")),
    ("rol", _("Romblomanon")),
    ("rom", _("Romany")),
    ("roo", _("Rotokas")),
    ("rop", _("Kriol")),
    ("ror", _("Rongga")),
    ("rou", _("Runga")),
    ("row", _("Dela-Oenale")),
    ("rpn", _("Repanbitip")),
    ("rpt", _("Rapting")),
    ("rri", _("Ririo")),
    ("rro", _("Waima")),
    ("rrt", _("Arritinngithigh")),
    ("rsb", _("Romano-Serbian")),
    ("rsi", _("Rennellese Sign Language")),
    ("rsl", _("Russian Sign Language")),
    ("rsm", _("Miriwoong Sign Language")),
    ("rtc", _("Rungtu Chin")),
    ("rth", _("Ratahan")),
    ("rtm", _("Rotuman")),
    ("rts", _("Yurats")),
    ("rtw", _("Rathawi")),
    ("rub", _("Gungu")),
    ("ruc", _("Ruuli")),
    ("rue", _("Rusyn")),
    ("ruf", _("Luguru")),
    ("rug", _("Roviana")),
    ("ruh", _("Ruga")),
    ("rui", _("Rufiji")),
    ("ruk", _("Che")),
    ("ruo", _("Istro Romanian")),
    ("rup", _("Macedo-Romanian")),
    ("ruq", _("Megleno Romanian")),
    ("rut", _("Rutul")),
    ("ruu", _("Lanas Lobu")),
    ("ruy", _("Mala")),
    ("ruz", _("Ruma")),
    ("rwa", _("Rawo")),
    ("rwk", _("Rwa")),
    ("rwl", _("Ruwila")),
    ("rwm", _("Amba")),
    ("rwo", _("Rawa")),
    ("rwr", _("Marwari")),
    ("rxd", _("Ngardi")),
    ("rxw", _("Karuwali")),
    ("ryn", _("Northern Amami-Oshima")),
    ("rys", _("Yaeyama")),
    ("ryu", _("Central Okinawan")),
    ("rzh", _("Rāziḥī")),
    ("saa", _("Saba")),
    ("sab", _("Buglere")),
    ("sac", _("Meskwaki")),
    ("sad", _("Sandawe")),
    ("sae", _("Sabanê")),
    ("saf", _("Safaliba")),
    ("sah", _("Yakut")),
    ("sai", _("South American Indian languages")),
    ("saj", _("Sahu")),
    ("sak", _("Sake")),
    ("sal", _("Salishan languages")),
    ("sam", _("Samaritan Aramaic")),
    ("sao", _("Sause")),
    ("sap", _("Sanapaná")),
    ("saq", _("Samburu")),
    ("sar", _("Saraveca")),
    ("sas", _("Sasak")),
    ("sat", _("Santali")),
    ("sau", _("Saleman")),
    ("sav", _("Saafi-Saafi")),
    ("saw", _("Sawi")),
    ("sax", _("Sa")),
    ("say", _("Saya")),
    ("saz", _("Saurashtra")),
    ("sba", _("Ngambay")),
    ("sbb", _("Simbo")),
    ("sbc", _("Kele")),
    ("sbd", _("Southern Samo")),
    ("sbe", _("Saliba")),
    ("sbf", _("Chabu")),
    ("sbg", _("Seget")),
    ("sbh", _("Sori-Harengan")),
    ("sbi", _("Seti")),
    ("sbj", _("Surbakhal")),
    ("sbk", _("Safwa")),
    ("sbl", _("Botolan Sambal")),
    ("sbm", _("Sagala")),
    ("sbn", _("Sindhi Bhil")),
    ("sbo", _("Sabüm")),
    ("sbp", _("Sangu")),
    ("sbq", _("Sileibi")),
    ("sbr", _("Sembakung Murut")),
    ("sbs", _("Subiya")),
    ("sbt", _("Kimki")),
    ("sbu", _("Stod Bhoti")),
    ("sbv", _("Sabine")),
    ("sbw", _("Simba")),
    ("sbx", _("Seberuang")),
    ("sby", _("Soli")),
    ("sbz", _("Sara Kaba")),
    ("sca", _("Sansu")),
    ("scb", _("Chut")),
    ("sce", _("Dongxiang")),
    ("scf", _("San Miguel Creole French")),
    ("scg", _("Sanggau")),
    ("sch", _("Sakachep")),
    ("sci", _("Sri Lankan Creole Malay")),
    ("sck", _("Sadri")),
    ("scl", _("Shina")),
    ("scn", _("Sicilian")),
    ("sco", _("Scots")),
    ("scp", _("Hyolmo")),
    ("scq", _("Sa'och")),
    ("scs", _("North Slavey")),
    ("sct", _("Southern Katang")),
    ("scu", _("Shumcho")),
    ("scv", _("Sheni")),
    ("scw", _("Sha")),
    ("scx", _("Sicel")),
    ("sda", _("Toraja-Sa'dan")),
    ("sdb", _("Shabak")),
    ("sdc", _("Sassarese Sardinian")),
    ("sde", _("Surubu")),
    ("sdf", _("Sarli")),
    ("sdg", _("Savi")),
    ("sdh", _("Southern Kurdish")),
    ("sdj", _("Suundi")),
    ("sdk", _("Sos Kundi")),
    ("sdl", _("Saudi Arabian Sign Language")),
    ("sdm", _("Semandang")),
    ("sdn", _("Gallurese Sardinian")),
    ("sdo", _("Bukar-Sadung Bidayuh")),
    ("sdp", _("Sherdukpen")),
    ("sdq", _("Semandang")),
    ("sdr", _("Oraon Sadri")),
    ("sds", _("Sened")),
    ("sdt", _("Shuadit")),
    ("sdu", _("Sarudu")),
    ("sdv", _("Eastern Sudanic languages")),
    ("sdx", _("Sibu Melanau")),
    ("sdz", _("Sallands")),
    ("sea", _("Semai")),
    ("seb", _("Shempire Senoufo")),
    ("sec", _("Sechelt")),
    ("sed", _("Sedang")),
    ("see", _("Seneca")),
    ("sef", _("Cebaara Senoufo")),
    ("seg", _("Segeju")),
    ("seh", _("Sena")),
    ("sei", _("Seri")),
    ("sej", _("Sene")),
    ("sek", _("Sekani")),
    ("sel", _("Selkup")),
    ("sem", _("Semitic languages")),
    ("sen", _("Nanerigé Sénoufo")),
    ("seo", _("Suarmin")),
    ("sep", _("Sìcìté Sénoufo")),
    ("seq", _("Senara Sénoufo")),
    ("ser", _("Serrano")),
    ("ses", _("Koyraboro Senni Songhai")),
    ("set", _("Sentani")),
    ("seu", _("Serui-Laut")),
    ("sev", _("Nyarafolo Senoufo")),
    ("sew", _("Sewa Bay")),
    ("sey", _("Secoya")),
    ("sez", _("Senthang Chin")),
    ("sfb", _("Langue des signes de Belgique Francophone")),
    ("sfe", _("Eastern Subanen")),
    ("sfm", _("Small Flowery Miao")),
    ("sfs", _("South African Sign Language")),
    ("sfw", _("Sehwi")),
    ("sga", _("Old Irish")),
    ("sgb", _("Mag-antsi Ayta")),
    ("sgc", _("Kipsigis")),
    ("sgd", _("Surigaonon")),
    ("sge", _("Segai")),
    ("sgg", _("Swiss-German Sign Language")),
    ("sgh", _("Shughni")),
    ("sgi", _("Suga")),
    ("sgj", _("Surgujia")),
    ("sgk", _("Sangkong")),
    ("sgl", _("Sanglechi-Ishkashimi")),
    ("sgm", _("Singa")),
    ("sgn", _("Sign languages")),
    ("sgo", _("Songa")),
    ("sgp", _("Singpho")),
    ("sgr", _("Sangisari")),
    ("sgs", _("Samogitian")),
    ("sgt", _("Brokpake")),
    ("sgu", _("Salas")),
    ("sgw", _("Sebat Bet Gurage")),
    ("sgx", _("Sierra Leone Sign Language")),
    ("sgy", _("Sanglechi")),
    ("sgz", _("Sursurunga")),
    ("sha", _("Shall-Zwall")),
    ("shb", _("Ninam")),
    ("shc", _("Sonde")),
    ("shd", _("Kundal Shahi")),
    ("she", _("Sheko")),
    ("shg", _("Shua")),
    ("shh", _("Shoshoni")),
    ("shi", _("Tachelhit")),
    ("shj", _("Shatt")),
    ("shk", _("Shilluk")),
    ("shl", _("Shendu")),
    ("shm", _("Shahrudi")),
    ("shn", _("Shan")),
    ("sho", _("Shanga")),
    ("shp", _("Shipibo-Conibo")),
    ("shq", _("Sala")),
    ("shr", _("Shi")),
    ("shs", _("Shuswap")),
    ("sht", _("Shasta")),
    ("shu", _("Chadian Arabic")),
    ("shv", _("Shehri")),
    ("shw", _("Shwai")),
    ("shx", _("She")),
    ("shy", _("Tachawit")),
    ("shz", _("Syenara Senoufo")),
    ("sia", _("Akkala Sami")),
    ("sib", _("Sebop")),
    ("sid", _("Sidamo")),
    ("sie", _("Simaa")),
    ("sif", _("Siamou")),
    ("sig", _("Paasaal")),
    ("sih", _("Zire")),
    ("sii", _("Shom Peng")),
    ("sij", _("Numbami")),
    ("sik", _("Sikiana")),
    ("sil", _("Tumulung Sisaala")),
    ("sim", _("Mende")),
    ("sio", _("Siouan languages")),
    ("sip", _("Sikkimese")),
    ("siq", _("Sonia")),
    ("sir", _("Siri")),
    ("sis", _("Siuslaw")),
    ("sit", _("Sino-Tibetan languages")),
    ("siu", _("Sinagen")),
    ("siv", _("Sumariup")),
    ("siw", _("Siwai")),
    ("six", _("Sumau")),
    ("siy", _("Sivandi")),
    ("siz", _("Siwi")),
    ("sja", _("Epena")),
    ("sjb", _("Sajau Basap")),
    ("sjd", _("Kildin Sami")),
    ("sje", _("Pite Sami")),
    ("sjg", _("Assangori")),
    ("sjk", _("Kemi Sami")),
    ("sjl", _("Sajalong")),
    ("sjm", _("Mapun")),
    ("sjn", _("Sindarin")),
    ("sjo", _("Xibe")),
    ("sjp", _("Surjapuri")),
    ("sjr", _("Siar-Lak")),
    ("sjs", _("Senhaja De Srair")),
    ("sjt", _("Ter Sami")),
    ("sju", _("Ume Sami")),
    ("sjw", _("Shawnee")),
    ("ska", _("Skagit")),
    ("skb", _("Saek")),
    ("skc", _("Ma Manda")),
    ("skd", _("Southern Sierra Miwok")),
    ("ske", _("Seke")),
    ("skf", _("Sakirabiá")),
    ("skg", _("Sakalava Malagasy")),
    ("skh", _("Sikule")),
    ("ski", _("Sika")),
    ("skj", _("Seke")),
    ("skk", _("Sok")),
    ("skm", _("Kutong")),
    ("skn", _("Kolibugan Subanon")),
    ("sko", _("Seko Tengah")),
    ("skp", _("Sekapan")),
    ("skq", _("Sininkere")),
    ("skr", _("Saraiki")),
    ("sks", _("Maia")),
    ("skt", _("Sakata")),
    ("sku", _("Sakao")),
    ("skv", _("Skou")),
    ("skw", _("Skepi Creole Dutch")),
    ("skx", _("Seko Padang")),
    ("sky", _("Sikaiana")),
    ("skz", _("Sekar")),
    ("sla", _("Slavic languages")),
    ("slc", _("Sáliba")),
    ("sld", _("Sissala")),
    ("sle", _("Sholaga")),
    ("slf", _("Swiss-Italian Sign Language")),
    ("slg", _("Selungai Murut")),
    ("slh", _("Southern Puget Sound Salish")),
    ("sli", _("Lower Silesian")),
    ("slj", _("Salumá")),
    ("sll", _("Salt-Yui")),
    ("slm", _("Pangutaran Sama")),
    ("sln", _("Salinan")),
    ("slp", _("Lamaholot")),
    ("slq", _("Salchuq")),
    ("slr", _("Salar")),
    ("sls", _("Singapore Sign Language")),
    ("slt", _("Sila")),
    ("slu", _("Selaru")),
    ("slw", _("Sialum")),
    ("slx", _("Salampasu")),
    ("sly", _("Selayar")),
    ("slz", _("Ma'ya")),
    ("sma", _("Southern Sami")),
    ("smb", _("Simbari")),
    ("smc", _("Som")),
    ("smd", _("Sama")),
    ("smf", _("Auwe")),
    ("smg", _("Simbali")),
    ("smh", _("Samei")),
    ("smi", _("Sami languages")),
    ("smj", _("Lule Sami")),
    ("smk", _("Bolinao")),
    ("sml", _("Central Sama")),
    ("smm", _("Musasa")),
    ("smn", _("Inari Sami")),
    ("smp", _("Samaritan")),
    ("smq", _("Samo")),
    ("smr", _("Simeulue")),
    ("sms", _("Skolt Sami")),
    ("smt", _("Simte")),
    ("smu", _("Somray")),
    ("smv", _("Samvedi")),
    ("smw", _("Sumbawa")),
    ("smx", _("Samba")),
    ("smy", _("Semnani")),
    ("smz", _("Simeku")),
    ("snb", _("Sebuyau")),
    ("snc", _("Sinaugoro")),
    ("sne", _("Bau Bidayuh")),
    ("snf", _("Noon")),
    ("sng", _("Sanga")),
    ("snh", _("Shinabo")),
    ("sni", _("Sensi")),
    ("snj", _("Riverain Sango")),
    ("snk", _("Soninke")),
    ("snl", _("Sangil")),
    ("snm", _("Southern Ma'di")),
    ("snn", _("Siona")),
    ("sno", _("Snohomish")),
    ("snp", _("Siane")),
    ("snq", _("Sangu")),
    ("snr", _("Sihan")),
    ("sns", _("South West Bay")),
    ("snu", _("Senggi")),
    ("snv", _("Sa'ban")),
    ("snw", _("Selee")),
    ("snx", _("Sam")),
    ("sny", _("Saniyo-Hiyewe")),
    ("snz", _("Kou")),
    ("soa", _("Thai Song")),
    ("sob", _("Sobei")),
    ("soc", _("So")),
    ("sod", _("Songoora")),
    ("soe", _("Songomeno")),
    ("sog", _("Sogdian")),
    ("soh", _("Aka")),
    ("soi", _("Sonha")),
    ("soj", _("Soi")),
    ("sok", _("Sokoro")),
    ("sol", _("Solos")),
    ("son", _("Songhai languages")),
    ("soo", _("Songo")),
    ("sop", _("Songe")),
    ("soq", _("Kanasi")),
    ("sor", _("Somrai")),
    ("sos", _("Seeku")),
    ("sou", _("Southern Thai")),
    ("sov", _("Sonsorol")),
    ("sow", _("Sowanda")),
    ("sox", _("Swo")),
    ("soy", _("Miyobe")),
    ("soz", _("Temi")),
    ("spb", _("Sepa")),
    ("spc", _("Sapé")),
    ("spd", _("Saep")),
    ("spe", _("Sepa")),
    ("spg", _("Sian")),
    ("spi", _("Saponi")),
    ("spk", _("Sengo")),
    ("spl", _("Selepet")),
    ("spm", _("Akukem")),
    ("spn", _("Sanapaná")),
    ("spo", _("Spokane")),
    ("spp", _("Supyire Senoufo")),
    ("spq", _("Loreto-Ucayali Spanish")),
    ("spr", _("Saparua")),
    ("sps", _("Saposa")),
    ("spt", _("Spiti Bhoti")),
    ("spu", _("Sapuan")),
    ("spv", _("Sambalpuri")),
    ("spx", _("South Picene")),
    ("spy", _("Sabaot")),
    ("sqa", _("Shama-Sambuga")),
    ("sqh", _("Shau")),
    ("sqj", _("Albanian languages")),
    ("sqk", _("Albanian Sign Language")),
    ("sqm", _("Suma")),
    ("sqn", _("Susquehannock")),
    ("sqo", _("Sorkhei")),
    ("sqq", _("Sou")),
    ("sqr", _("Siculo Arabic")),
    ("sqs", _("Sri Lankan Sign Language")),
    ("sqt", _("Soqotri")),
    ("squ", _("Squamish")),
    ("sqx", _("Kufr Qassem Sign Language")),
    ("sra", _("Saruga")),
    ("srb", _("Sora")),
    ("src", _("Logudorese Sardinian")),
    ("sre", _("Sara")),
    ("srf", _("Nafi")),
    ("srg", _("Sulod")),
    ("srh", _("Sarikoli")),
    ("sri", _("Siriano")),
    ("srk", _("Serudung Murut")),
    ("srl", _("Isirawa")),
    ("srm", _("Saramaccan")),
    ("srn", _("Sranan Tongo")),
    ("sro", _("Campidanese Sardinian")),
    ("srq", _("Sirionó")),
    ("srr", _("Serer")),
    ("srs", _("Sarsi")),
    ("srt", _("Sauri")),
    ("sru", _("Suruí")),
    ("srv", _("Southern Sorsoganon")),
    ("srw", _("Serua")),
    ("srx", _("Sirmauri")),
    ("sry", _("Sera")),
    ("srz", _("Shahmirzadi")),
    ("ssa", _("Nilo-Saharan languages")),
    ("ssb", _("Southern Sama")),
    ("ssc", _("Suba-Simbiti")),
    ("ssd", _("Siroi")),
    ("sse", _("Balangingi")),
    ("ssf", _("Thao")),
    ("ssg", _("Seimat")),
    ("ssh", _("Shihhi Arabic")),
    ("ssi", _("Sansi")),
    ("ssj", _("Sausi")),
    ("ssk", _("Sunam")),
    ("ssl", _("Western Sisaala")),
    ("ssm", _("Semnam")),
    ("ssn", _("Waata")),
    ("sso", _("Sissano")),
    ("ssp", _("Spanish Sign Language")),
    ("ssq", _("So'a")),
    ("ssr", _("Swiss-French Sign Language")),
    ("sss", _("Sô")),
    ("sst", _("Sinasina")),
    ("ssu", _("Susuami")),
    ("ssv", _("Shark Bay")),
    ("ssx", _("Samberigi")),
    ("ssy", _("Saho")),
    ("ssz", _("Sengseng")),
    ("sta", _("Settla")),
    ("stb", _("Northern Subanen")),
    ("std", _("Sentinel")),
    ("ste", _("Liana-Seti")),
    ("stf", _("Seta")),
    ("stg", _("Trieng")),
    ("sth", _("Shelta")),
    ("sti", _("Bulo Stieng")),
    ("stj", _("Matya Samo")),
    ("stk", _("Arammba")),
    ("stl", _("Stellingwerfs")),
    ("stm", _("Setaman")),
    ("stn", _("Owa")),
    ("sto", _("Stoney")),
    ("stp", _("Southeastern Tepehuan")),
    ("stq", _("Saterfriesisch")),
    ("str", _("Straits Salish")),
    ("sts", _("Shumashti")),
    ("stt", _("Budeh Stieng")),
    ("stu", _("Samtao")),
    ("stv", _("Silt'e")),
    ("stw", _("Satawalese")),
    ("sty", _("Siberian Tatar")),
    ("sua", _("Sulka")),
    ("sub", _("Suku")),
    ("suc", _("Western Subanon")),
    ("sue", _("Suena")),
    ("sug", _("Suganga")),
    ("sui", _("Suki")),
    ("suj", _("Shubi")),
    ("suk", _("Sukuma")),
    ("sul", _("Surigaonon")),
    ("sum", _("Sumo-Mayangna")),
    ("suo", _("Bouni")),
    ("suq", _("Tirmaga-Chai Suri")),
    ("sur", _("Mwaghavul")),
    ("sus", _("Susu")),
    ("sut", _("Subtiaba")),
    ("suv", _("Puroik")),
    ("suw", _("Sumbwa")),
    ("sux", _("Sumerian")),
    ("suy", _("Suyá")),
    ("suz", _("Sunwar")),
    ("sva", _("Svan")),
    ("svb", _("Ulau-Suain")),
    ("svc", _("Vincentian Creole English")),
    ("sve", _("Serili")),
    ("svk", _("Slovakian Sign Language")),
    ("svm", _("Slavomolisano")),
    ("svr", _("Savara")),
    ("svs", _("Savosavo")),
    ("svx", _("Skalvian")),
    ("swb", _("Maore Comorian")),
    ("swc", _("Congo Swahili")),
    ("swf", _("Sere")),
    ("swg", _("Swabian")),
    ("swh", _("Swahili")),
    ("swi", _("Sui")),
    ("swj", _("Sira")),
    ("swk", _("Malawi Sena")),
    ("swl", _("Swedish Sign Language")),
    ("swm", _("Samosa")),
    ("swn", _("Sawknah")),
    ("swo", _("Shanenawa")),
    ("swp", _("Suau")),
    ("swq", _("Sharwa")),
    ("swr", _("Saweru")),
    ("sws", _("Seluwasan")),
    ("swt", _("Sawila")),
    ("swu", _("Suwawa")),
    ("swv", _("Shekhawati")),
    ("sww", _("Sowa")),
    ("swx", _("Suruahá")),
    ("swy", _("Sarua")),
    ("sxb", _("Suba")),
    ("sxc", _("Sicanian")),
    ("sxe", _("Sighu")),
    ("sxg", _("Shuhi")),
    ("sxk", _("Southern Kalapuya")),
    ("sxl", _("Selian")),
    ("sxm", _("Samre")),
    ("sxn", _("Sangir")),
    ("sxo", _("Sorothaptic")),
    ("sxr", _("Saaroa")),
    ("sxs", _("Sasaru")),
    ("sxu", _("Upper Saxon")),
    ("sxw", _("Saxwe Gbe")),
    ("sya", _("Siang")),
    ("syb", _("Central Subanen")),
    ("syc", _("Classical Syriac")),
    ("syd", _("Samoyedic languages")),
    ("syi", _("Seki")),
    ("syk", _("Sukur")),
    ("syl", _("Sylheti")),
    ("sym", _("Maya Samo")),
    ("syn", _("Senaya")),
    ("syo", _("Suoy")),
    ("syr", _("Syriac")),
    ("sys", _("Sinyar")),
    ("syw", _("Kagate")),
    ("syx", _("Samay")),
    ("syy", _("Al-Sayyid Bedouin Sign Language")),
    ("sza", _("Semelai")),
    ("szb", _("Ngalum")),
    ("szc", _("Semaq Beri")),
    ("szd", _("Seru")),
    ("sze", _("Seze")),
    ("szg", _("Sengele")),
    ("szl", _("Silesian")),
    ("szn", _("Sula")),
    ("szp", _("Suabo")),
    ("szs", _("Solomon Islands Sign Language")),
    ("szv", _("Isu")),
    ("szw", _("Sawai")),
    ("szy", _("Sakizaya")),
    ("taa", _("Lower Tanana")),
    ("tab", _("Tabassaran")),
    ("tac", _("Lowland Tarahumara")),
    ("tad", _("Tause")),
    ("tae", _("Tariana")),
    ("taf", _("Tapirapé")),
    ("tag", _("Tagoi")),
    ("tai", _("Tai languages")),
    ("taj", _("Eastern Tamang")),
    ("tak", _("Tala")),
    ("tal", _("Tal")),
    ("tan", _("Tangale")),
    ("tao", _("Yami")),
    ("tap", _("Taabwa")),
    ("taq", _("Tamasheq")),
    ("tar", _("Central Tarahumara")),
    ("tas", _("Tay Boi")),
    ("tau", _("Upper Tanana")),
    ("tav", _("Tatuyo")),
    ("taw", _("Tai")),
    ("tax", _("Tamki")),
    ("tay", _("Atayal")),
    ("taz", _("Tocho")),
    ("tba", _("Aikanã")),
    ("tbb", _("Tapeba")),
    ("tbc", _("Takia")),
    ("tbd", _("Kaki Ae")),
    ("tbe", _("Tanimbili")),
    ("tbf", _("Mandara")),
    ("tbg", _("North Tairora")),
    ("tbh", _("Dharawal")),
    ("tbi", _("Gaam")),
    ("tbj", _("Tiang")),
    ("tbk", _("Calamian Tagbanwa")),
    ("tbl", _("Tboli")),
    ("tbm", _("Tagbu")),
    ("tbn", _("Barro Negro Tunebo")),
    ("tbo", _("Tawala")),
    ("tbp", _("Taworta")),
    ("tbq", _("Tibeto-Burman languages")),
    ("tbr", _("Tumtum")),
    ("tbs", _("Tanguat")),
    ("tbt", _("Tembo")),
    ("tbu", _("Tubar")),
    ("tbv", _("Tobo")),
    ("tbw", _("Tagbanwa")),
    ("tbx", _("Kapin")),
    ("tby", _("Tabaru")),
    ("tbz", _("Ditammari")),
    ("tca", _("Ticuna")),
    ("tcb", _("Tanacross")),
    ("tcc", _("Datooga")),
    ("tcd", _("Tafi")),
    ("tce", _("Southern Tutchone")),
    ("tcf", _("Malinaltepec Me'phaa")),
    ("tcg", _("Tamagario")),
    ("tch", _("Turks And Caicos Creole English")),
    ("tci", _("Wára")),
    ("tck", _("Tchitchege")),
    ("tcl", _("Taman")),
    ("tcm", _("Tanahmerah")),
    ("tcn", _("Tichurong")),
    ("tco", _("Taungyo")),
    ("tcp", _("Tawr Chin")),
    ("tcq", _("Kaiy")),
    ("tcs", _("Torres Strait Creole")),
    ("tct", _("T'en")),
    ("tcu", _("Southeastern Tarahumara")),
    ("tcw", _("Tecpatlán Totonac")),
    ("tcx", _("Toda")),
    ("tcy", _("Tulu")),
    ("tcz", _("Thado Chin")),
    ("tda", _("Tagdal")),
    ("tdb", _("Panchpargania")),
    ("tdc", _("Emberá-Tadó")),
    ("tdd", _("Tai Nüa")),
    ("tde", _("Tiranige Diga Dogon")),
    ("tdf", _("Talieng")),
    ("tdg", _("Western Tamang")),
    ("tdh", _("Thulung")),
    ("tdi", _("Tomadino")),
    ("tdj", _("Tajio")),
    ("tdk", _("Tambas")),
    ("tdl", _("Sur")),
    ("tdm", _("Taruma")),
    ("tdn", _("Tondano")),
    ("tdo", _("Teme")),
    ("tdq", _("Tita")),
    ("tdr", _("Todrah")),
    ("tds", _("Doutai")),
    ("tdt", _("Tetun Dili")),
    ("tdu", _("Tempasuk Dusun")),
    ("tdv", _("Toro")),
    ("tdx", _("Tandroy-Mahafaly Malagasy")),
    ("tdy", _("Tadyawan")),
    ("tea", _("Temiar")),
    ("teb", _("Tetete")),
    ("tec", _("Terik")),
    ("ted", _("Tepo Krumen")),
    ("tee", _("Huehuetla Tepehua")),
    ("tef", _("Teressa")),
    ("teg", _("Teke-Tege")),
    ("teh", _("Tehuelche")),
    ("tei", _("Torricelli")),
    ("tek", _("Ibali Teke")),
    ("tem", _("Timne")),
    ("ten", _("Tama")),
    ("teo", _("Teso")),
    ("tep", _("Tepecano")),
    ("teq", _("Temein")),
    ("ter", _("Tereno")),
    ("tes", _("Tengger")),
    ("tet", _("Tetum")),
    ("teu", _("Soo")),
    ("tev", _("Teor")),
    ("tew", _("Tewa")),
    ("tex", _("Tennet")),
    ("tey", _("Tulishi")),
    ("tez", _("Tetserret")),
    ("tfi", _("Tofin Gbe")),
    ("tfn", _("Tanaina")),
    ("tfo", _("Tefaro")),
    ("tfr", _("Teribe")),
    ("tft", _("Ternate")),
    ("tga", _("Sagalla")),
    ("tgb", _("Tobilung")),
    ("tgc", _("Tigak")),
    ("tgd", _("Ciwogai")),
    ("tge", _("Eastern Gorkha Tamang")),
    ("tgf", _("Chalikha")),
    ("tgg", _("Tangga")),
    ("tgh", _("Tobagonian Creole English")),
    ("tgi", _("Lawunuia")),
    ("tgj", _("Tagin")),
    ("tgn", _("Tandaganon")),
    ("tgo", _("Sudest")),
    ("tgp", _("Tangoa")),
    ("tgq", _("Tring")),
    ("tgr", _("Tareng")),
    ("tgs", _("Nume")),
    ("tgt", _("Central Tagbanwa")),
    ("tgu", _("Tanggu")),
    ("tgv", _("Tingui-Boto")),
    ("tgw", _("Tagwana Senoufo")),
    ("tgx", _("Tagish")),
    ("tgy", _("Togoyo")),
    ("tgz", _("Tagalaka")),
    ("thc", _("Tai Hang Tong")),
    ("thd", _("Kuuk Thaayorre")),
    ("the", _("Chitwania Tharu")),
    ("thf", _("Thangmi")),
    ("thh", _("Northern Tarahumara")),
    ("thi", _("Tai Long")),
    ("thk", _("Tharaka")),
    ("thl", _("Dangaura Tharu")),
    ("thm", _("Aheu")),
    ("thn", _("Thachanadan")),
    ("thp", _("Thompson")),
    ("thq", _("Kochila Tharu")),
    ("thr", _("Rana Tharu")),
    ("ths", _("Thakali")),
    ("tht", _("Tahltan")),
    ("thu", _("Thuri")),
    ("thv", _("Tahaggart Tamahaq")),
    ("thw", _("Thudam")),
    ("thx", _("The")),
    ("thy", _("Tha")),
    ("thz", _("Tayart Tamajeq")),
    ("tia", _("Tidikelt Tamazight")),
    ("tic", _("Tira")),
    ("tid", _("Tidong")),
    ("tie", _("Tingal")),
    ("tif", _("Tifal")),
    ("tig", _("Tigre")),
    ("tih", _("Timugon Murut")),
    ("tii", _("Tiene")),
    ("tij", _("Tilung")),
    ("tik", _("Tikar")),
    ("til", _("Tillamook")),
    ("tim", _("Timbe")),
    ("tin", _("Tindi")),
    ("tio", _("Teop")),
    ("tip", _("Trimuris")),
    ("tiq", _("Tiéfo")),
    ("tis", _("Masadiit Itneg")),
    ("tit", _("Tinigua")),
    ("tiu", _("Adasen")),
    ("tiv", _("Tiv")),
    ("tiw", _("Tiwi")),
    ("tix", _("Southern Tiwa")),
    ("tiy", _("Tiruray")),
    ("tiz", _("Tai Hongjin")),
    ("tja", _("Tajuasohn")),
    ("tjg", _("Tunjung")),
    ("tji", _("Northern Tujia")),
    ("tjj", _("Tjungundji")),
    ("tjl", _("Tai Laing")),
    ("tjm", _("Timucua")),
    ("tjn", _("Tonjon")),
    ("tjo", _("Temacine Tamazight")),
    ("tjp", _("Tjupany")),
    ("tjs", _("Southern Tujia")),
    ("tju", _("Tjurruru")),
    ("tjw", _("Djabwurrung")),
    ("tka", _("Truká")),
    ("tkb", _("Buksa")),
    ("tkd", _("Tukudede")),
    ("tke", _("Takwane")),
    ("tkf", _("Tukumanféd")),
    ("tkg", _("Tesaka Malagasy")),
    ("tkk", _("Takpa")),
    ("tkl", _("Tokelau")),
    ("tkm", _("Takelma")),
    ("tkn", _("Toku-No-Shima")),
    ("tkp", _("Tikopia")),
    ("tkq", _("Tee")),
    ("tkr", _("Tsakhur")),
    ("tks", _("Takestani")),
    ("tkt", _("Kathoriya Tharu")),
    ("tku", _("Upper Necaxa Totonac")),
    ("tkv", _("Mur Pano")),
    ("tkw", _("Teanu")),
    ("tkx", _("Tangko")),
    ("tkz", _("Takua")),
    ("tla", _("Southwestern Tepehuan")),
    ("tlb", _("Tobelo")),
    ("tlc", _("Yecuatla Totonac")),
    ("tld", _("Talaud")),
    ("tlf", _("Telefol")),
    ("tlg", _("Tofanma")),
    ("tlh", _("Klingon")),
    ("tli", _("Tlingit")),
    ("tlj", _("Talinga-Bwisi")),
    ("tlk", _("Taloki")),
    ("tll", _("Tetela")),
    ("tlm", _("Tolomako")),
    ("tln", _("Talondo'")),
    ("tlo", _("Talodi")),
    ("tlp", _("Filomena Mata-Coahuitlán Totonac")),
    ("tlq", _("Tai Loi")),
    ("tlr", _("Talise")),
    ("tls", _("Tambotalo")),
    ("tlt", _("Sou Nama")),
    ("tlu", _("Tulehu")),
    ("tlv", _("Taliabu")),
    ("tlw", _("South Wemale")),
    ("tlx", _("Khehek")),
    ("tly", _("Talysh")),
    ("tma", _("Tama")),
    ("tmb", _("Katbol")),
    ("tmc", _("Tumak")),
    ("tmd", _("Haruai")),
    ("tme", _("Tremembé")),
    ("tmf", _("Toba-Maskoy")),
    ("tmg", _("Ternateño")),
    ("tmh", _("Tamashek")),
    ("tmi", _("Tutuba")),
    ("tmj", _("Samarokena")),
    ("tmk", _("Northwestern Tamang")),
    ("tml", _("Tamnim Citak")),
    ("tmm", _("Tai Thanh")),
    ("tmn", _("Taman")),
    ("tmo", _("Temoq")),
    ("tmp", _("Tai Mène")),
    ("tmq", _("Tumleo")),
    ("tmr", _("Jewish Babylonian Aramaic")),
    ("tms", _("Tima")),
    ("tmt", _("Tasmate")),
    ("tmu", _("Iau")),
    ("tmv", _("Tembo")),
    ("tmw", _("Temuan")),
    ("tmy", _("Tami")),
    ("tmz", _("Tamanaku")),
    ("tna", _("Tacana")),
    ("tnb", _("Western Tunebo")),
    ("tnc", _("Tanimuca-Retuarã")),
    ("tnd", _("Angosturas Tunebo")),
    ("tne", _("Tinoc Kallahan")),
    ("tnf", _("Tangshewi")),
    ("tng", _("Tobanga")),
    ("tnh", _("Maiani")),
    ("tni", _("Tandia")),
    ("tnk", _("Kwamera")),
    ("tnl", _("Lenakel")),
    ("tnm", _("Tabla")),
    ("tnn", _("North Tanna")),
    ("tno", _("Toromono")),
    ("tnp", _("Whitesands")),
    ("tnq", _("Taino")),
    ("tnr", _("Ménik")),
    ("tns", _("Tenis")),
    ("tnt", _("Tontemboan")),
    ("tnu", _("Tay Khang")),
    ("tnv", _("Tangchangya")),
    ("tnw", _("Tonsawang")),
    ("tnx", _("Tanema")),
    ("tny", _("Tongwe")),
    ("tnz", _("Ten'edn")),
    ("tob", _("Toba")),
    ("toc", _("Coyutla Totonac")),
    ("tod", _("Toma")),
    ("toe", _("Tomedes")),
    ("tof", _("Gizrra")),
    ("tog", _("Tonga")),
    ("toh", _("Gitonga")),
    ("toi", _("Tonga")),
    ("toj", _("Tojolabal")),
    ("tol", _("Tolowa")),
    ("tom", _("Tombulu")),
    ("too", _("Xicotepec De Juárez Totonac")),
    ("top", _("Papantla Totonac")),
    ("toq", _("Toposa")),
    ("tor", _("Togbo-Vara Banda")),
    ("tos", _("Highland Totonac")),
    ("tou", _("Tho")),
    ("tov", _("Upper Taromi")),
    ("tow", _("Jemez")),
    ("tox", _("Tobian")),
    ("toy", _("Topoiyo")),
    ("toz", _("To")),
    ("tpa", _("Taupota")),
    ("tpc", _("Azoyú Me'phaa")),
    ("tpe", _("Tippera")),
    ("tpf", _("Tarpia")),
    ("tpg", _("Kula")),
    ("tpi", _("Tok Pisin")),
    ("tpj", _("Tapieté")),
    ("tpk", _("Tupinikin")),
    ("tpl", _("Tlacoapa Me'phaa")),
    ("tpm", _("Tampulma")),
    ("tpn", _("Tupinambá")),
    ("tpo", _("Tai Pao")),
    ("tpp", _("Pisaflores Tepehua")),
    ("tpq", _("Tukpa")),
    ("tpr", _("Tuparí")),
    ("tpt", _("Tlachichilco Tepehua")),
    ("tpu", _("Tampuan")),
    ("tpv", _("Tanapag")),
    ("tpw", _("Tupí")),
    ("tpx", _("Acatepec Me'phaa")),
    ("tpy", _("Trumai")),
    ("tpz", _("Tinputz")),
    ("tqb", _("Tembé")),
    ("tql", _("Lehali")),
    ("tqm", _("Turumsa")),
    ("tqn", _("Tenino")),
    ("tqo", _("Toaripi")),
    ("tqp", _("Tomoip")),
    ("tqq", _("Tunni")),
    ("tqr", _("Torona")),
    ("tqt", _("Western Totonac")),
    ("tqu", _("Touo")),
    ("tqw", _("Tonkawa")),
    ("tra", _("Tirahi")),
    ("trb", _("Terebu")),
    ("trc", _("Copala Triqui")),
    ("trd", _("Turi")),
    ("tre", _("East Tarangan")),
    ("trf", _("Trinidadian Creole English")),
    ("trg", _("Lishán Didán")),
    ("trh", _("Turaka")),
    ("tri", _("Trió")),
    ("trj", _("Toram")),
    ("trk", _("Turkic languages")),
    ("trl", _("Traveller Scottish")),
    ("trm", _("Tregami")),
    ("trn", _("Trinitario")),
    ("tro", _("Tarao Naga")),
    ("trp", _("Kok Borok")),
    ("trq", _("San Martín Itunyoso Triqui")),
    ("trr", _("Taushiro")),
    ("trs", _("Chicahuaxtla Triqui")),
    ("trt", _("Tunggare")),
    ("tru", _("Turoyo")),
    ("trv", _("Taroko")),
    ("trw", _("Torwali")),
    ("trx", _("Tringgus-Sembaan Bidayuh")),
    ("try", _("Turung")),
    ("trz", _("Torá")),
    ("tsa", _("Tsaangi")),
    ("tsb", _("Tsamai")),
    ("tsc", _("Tswa")),
    ("tsd", _("Tsakonian")),
    ("tse", _("Tunisian Sign Language")),
    ("tsf", _("Southwestern Tamang")),
    ("tsg", _("Tausug")),
    ("tsh", _("Tsuvan")),
    ("tsi", _("Tsimshian")),
    ("tsj", _("Tshangla")),
    ("tsk", _("Tseku")),
    ("tsl", _("Ts'ün-Lao")),
    ("tsm", _("Turkish Sign Language")),
    ("tsp", _("Northern Toussian")),
    ("tsq", _("Thai Sign Language")),
    ("tsr", _("Akei")),
    ("tss", _("Taiwan Sign Language")),
    ("tst", _("Tondi Songway Kiini")),
    ("tsu", _("Tsou")),
    ("tsv", _("Tsogo")),
    ("tsw", _("Tsishingini")),
    ("tsx", _("Mubami")),
    ("tsy", _("Tebul Sign Language")),
    ("tsz", _("Purepecha")),
    ("tta", _("Tutelo")),
    ("ttb", _("Gaa")),
    ("ttc", _("Tektiteko")),
    ("ttd", _("Tauade")),
    ("tte", _("Bwanabwana")),
    ("ttf", _("Tuotomb")),
    ("ttg", _("Tutong")),
    ("tth", _("Upper Ta'oih")),
    ("tti", _("Tobati")),
    ("ttj", _("Tooro")),
    ("ttk", _("Totoro")),
    ("ttl", _("Totela")),
    ("ttm", _("Northern Tutchone")),
    ("ttn", _("Towei")),
    ("tto", _("Lower Ta'oih")),
    ("ttp", _("Tombelala")),
    ("ttq", _("Tawallammat Tamajaq")),
    ("ttr", _("Tera")),
    ("tts", _("Northeastern Thai")),
    ("ttt", _("Muslim Tat")),
    ("ttu", _("Torau")),
    ("ttv", _("Titan")),
    ("ttw", _("Long Wat")),
    ("tty", _("Sikaritai")),
    ("ttz", _("Tsum")),
    ("tua", _("Wiarumus")),
    ("tub", _("Tübatulabal")),
    ("tuc", _("Mutu")),
    ("tud", _("Tuxá")),
    ("tue", _("Tuyuca")),
    ("tuf", _("Central Tunebo")),
    ("tug", _("Tunia")),
    ("tuh", _("Taulil")),
    ("tui", _("Tupuri")),
    ("tuj", _("Tugutil")),
    ("tul", _("Tula")),
    ("tum", _("Tumbuka")),
    ("tun", _("Tunica")),
    ("tuo", _("Tucano")),
    ("tup", _("Tupi languages")),
    ("tuq", _("Tedaga")),
    ("tus", _("Tuscarora")),
    ("tut", _("Altaic languages")),
    ("tuu", _("Tututni")),
    ("tuv", _("Turkana")),
    ("tuw", _("Tungus languages")),
    ("tux", _("Tuxináwa")),
    ("tuy", _("Tugen")),
    ("tuz", _("Turka")),
    ("tva", _("Vaghua")),
    ("tvd", _("Tsuvadi")),
    ("tve", _("Te'un")),
    ("tvk", _("Southeast Ambrym")),
    ("tvl", _("Tuvalu")),
    ("tvm", _("Tela-Masbuar")),
    ("tvn", _("Tavoyan")),
    ("tvo", _("Tidore")),
    ("tvs", _("Taveta")),
    ("tvt", _("Tutsa Naga")),
    ("tvu", _("Tunen")),
    ("tvw", _("Sedoa")),
    ("tvx", _("Taivoan")),
    ("tvy", _("Timor Pidgin")),
    ("twa", _("Twana")),
    ("twb", _("Western Tawbuid")),
    ("twc", _("Teshenawa")),
    ("twd", _("Twents")),
    ("twe", _("Tewa")),
    ("twf", _("Northern Tiwa")),
    ("twg", _("Tereweng")),
    ("twh", _("Tai Dón")),
    ("twl", _("Tawara")),
    ("twm", _("Tawang Monpa")),
    ("twn", _("Twendi")),
    ("two", _("Tswapong")),
    ("twp", _("Ere")),
    ("twq", _("Tasawaq")),
    ("twr", _("Southwestern Tarahumara")),
    ("twt", _("Turiwára")),
    ("twu", _("Termanu")),
    ("tww", _("Tuwari")),
    ("twx", _("Tewe")),
    ("twy", _("Tawoyan")),
    ("txa", _("Tombonuo")),
    ("txb", _("Tokharian B")),
    ("txc", _("Tsetsaut")),
    ("txe", _("Totoli")),
    ("txg", _("Tangut")),
    ("txh", _("Thracian")),
    ("txi", _("Ikpeng")),
    ("txj", _("Tarjumo")),
    ("txm", _("Tomini")),
    ("txn", _("West Tarangan")),
    ("txo", _("Toto")),
    ("txq", _("Tii")),
    ("txr", _("Tartessian")),
    ("txs", _("Tonsea")),
    ("txt", _("Citak")),
    ("txu", _("Kayapó")),
    ("txx", _("Tatana")),
    ("txy", _("Tanosy Malagasy")),
    ("tya", _("Tauya")),
    ("tye", _("Kyanga")),
    ("tyh", _("O'du")),
    ("tyi", _("Teke-Tsaayi")),
    ("tyj", _("Tai Do")),
    ("tyl", _("Thu Lao")),
    ("tyn", _("Kombai")),
    ("typ", _("Thaypan")),
    ("tyr", _("Tai Daeng")),
    ("tys", _("Tày Sa Pa")),
    ("tyt", _("Tày Tac")),
    ("tyu", _("Kua")),
    ("tyv", _("Tuvinian")),
    ("tyx", _("Teke-Tyee")),
    ("tyy", _("Tiyaa")),
    ("tyz", _("Tày")),
    ("tza", _("Tanzanian Sign Language")),
    ("tzh", _("Tzeltal")),
    ("tzj", _("Tz'utujil")),
    ("tzl", _("Talossan")),
    ("tzm", _("Central Atlas Tamazight")),
    ("tzn", _("Tugun")),
    ("tzo", _("Tzotzil")),
    ("tzx", _("Tabriak")),
    ("uam", _("Uamué")),
    ("uan", _("Kuan")),
    ("uar", _("Tairuma")),
    ("uba", _("Ubang")),
    ("ubi", _("Ubi")),
    ("ubl", _("Buhi'non Bikol")),
    ("ubr", _("Ubir")),
    ("ubu", _("Umbu-Ungu")),
    ("uby", _("Ubykh")),
    ("uda", _("Uda")),
    ("ude", _("Udihe")),
    ("udg", _("Muduga")),
    ("udi", _("Udi")),
    ("udj", _("Ujir")),
    ("udl", _("Wuzlam")),
    ("udm", _("Udmurt")),
    ("udu", _("Uduk")),
    ("ues", _("Kioko")),
    ("ufi", _("Ufim")),
    ("uga", _("Ugaritic")),
    ("ugb", _("Kuku-Ugbanh")),
    ("uge", _("Ughele")),
    ("ugn", _("Ugandan Sign Language")),
    ("ugo", _("Ugong")),
    ("ugy", _("Uruguayan Sign Language")),
    ("uha", _("Uhami")),
    ("uhn", _("Damal")),
    ("uis", _("Uisai")),
    ("uiv", _("Iyive")),
    ("uji", _("Tanjijili")),
    ("uka", _("Kaburi")),
    ("ukg", _("Ukuriguma")),
    ("ukh", _("Ukhwejo")),
    ("uki", _("Kui")),
    ("ukk", _("Muak Sa-aak")),
    ("ukl", _("Ukrainian Sign Language")),
    ("ukp", _("Ukpe-Bayobiri")),
    ("ukq", _("Ukwa")),
    ("uks", _("Urubú-Kaapor Sign Language")),
    ("uku", _("Ukue")),
    ("ukv", _("Kuku")),
    ("ukw", _("Ukwuani-Aboh-Ndoni")),
    ("uky", _("Kuuk-Yak")),
    ("ula", _("Fungwa")),
    ("ulb", _("Ulukwumi")),
    ("ulc", _("Ulch")),
    ("ule", _("Lule")),
    ("ulf", _("Usku")),
    ("uli", _("Ulithian")),
    ("ulk", _("Meriam Mir")),
    ("ull", _("Ullatan")),
    ("ulm", _("Ulumanda'")),
    ("uln", _("Unserdeutsch")),
    ("ulu", _("Uma' Lung")),
    ("ulw", _("Ulwa")),
    ("uma", _("Umatilla")),
    ("umb", _("Umbundu")),
    ("umc", _("Marrucinian")),
    ("umd", _("Umbindhamu")),
    ("umg", _("Morrobalama")),
    ("umi", _("Ukit")),
    ("umm", _("Umon")),
    ("umn", _("Makyan Naga")),
    ("umo", _("Umotína")),
    ("ump", _("Umpila")),
    ("umr", _("Umbugarla")),
    ("ums", _("Pendau")),
    ("umu", _("Munsee")),
    ("una", _("North Watut")),
    ("und", _("Undetermined")),
    ("une", _("Uneme")),
    ("ung", _("Ngarinyin")),
    ("uni", _("Uni")),
    ("unk", _("Enawené-Nawé")),
    ("unm", _("Unami")),
    ("unn", _("Kurnai")),
    ("unp", _("Worora")),
    ("unr", _("Mundari")),
    ("unu", _("Unubahe")),
    ("unx", _("Munda")),
    ("unz", _("Unde Kaili")),
    ("uok", _("Uokha")),
    ("upi", _("Umeda")),
    ("upv", _("Uripiv-Wala-Rano-Atchin")),
    ("ura", _("Urarina")),
    ("urb", _("Urubú-Kaapor")),
    ("urc", _("Urningangg")),
    ("ure", _("Uru")),
    ("urf", _("Uradhi")),
    ("urg", _("Urigina")),
    ("urh", _("Urhobo")),
    ("uri", _("Urim")),
    ("urj", _("Uralic languages")),
    ("urk", _("Urak Lawoi'")),
    ("url", _("Urali")),
    ("urm", _("Urapmin")),
    ("urn", _("Uruangnirin")),
    ("uro", _("Ura")),
    ("urp", _("Uru-Pa-In")),
    ("urr", _("Lehalurup")),
    ("urt", _("Urat")),
    ("uru", _("Urumi")),
    ("urv", _("Uruava")),
    ("urw", _("Sop")),
    ("urx", _("Urimo")),
    ("ury", _("Orya")),
    ("urz", _("Uru-Eu-Wau-Wau")),
    ("usa", _("Usarufa")),
    ("ush", _("Ushojo")),
    ("usi", _("Usui")),
    ("usk", _("Usaghade")),
    ("usp", _("Uspanteco")),
    ("uss", _("us-Saare")),
    ("usu", _("Uya")),
    ("uta", _("Otank")),
    ("ute", _("Ute-Southern Paiute")),
    ("uth", _("ut-Hun")),
    ("utp", _("Amba")),
    ("utr", _("Etulo")),
    ("utu", _("Utu")),
    ("uum", _("Urum")),
    ("uun", _("Kulon-Pazeh")),
    ("uur", _("Ura")),
    ("uuu", _("U")),
    ("uve", _("West Uvean")),
    ("uvh", _("Uri")),
    ("uvl", _("Lote")),
    ("uwa", _("Kuku-Uwanh")),
    ("uya", _("Doko-Uyanga")),
    ("uzn", _("Northern Uzbek")),
    ("uzs", _("Southern Uzbek")),
    ("vaa", _("Vaagri Booli")),
    ("vae", _("Vale")),
    ("vaf", _("Vafsi")),
    ("vag", _("Vagla")),
    ("vah", _("Varhadi-Nagpuri")),
    ("vai", _("Vai")),
    ("vaj", _("Sekele")),
    ("val", _("Vehes")),
    ("vam", _("Vanimo")),
    ("van", _("Valman")),
    ("vao", _("Vao")),
    ("vap", _("Vaiphei")),
    ("var", _("Huarijio")),
    ("vas", _("Vasavi")),
    ("vau", _("Vanuma")),
    ("vav", _("Varli")),
    ("vay", _("Wayu")),
    ("vbb", _("Southeast Babar")),
    ("vbk", _("Southwestern Bontok")),
    ("vec", _("Venetian")),
    ("ved", _("Veddah")),
    ("vel", _("Veluws")),
    ("vem", _("Vemgo-Mabas")),
    ("veo", _("Ventureño")),
    ("vep", _("Veps")),
    ("ver", _("Mom Jango")),
    ("vgr", _("Vaghri")),
    ("vgt", _("Vlaamse Gebarentaal")),
    ("vic", _("Virgin Islands Creole English")),
    ("vid", _("Vidunda")),
    ("vif", _("Vili")),
    ("vig", _("Viemo")),
    ("vil", _("Vilela")),
    ("vin", _("Vinza")),
    ("vis", _("Vishavan")),
    ("vit", _("Viti")),
    ("viv", _("Iduna")),
    ("vka", _("Kariyarra")),
    ("vki", _("Ija-Zuba")),
    ("vkj", _("Kujarge")),
    ("vkk", _("Kaur")),
    ("vkl", _("Kulisusu")),
    ("vkm", _("Kamakan")),
    ("vkn", _("Koro Nulu")),
    ("vko", _("Kodeoha")),
    ("vkp", _("Korlai Creole Portuguese")),
    ("vkt", _("Tenggarong Kutai Malay")),
    ("vku", _("Kurrama")),
    ("vkz", _("Koro Zuba")),
    ("vlp", _("Valpei")),
    ("vls", _("Vlaams")),
    ("vma", _("Martuyhunira")),
    ("vmb", _("Barbaram")),
    ("vmc", _("Juxtlahuaca Mixtec")),
    ("vmd", _("Mudu Koraga")),
    ("vme", _("East Masela")),
    ("vmf", _("Mainfränkisch")),
    ("vmg", _("Lungalunga")),
    ("vmh", _("Maraghei")),
    ("vmi", _("Miwa")),
    ("vmj", _("Ixtayutla Mixtec")),
    ("vmk", _("Makhuwa-Shirima")),
    ("vml", _("Malgana")),
    ("vmm", _("Mitlatongo Mixtec")),
    ("vmp", _("Soyaltepec Mazatec")),
    ("vmq", _("Soyaltepec Mixtec")),
    ("vmr", _("Marenje")),
    ("vms", _("Moksela")),
    ("vmu", _("Muluridyi")),
    ("vmv", _("Valley Maidu")),
    ("vmw", _("Makhuwa")),
    ("vmx", _("Tamazola Mixtec")),
    ("vmy", _("Ayautla Mazatec")),
    ("vmz", _("Mazatlán Mazatec")),
    ("vnk", _("Vano")),
    ("vnm", _("Vinmavis")),
    ("vnp", _("Vunapu")),
    ("vor", _("Voro")),
    ("vot", _("Votic")),
    ("vra", _("Vera'a")),
    ("vro", _("Võro")),
    ("vrs", _("Varisi")),
    ("vrt", _("Burmbar")),
    ("vsi", _("Moldova Sign Language")),
    ("vsl", _("Venezuelan Sign Language")),
    ("vsv", _("Valencian Sign Language")),
    ("vto", _("Vitou")),
    ("vum", _("Vumbu")),
    ("vun", _("Vunjo")),
    ("vut", _("Vute")),
    ("vwa", _("Awa")),
    ("waa", _("Walla Walla")),
    ("wab", _("Wab")),
    ("wac", _("Wasco-Wishram")),
    ("wad", _("Wamesa")),
    ("wae", _("Walser")),
    ("waf", _("Wakoná")),
    ("wag", _("Wa'ema")),
    ("wah", _("Watubela")),
    ("wai", _("Wares")),
    ("waj", _("Waffa")),
    ("wak", _("Wakashan languages")),
    ("wal", _("Wolaytta")),
    ("wam", _("Wampanoag")),
    ("wan", _("Wan")),
    ("wao", _("Wappo")),
    ("wap", _("Wapishana")),
    ("waq", _("Wagiman")),
    ("war", _("Waray")),
    ("was", _("Washo")),
    ("wat", _("Kaninuwa")),
    ("wau", _("Waurá")),
    ("wav", _("Waka")),
    ("waw", _("Waiwai")),
    ("wax", _("Watam")),
    ("way", _("Wayana")),
    ("waz", _("Wampur")),
    ("wba", _("Warao")),
    ("wbb", _("Wabo")),
    ("wbe", _("Waritai")),
    ("wbf", _("Wara")),
    ("wbh", _("Wanda")),
    ("wbi", _("Vwanji")),
    ("wbj", _("Alagwa")),
    ("wbk", _("Waigali")),
    ("wbl", _("Wakhi")),
    ("wbm", _("Wa")),
    ("wbp", _("Warlpiri")),
    ("wbq", _("Waddar")),
    ("wbr", _("Wagdi")),
    ("wbs", _("West Bengal Sign Language")),
    ("wbt", _("Warnman")),
    ("wbv", _("Wajarri")),
    ("wbw", _("Woi")),
    ("wca", _("Yanomámi")),
    ("wci", _("Waci Gbe")),
    ("wdd", _("Wandji")),
    ("wdg", _("Wadaginam")),
    ("wdj", _("Wadjiginy")),
    ("wdk", _("Wadikali")),
    ("wdu", _("Wadjigu")),
    ("wdy", _("Wadjabangayi")),
    ("wea", _("Wewaw")),
    ("wec", _("Wè Western")),
    ("wed", _("Wedau")),
    ("weg", _("Wergaia")),
    ("weh", _("Weh")),
    ("wei", _("Kiunum")),
    ("wem", _("Weme Gbe")),
    ("wen", _("Sorbian languages")),
    ("weo", _("Wemale")),
    ("wep", _("Westphalien")),
    ("wer", _("Weri")),
    ("wes", _("Cameroon Pidgin")),
    ("wet", _("Perai")),
    ("weu", _("Rawngtu Chin")),
    ("wew", _("Wejewa")),
    ("wfg", _("Yafi")),
    ("wga", _("Wagaya")),
    ("wgb", _("Wagawaga")),
    ("wgg", _("Wangkangurru")),
    ("wgi", _("Wahgi")),
    ("wgo", _("Waigeo")),
    ("wgu", _("Wirangu")),
    ("wgw", _("Wagawaga")),
    ("wgy", _("Warrgamay")),
    ("wha", _("Sou Upaa")),
    ("whg", _("North Wahgi")),
    ("whk", _("Wahau Kenyah")),
    ("whu", _("Wahau Kayan")),
    ("wib", _("Southern Toussian")),
    ("wic", _("Wichita")),
    ("wie", _("Wik-Epa")),
    ("wif", _("Wik-Keyangan")),
    ("wig", _("Wik Ngathan")),
    ("wih", _("Wik-Me'anha")),
    ("wii", _("Minidien")),
    ("wij", _("Wik-Iiyanh")),
    ("wik", _("Wikalkan")),
    ("wil", _("Wilawila")),
    ("wim", _("Wik-Mungkan")),
    ("win", _("Ho-Chunk")),
    ("wir", _("Wiraféd")),
    ("wit", _("Wintu")),
    ("wiu", _("Wiru")),
    ("wiv", _("Vitu")),
    ("wiw", _("Wirangu")),
    ("wiy", _("Wiyot")),
    ("wja", _("Waja")),
    ("wji", _("Warji")),
    ("wka", _("Kw'adza")),
    ("wkb", _("Kumbaran")),
    ("wkd", _("Wakde")),
    ("wkl", _("Kalanadi")),
    ("wkr", _("Keerray-Woorroong")),
    ("wku", _("Kunduvadi")),
    ("wkw", _("Wakawaka")),
    ("wky", _("Wangkayutyuru")),
    ("wla", _("Walio")),
    ("wlc", _("Mwali Comorian")),
    ("wle", _("Wolane")),
    ("wlg", _("Kunbarlang")),
    ("wlh", _("Welaun")),
    ("wli", _("Waioli")),
    ("wlk", _("Wailaki")),
    ("wll", _("Wali")),
    ("wlm", _("Middle Welsh")),
    ("wlo", _("Wolio")),
    ("wlr", _("Wailapa")),
    ("wls", _("Wallisian")),
    ("wlu", _("Wuliwuli")),
    ("wlv", _("Wichí Lhamtés Vejoz")),
    ("wlw", _("Walak")),
    ("wlx", _("Wali")),
    ("wly", _("Waling")),
    ("wma", _("Mawa")),
    ("wmb", _("Wambaya")),
    ("wmc", _("Wamas")),
    ("wmd", _("Mamaindé")),
    ("wme", _("Wambule")),
    ("wmg", _("Western Minyag")),
    ("wmh", _("Waima'a")),
    ("wmi", _("Wamin")),
    ("wmm", _("Maiwa")),
    ("wmn", _("Waamwang")),
    ("wmo", _("Wom")),
    ("wms", _("Wambon")),
    ("wmt", _("Walmajarri")),
    ("wmw", _("Mwani")),
    ("wmx", _("Womo")),
    ("wnb", _("Wanambre")),
    ("wnc", _("Wantoat")),
    ("wnd", _("Wandarang")),
    ("wne", _("Waneci")),
    ("wng", _("Wanggom")),
    ("wni", _("Ndzwani Comorian")),
    ("wnk", _("Wanukaka")),
    ("wnm", _("Wanggamala")),
    ("wnn", _("Wunumara")),
    ("wno", _("Wano")),
    ("wnp", _("Wanap")),
    ("wnu", _("Usan")),
    ("wnw", _("Wintu")),
    ("wny", _("Wanyi")),
    ("woa", _("Kuwema")),
    ("wob", _("Wè Northern")),
    ("woc", _("Wogeo")),
    ("wod", _("Wolani")),
    ("woe", _("Woleaian")),
    ("wof", _("Gambian Wolof")),
    ("wog", _("Wogamusin")),
    ("woi", _("Kamang")),
    ("wok", _("Longto")),
    ("wom", _("Wom")),
    ("won", _("Wongo")),
    ("woo", _("Manombai")),
    ("wor", _("Woria")),
    ("wos", _("Hanga Hundi")),
    ("wow", _("Wawonii")),
    ("woy", _("Weyto")),
    ("wpc", _("Maco")),
    ("wra", _("Warapu")),
    ("wrb", _("Waluwarra")),
    ("wrd", _("Warduji")),
    ("wrg", _("Warungu")),
    ("wrh", _("Wiradjuri")),
    ("wri", _("Wariyangga")),
    ("wrk", _("Garrwa")),
    ("wrl", _("Warlmanpa")),
    ("wrm", _("Warumungu")),
    ("wrn", _("Warnang")),
    ("wro", _("Worrorra")),
    ("wrp", _("Waropen")),
    ("wrr", _("Wardaman")),
    ("wrs", _("Waris")),
    ("wru", _("Waru")),
    ("wrv", _("Waruna")),
    ("wrw", _("Gugu Warra")),
    ("wrx", _("Wae Rana")),
    ("wry", _("Merwari")),
    ("wrz", _("Waray")),
    ("wsa", _("Warembori")),
    ("wsg", _("Adilabad Gondi")),
    ("wsi", _("Wusi")),
    ("wsk", _("Waskia")),
    ("wsr", _("Owenia")),
    ("wss", _("Wasa")),
    ("wsu", _("Wasu")),
    ("wsv", _("Wotapuri-Katarqalai")),
    ("wtf", _("Watiwa")),
    ("wth", _("Wathawurrung")),
    ("wti", _("Berta")),
    ("wtk", _("Watakataui")),
    ("wtm", _("Mewati")),
    ("wtw", _("Wotu")),
    ("wua", _("Wikngenchera")),
    ("wub", _("Wunambal")),
    ("wud", _("Wudu")),
    ("wuh", _("Wutunhua")),
    ("wul", _("Silimo")),
    ("wum", _("Wumbvu")),
    ("wun", _("Bungu")),
    ("wur", _("Wurrugu")),
    ("wut", _("Wutung")),
    ("wuu", _("Wu Chinese")),
    ("wuv", _("Wuvulu-Aua")),
    ("wux", _("Wulna")),
    ("wuy", _("Wauyai")),
    ("wwa", _("Waama")),
    ("wwb", _("Wakabunga")),
    ("wwo", _("Wetamut")),
    ("wwr", _("Warrwa")),
    ("www", _("Wawa")),
    ("wxa", _("Waxianghua")),
    ("wxw", _("Wardandi")),
    ("wya", _("Wyandot")),
    ("wyb", _("Wangaaybuwan-Ngiyambaa")),
    ("wyi", _("Woiwurrung")),
    ("wym", _("Wymysorys")),
    ("wyr", _("Wayoró")),
    ("wyy", _("Western Fijian")),
    ("xaa", _("Andalusian Arabic")),
    ("xab", _("Sambe")),
    ("xac", _("Kachari")),
    ("xad", _("Adai")),
    ("xae", _("Aequian")),
    ("xag", _("Aghwan")),
    ("xai", _("Kaimbé")),
    ("xaj", _("Ararandewára")),
    ("xak", _("Máku")),
    ("xal", _("Kalmyk")),
    ("xam", _("ǀXam")),
    ("xan", _("Xamtanga")),
    ("xao", _("Khao")),
    ("xap", _("Apalachee")),
    ("xaq", _("Aquitanian")),
    ("xar", _("Karami")),
    ("xas", _("Kamas")),
    ("xat", _("Katawixi")),
    ("xau", _("Kauwera")),
    ("xav", _("Xavánte")),
    ("xaw", _("Kawaiisu")),
    ("xay", _("Kayan Mahakam")),
    ("xba", _("Kamba")),
    ("xbb", _("Lower Burdekin")),
    ("xbc", _("Bactrian")),
    ("xbd", _("Bindal")),
    ("xbe", _("Bigambal")),
    ("xbg", _("Bunganditj")),
    ("xbi", _("Kombio")),
    ("xbj", _("Birrpayi")),
    ("xbm", _("Middle Breton")),
    ("xbn", _("Kenaboi")),
    ("xbo", _("Bolgarian")),
    ("xbp", _("Bibbulman")),
    ("xbr", _("Kambera")),
    ("xbw", _("Kambiwá")),
    ("xbx", _("Kabixí")),
    ("xby", _("Batjala")),
    ("xcb", _("Cumbric")),
    ("xcc", _("Camunic")),
    ("xce", _("Celtiberian")),
    ("xcg", _("Cisalpine Gaulish")),
    ("xch", _("Chemakum")),
    ("xcl", _("Classical Armenian")),
    ("xcm", _("Comecrudo")),
    ("xcn", _("Cotoname")),
    ("xco", _("Chorasmian")),
    ("xcr", _("Carian")),
    ("xct", _("Classical Tibetan")),
    ("xcu", _("Curonian")),
    ("xcv", _("Chuvantsy")),
    ("xcw", _("Coahuilteco")),
    ("xcy", _("Cayuse")),
    ("xda", _("Darkinyung")),
    ("xdc", _("Dacian")),
    ("xdk", _("Dharuk")),
    ("xdm", _("Edomite")),
    ("xdo", _("Kwandu")),
    ("xdy", _("Malayic Dayak")),
    ("xeb", _("Eblan")),
    ("xed", _("Hdi")),
    ("xeg", _("ǁXegwi")),
    ("xel", _("Kelo")),
    ("xem", _("Kembayan")),
    ("xep", _("Epi-Olmec")),
    ("xer", _("Xerénte")),
    ("xes", _("Kesawai")),
    ("xet", _("Xetá")),
    ("xeu", _("Keoru-Ahia")),
    ("xfa", _("Faliscan")),
    ("xga", _("Galatian")),
    ("xgb", _("Gbin")),
    ("xgd", _("Gudang")),
    ("xgf", _("Gabrielino-Fernandeño")),
    ("xgg", _("Goreng")),
    ("xgi", _("Garingbal")),
    ("xgl", _("Galindan")),
    ("xgm", _("Dharumbal")),
    ("xgn", _("Mongolian languages")),
    ("xgr", _("Garza")),
    ("xgu", _("Unggumi")),
    ("xgw", _("Guwa")),
    ("xha", _("Harami")),
    ("xhc", _("Hunnic")),
    ("xhd", _("Hadrami")),
    ("xhe", _("Khetrani")),
    ("xhr", _("Hernican")),
    ("xht", _("Hattic")),
    ("xhu", _("Hurrian")),
    ("xhv", _("Khua")),
    ("xia", _("Xiandao")),
    ("xib", _("Iberian")),
    ("xii", _("Xiri")),
    ("xil", _("Illyrian")),
    ("xin", _("Xinca")),
    ("xip", _("Xipináwa")),
    ("xir", _("Xiriâna")),
    ("xis", _("Kisan")),
    ("xiv", _("Indus Valley Language")),
    ("xiy", _("Xipaya")),
    ("xjb", _("Minjungbal")),
    ("xjt", _("Jaitmatang")),
    ("xka", _("Kalkoti")),
    ("xkb", _("Northern Nago")),
    ("xkc", _("Kho'ini")),
    ("xkd", _("Mendalam Kayan")),
    ("xke", _("Kereho")),
    ("xkf", _("Khengkha")),
    ("xkg", _("Kagoro")),
    ("xkh", _("Karahawyana")),
    ("xki", _("Kenyan Sign Language")),
    ("xkj", _("Kajali")),
    ("xkk", _("Kaco'")),
    ("xkl", _("Mainstream Kenyah")),
    ("xkn", _("Kayan River Kayan")),
    ("xko", _("Kiorr")),
    ("xkp", _("Kabatei")),
    ("xkq", _("Koroni")),
    ("xkr", _("Xakriabá")),
    ("xks", _("Kumbewaha")),
    ("xkt", _("Kantosi")),
    ("xku", _("Kaamba")),
    ("xkv", _("Kgalagadi")),
    ("xkw", _("Kembra")),
    ("xkx", _("Karore")),
    ("xky", _("Uma' Lasan")),
    ("xkz", _("Kurtokha")),
    ("xla", _("Kamula")),
    ("xlb", _("Loup B")),
    ("xlc", _("Lycian")),
    ("xld", _("Lydian")),
    ("xle", _("Lemnian")),
    ("xlg", _("Ligurian")),
    ("xli", _("Liburnian")),
    ("xln", _("Alanic")),
    ("xlo", _("Loup A")),
    ("xlp", _("Lepontic")),
    ("xls", _("Lusitanian")),
    ("xlu", _("Cuneiform Luwian")),
    ("xly", _("Elymian")),
    ("xma", _("Mushungulu")),
    ("xmb", _("Mbonga")),
    ("xmc", _("Makhuwa-Marrevone")),
    ("xmd", _("Mbudum")),
    ("xme", _("Median")),
    ("xmf", _("Mingrelian")),
    ("xmg", _("Mengaka")),
    ("xmh", _("Kugu-Muminh")),
    ("xmj", _("Majera")),
    ("xmk", _("Ancient Macedonian")),
    ("xml", _("Malaysian Sign Language")),
    ("xmm", _("Manado Malay")),
    ("xmn", _("Manichaean Middle Persian")),
    ("xmo", _("Morerebi")),
    ("xmp", _("Kuku-Mu'inh")),
    ("xmq", _("Kuku-Mangk")),
    ("xmr", _("Meroitic")),
    ("xms", _("Moroccan Sign Language")),
    ("xmt", _("Matbat")),
    ("xmu", _("Kamu")),
    ("xmv", _("Antankarana Malagasy")),
    ("xmw", _("Tsimihety Malagasy")),
    ("xmx", _("Maden")),
    ("xmy", _("Mayaguduna")),
    ("xmz", _("Mori Bawah")),
    ("xna", _("Ancient North Arabian")),
    ("xnb", _("Kanakanabu")),
    ("xnd", _("Na-Dene languages")),
    ("xng", _("Middle Mongolian")),
    ("xnh", _("Kuanhua")),
    ("xni", _("Ngarigu")),
    ("xnj", _("Ngoni")),
    ("xnk", _("Nganakarti")),
    ("xnm", _("Ngumbarl")),
    ("xnn", _("Northern Kankanay")),
    ("xno", _("Anglo-Norman")),
    ("xnq", _("Ngoni")),
    ("xnr", _("Kangri")),
    ("xns", _("Kanashi")),
    ("xnt", _("Narragansett")),
    ("xnu", _("Nukunul")),
    ("xny", _("Nyiyaparli")),
    ("xnz", _("Kenzi")),
    ("xoc", _("O'chi'chi'")),
    ("xod", _("Kokoda")),
    ("xog", _("Soga")),
    ("xoi", _("Kominimung")),
    ("xok", _("Xokleng")),
    ("xom", _("Komo")),
    ("xon", _("Konkomba")),
    ("xoo", _("Xukurú")),
    ("xop", _("Kopar")),
    ("xor", _("Korubo")),
    ("xow", _("Kowaki")),
    ("xpa", _("Pirriya")),
    ("xpb", _("Northeastern Tasmanian")),
    ("xpc", _("Pecheneg")),
    ("xpd", _("Oyster Bay Tasmanian")),
    ("xpe", _("Liberia Kpelle")),
    ("xpf", _("Southeast Tasmanian")),
    ("xpg", _("Phrygian")),
    ("xph", _("North Midlands Tasmanian")),
    ("xpi", _("Pictish")),
    ("xpj", _("Mpalitjanh")),
    ("xpk", _("Kulina Pano")),
    ("xpl", _("Port Sorell Tasmanian")),
    ("xpm", _("Pumpokol")),
    ("xpn", _("Kapinawá")),
    ("xpo", _("Pochutec")),
    ("xpp", _("Puyo-Paekche")),
    ("xpq", _("Mohegan-Pequot")),
    ("xpr", _("Parthian")),
    ("xps", _("Pisidian")),
    ("xpt", _("Punthamara")),
    ("xpu", _("Punic")),
    ("xpv", _("Northern Tasmanian")),
    ("xpw", _("Northwestern Tasmanian")),
    ("xpx", _("Southwestern Tasmanian")),
    ("xpy", _("Puyo")),
    ("xpz", _("Bruny Island Tasmanian")),
    ("xqa", _("Karakhanid")),
    ("xqt", _("Qatabanian")),
    ("xra", _("Krahô")),
    ("xrb", _("Eastern Karaboro")),
    ("xrd", _("Gundungurra")),
    ("xre", _("Kreye")),
    ("xrg", _("Minang")),
    ("xri", _("Krikati-Timbira")),
    ("xrm", _("Armazic")),
    ("xrn", _("Arin")),
    ("xrq", _("Karranga")),
    ("xrr", _("Raetic")),
    ("xrt", _("Aranama-Tamique")),
    ("xru", _("Marriammu")),
    ("xrw", _("Karawa")),
    ("xsa", _("Sabaean")),
    ("xsb", _("Sambal")),
    ("xsc", _("Scythian")),
    ("xsd", _("Sidetic")),
    ("xse", _("Sempan")),
    ("xsh", _("Shamang")),
    ("xsi", _("Sio")),
    ("xsj", _("Subi")),
    ("xsl", _("South Slavey")),
    ("xsm", _("Kasem")),
    ("xsn", _("Sanga")),
    ("xso", _("Solano")),
    ("xsp", _("Silopi")),
    ("xsq", _("Makhuwa-Saka")),
    ("xsr", _("Sherpa")),
    ("xss", _("Assan")),
    ("xsu", _("Sanumá")),
    ("xsv", _("Sudovian")),
    ("xsy", _("Saisiyat")),
    ("xta", _("Alcozauca Mixtec")),
    ("xtb", _("Chazumba Mixtec")),
    ("xtc", _("Katcha-Kadugli-Miri")),
    ("xtd", _("Diuxi-Tilantongo Mixtec")),
    ("xte", _("Ketengban")),
    ("xtg", _("Transalpine Gaulish")),
    ("xth", _("Yitha Yitha")),
    ("xti", _("Sinicahua Mixtec")),
    ("xtj", _("San Juan Teita Mixtec")),
    ("xtl", _("Tijaltepec Mixtec")),
    ("xtm", _("Magdalena Peñasco Mixtec")),
    ("xtn", _("Northern Tlaxiaco Mixtec")),
    ("xto", _("Tokharian A")),
    ("xtp", _("San Miguel Piedras Mixtec")),
    ("xtq", _("Tumshuqese")),
    ("xtr", _("Early Tripuri")),
    ("xts", _("Sindihui Mixtec")),
    ("xtt", _("Tacahua Mixtec")),
    ("xtu", _("Cuyamecalco Mixtec")),
    ("xtv", _("Thawa")),
    ("xtw", _("Tawandê")),
    ("xty", _("Yoloxochitl Mixtec")),
    ("xtz", _("Tasmanian")),
    ("xua", _("Alu Kurumba")),
    ("xub", _("Betta Kurumba")),
    ("xud", _("Umiida")),
    ("xug", _("Kunigami")),
    ("xuj", _("Jennu Kurumba")),
    ("xul", _("Ngunawal")),
    ("xum", _("Umbrian")),
    ("xun", _("Unggaranggu")),
    ("xuo", _("Kuo")),
    ("xup", _("Upper Umpqua")),
    ("xur", _("Urartian")),
    ("xut", _("Kuthant")),
    ("xuu", _("Kxoe")),
    ("xve", _("Venetic")),
    ("xvi", _("Kamviri")),
    ("xvn", _("Vandalic")),
    ("xvo", _("Volscian")),
    ("xvs", _("Vestinian")),
    ("xwa", _("Kwaza")),
    ("xwc", _("Woccon")),
    ("xwd", _("Wadi Wadi")),
    ("xwe", _("Xwela Gbe")),
    ("xwg", _("Kwegu")),
    ("xwj", _("Wajuk")),
    ("xwk", _("Wangkumara")),
    ("xwl", _("Western Xwla Gbe")),
    ("xwo", _("Written Oirat")),
    ("xwr", _("Kwerba Mamberamo")),
    ("xwt", _("Wotjobaluk")),
    ("xww", _("Wemba Wemba")),
    ("xxb", _("Boro")),
    ("xxk", _("Ke'o")),
    ("xxm", _("Minkin")),
    ("xxr", _("Koropó")),
    ("xxt", _("Tambora")),
    ("xya", _("Yaygir")),
    ("xyb", _("Yandjibara")),
    ("xyj", _("Mayi-Yapi")),
    ("xyk", _("Mayi-Kulan")),
    ("xyl", _("Yalakalore")),
    ("xyt", _("Mayi-Thakurti")),
    ("xyy", _("Yorta Yorta")),
    ("xzh", _("Zhang-Zhung")),
    ("xzm", _("Zemgalian")),
    ("xzp", _("Ancient Zapotec")),
    ("yaa", _("Yaminahua")),
    ("yab", _("Yuhup")),
    ("yac", _("Pass Valley Yali")),
    ("yad", _("Yagua")),
    ("yae", _("Pumé")),
    ("yaf", _("Yaka")),
    ("yag", _("Yámana")),
    ("yah", _("Yazgulyam")),
    ("yai", _("Yagnobi")),
    ("yaj", _("Banda-Yangere")),
    ("yak", _("Yakama")),
    ("yal", _("Yalunka")),
    ("yam", _("Yamba")),
    ("yan", _("Mayangna")),
    ("yao", _("Yao")),
    ("yap", _("Yapese")),
    ("yaq", _("Yaqui")),
    ("yar", _("Yabarana")),
    ("yas", _("Nugunu")),
    ("yat", _("Yambeta")),
    ("yau", _("Yuwana")),
    ("yav", _("Yangben")),
    ("yaw", _("Yawalapití")),
    ("yax", _("Yauma")),
    ("yay", _("Agwagwune")),
    ("yaz", _("Lokaa")),
    ("yba", _("Yala")),
    ("ybb", _("Yemba")),
    ("ybd", _("Yangbye")),
    ("ybe", _("West Yugur")),
    ("ybh", _("Yakha")),
    ("ybi", _("Yamphu")),
    ("ybj", _("Hasha")),
    ("ybk", _("Bokha")),
    ("ybl", _("Yukuben")),
    ("ybm", _("Yaben")),
    ("ybn", _("Yabaâna")),
    ("ybo", _("Yabong")),
    ("ybx", _("Yawiyo")),
    ("yby", _("Yaweyuha")),
    ("ych", _("Chesu")),
    ("ycl", _("Lolopo")),
    ("ycn", _("Yucuna")),
    ("ycp", _("Chepya")),
    ("yda", _("Yanda")),
    ("ydd", _("Eastern Yiddish")),
    ("yde", _("Yangum Dey")),
    ("ydg", _("Yidgha")),
    ("ydk", _("Yoidik")),
    ("yds", _("Yiddish Sign Language")),
    ("yea", _("Ravula")),
    ("yec", _("Yeniche")),
    ("yee", _("Yimas")),
    ("yei", _("Yeni")),
    ("yej", _("Yevanic")),
    ("yel", _("Yela")),
    ("yen", _("Yendang")),
    ("yer", _("Tarok")),
    ("yes", _("Nyankpa")),
    ("yet", _("Yetfa")),
    ("yeu", _("Yerukula")),
    ("yev", _("Yapunda")),
    ("yey", _("Yeyi")),
    ("yga", _("Malyangapa")),
    ("ygi", _("Yiningayi")),
    ("ygl", _("Yangum Gel")),
    ("ygm", _("Yagomi")),
    ("ygp", _("Gepo")),
    ("ygr", _("Yagaria")),
    ("ygs", _("Yolŋu Sign Language")),
    ("ygu", _("Yugul")),
    ("ygw", _("Yagwoia")),
    ("yha", _("Baha Buyang")),
    ("yhd", _("Judeo-Iraqi Arabic")),
    ("yhl", _("Hlepho Phowa")),
    ("yhs", _("Yan-nhaŋu Sign Language")),
    ("yia", _("Yinggarda")),
    ("yif", _("Ache")),
    ("yig", _("Wusa Nasu")),
    ("yih", _("Western Yiddish")),
    ("yii", _("Yidiny")),
    ("yij", _("Yindjibarndi")),
    ("yik", _("Dongshanba Lalo")),
    ("yil", _("Yindjilandji")),
    ("yim", _("Yimchungru Naga")),
    ("yin", _("Riang Lai")),
    ("yip", _("Pholo")),
    ("yiq", _("Miqie")),
    ("yir", _("North Awyu")),
    ("yis", _("Yis")),
    ("yit", _("Eastern Lalu")),
    ("yiu", _("Awu")),
    ("yiv", _("Northern Nisu")),
    ("yix", _("Axi Yi")),
    ("yiy", _("Yir Yoront")),
    ("yiz", _("Azhe")),
    ("yka", _("Yakan")),
    ("ykg", _("Northern Yukaghir")),
    ("yki", _("Yoke")),
    ("ykk", _("Yakaikeke")),
    ("ykl", _("Khlula")),
    ("ykm", _("Kap")),
    ("ykn", _("Kua-nsi")),
    ("yko", _("Yasa")),
    ("ykr", _("Yekora")),
    ("ykt", _("Kathu")),
    ("yku", _("Kuamasi")),
    ("yky", _("Yakoma")),
    ("yla", _("Yaul")),
    ("ylb", _("Yaleba")),
    ("yle", _("Yele")),
    ("ylg", _("Yelogu")),
    ("yli", _("Angguruk Yali")),
    ("yll", _("Yil")),
    ("ylm", _("Limi")),
    ("yln", _("Langnian Buyang")),
    ("ylo", _("Naluo Yi")),
    ("ylr", _("Yalarnnga")),
    ("ylu", _("Aribwaung")),
    ("yly", _("Nyâlayu")),
    ("yma", _("Yamphe")),
    ("ymb", _("Yambes")),
    ("ymc", _("Southern Muji")),
    ("ymd", _("Muda")),
    ("yme", _("Yameo")),
    ("ymg", _("Yamongeri")),
    ("ymh", _("Mili")),
    ("ymi", _("Moji")),
    ("ymk", _("Makwe")),
    ("yml", _("Iamalele")),
    ("ymm", _("Maay")),
    ("ymn", _("Yamna")),
    ("ymo", _("Yangum Mon")),
    ("ymp", _("Yamap")),
    ("ymq", _("Qila Muji")),
    ("ymr", _("Malasar")),
    ("yms", _("Mysian")),
    ("ymt", _("Mator-Taygi-Karagas")),
    ("ymx", _("Northern Muji")),
    ("ymz", _("Muzi")),
    ("yna", _("Aluo")),
    ("ynd", _("Yandruwandha")),
    ("yne", _("Lang'e")),
    ("yng", _("Yango")),
    ("ynh", _("Yangho")),
    ("ynk", _("Naukan Yupik")),
    ("ynl", _("Yangulam")),
    ("ynn", _("Yana")),
    ("yno", _("Yong")),
    ("ynq", _("Yendang")),
    ("yns", _("Yansi")),
    ("ynu", _("Yahuna")),
    ("yob", _("Yoba")),
    ("yog", _("Yogad")),
    ("yoi", _("Yonaguni")),
    ("yok", _("Yokuts")),
    ("yol", _("Yola")),
    ("yom", _("Yombe")),
    ("yon", _("Yongkom")),
    ("yos", _("Yos")),
    ("yot", _("Yotti")),
    ("yox", _("Yoron")),
    ("yoy", _("Yoy")),
    ("ypa", _("Phala")),
    ("ypb", _("Labo Phowa")),
    ("ypg", _("Phola")),
    ("yph", _("Phupha")),
    ("ypk", _("Yupik languages")),
    ("ypm", _("Phuma")),
    ("ypn", _("Ani Phowa")),
    ("ypo", _("Alo Phola")),
    ("ypp", _("Phupa")),
    ("ypz", _("Phuza")),
    ("yra", _("Yerakai")),
    ("yrb", _("Yareba")),
    ("yre", _("Yaouré")),
    ("yri", _("Yarí")),
    ("yrk", _("Nenets")),
    ("yrl", _("Nhengatu")),
    ("yrm", _("Yirrk-Mel")),
    ("yrn", _("Yerong")),
    ("yro", _("Yaroamë")),
    ("yrs", _("Yarsun")),
    ("yrw", _("Yarawata")),
    ("yry", _("Yarluyandi")),
    ("ysc", _("Yassic")),
    ("ysd", _("Samatao")),
    ("ysg", _("Sonaga")),
    ("ysl", _("Yugoslavian Sign Language")),
    ("ysm", _("Myanmar Sign Language")),
    ("ysn", _("Sani")),
    ("yso", _("Nisi")),
    ("ysp", _("Southern Lolopo")),
    ("ysr", _("Sirenik Yupik")),
    ("yss", _("Yessan-Mayo")),
    ("ysy", _("Sanie")),
    ("yta", _("Talu")),
    ("ytl", _("Tanglang")),
    ("ytp", _("Thopho")),
    ("ytw", _("Yout Wam")),
    ("yty", _("Yatay")),
    ("yua", _("Yucateco")),
    ("yub", _("Yugambal")),
    ("yuc", _("Yuchi")),
    ("yud", _("Judeo-Tripolitanian Arabic")),
    ("yue", _("Yue Chinese")),
    ("yuf", _("Havasupai-Walapai-Yavapai")),
    ("yug", _("Yug")),
    ("yui", _("Yurutí")),
    ("yuj", _("Karkar-Yuri")),
    ("yuk", _("Yuki")),
    ("yul", _("Yulu")),
    ("yum", _("Quechan")),
    ("yun", _("Bena")),
    ("yup", _("Yukpa")),
    ("yuq", _("Yuqui")),
    ("yur", _("Yurok")),
    ("yut", _("Yopno")),
    ("yuu", _("Yugh")),
    ("yuw", _("Yau")),
    ("yux", _("Southern Yukaghir")),
    ("yuy", _("East Yugur")),
    ("yuz", _("Yuracare")),
    ("yva", _("Yawa")),
    ("yvt", _("Yavitero")),
    ("ywa", _("Kalou")),
    ("ywg", _("Yinhawangka")),
    ("ywl", _("Western Lalu")),
    ("ywn", _("Yawanawa")),
    ("ywq", _("Wuding-Luquan Yi")),
    ("ywr", _("Yawuru")),
    ("ywt", _("Xishanba Lalo")),
    ("ywu", _("Wumeng Nasu")),
    ("yww", _("Yawarawarga")),
    ("yxa", _("Mayawali")),
    ("yxg", _("Yagara")),
    ("yxl", _("Yardliyawarra")),
    ("yxm", _("Yinwum")),
    ("yxu", _("Yuyu")),
    ("yxy", _("Yabula Yabula")),
    ("yyr", _("Yir Yoront")),
    ("yyu", _("Yau")),
    ("yyz", _("Ayizi")),
    ("yzg", _("E'ma Buyang")),
    ("yzk", _("Zokhuo")),
    ("zaa", _("Sierra de Juárez Zapotec")),
    ("zab", _("Western Tlacolula Valley Zapotec")),
    ("zac", _("Ocotlán Zapotec")),
    ("zad", _("Cajonos Zapotec")),
    ("zae", _("Yareni Zapotec")),
    ("zaf", _("Ayoquesco Zapotec")),
    ("zag", _("Zaghawa")),
    ("zah", _("Zangwal")),
    ("zai", _("Isthmus Zapotec")),
    ("zaj", _("Zaramo")),
    ("zak", _("Zanaki")),
    ("zal", _("Zauzou")),
    ("zam", _("Miahuatlán Zapotec")),
    ("zao", _("Ozolotepec Zapotec")),
    ("zap", _("Zapotec")),
    ("zaq", _("Aloápam Zapotec")),
    ("zar", _("Rincón Zapotec")),
    ("zas", _("Santo Domingo Albarradas Zapotec")),
    ("zat", _("Tabaa Zapotec")),
    ("zau", _("Zangskari")),
    ("zav", _("Yatzachi Zapotec")),
    ("zaw", _("Mitla Zapotec")),
    ("zax", _("Xadani Zapotec")),
    ("zay", _("Zayse-Zergulla")),
    ("zaz", _("Zari")),
    ("zba", _("Balaibalan")),
    ("zbc", _("Central Berawan")),
    ("zbe", _("East Berawan")),
    ("zbl", _("Blissymbols")),
    ("zbt", _("Batui")),
    ("zbu", _("Bu")),
    ("zbw", _("West Berawan")),
    ("zca", _("Coatecas Altas Zapotec")),
    ("zch", _("Central Hongshuihe Zhuang")),
    ("zdj", _("Ngazidja Comorian")),
    ("zea", _("Zeeuws")),
    ("zeg", _("Zenag")),
    ("zeh", _("Eastern Hongshuihe Zhuang")),
    ("zen", _("Zenaga")),
    ("zga", _("Kinga")),
    ("zgb", _("Guibei Zhuang")),
    ("zgh", _("Standard Moroccan Tamazight")),
    ("zgm", _("Minz Zhuang")),
    ("zgn", _("Guibian Zhuang")),
    ("zgr", _("Magori")),
    ("zhb", _("Zhaba")),
    ("zhd", _("Dai Zhuang")),
    ("zhi", _("Zhire")),
    ("zhn", _("Nong Zhuang")),
    ("zhw", _("Zhoa")),
    ("zhx", _("Chinese")),
    ("zia", _("Zia")),
    ("zib", _("Zimbabwe Sign Language")),
    ("zik", _("Zimakani")),
    ("zil", _("Zialo")),
    ("zim", _("Mesme")),
    ("zin", _("Zinza")),
    ("zir", _("Ziriya")),
    ("ziw", _("Zigula")),
    ("ziz", _("Zizilivakan")),
    ("zka", _("Kaimbulawa")),
    ("zkb", _("Koibal")),
    ("zkd", _("Kadu")),
    ("zkg", _("Koguryo")),
    ("zkh", _("Khorezmian")),
    ("zkk", _("Karankawa")),
    ("zkn", _("Kanan")),
    ("zko", _("Kott")),
    ("zkp", _("São Paulo Kaingáng")),
    ("zkr", _("Zakhring")),
    ("zkt", _("Kitan")),
    ("zku", _("Kaurna")),
    ("zkv", _("Krevinian")),
    ("zkz", _("Khazar")),
    ("zla", _("Zula")),
    ("zle", _("East Slavic languages")),
    ("zlj", _("Liujiang Zhuang")),
    ("zlm", _("Malay")),
    ("zln", _("Lianshan Zhuang")),
    ("zlq", _("Liuqian Zhuang")),
    ("zls", _("South Slavic languages")),
    ("zlw", _("West Slavic languages")),
    ("zma", _("Manda")),
    ("zmb", _("Zimba")),
    ("zmc", _("Margany")),
    ("zmd", _("Maridan")),
    ("zme", _("Mangerr")),
    ("zmf", _("Mfinu")),
    ("zmg", _("Marti Ke")),
    ("zmh", _("Makolkol")),
    ("zmi", _("Negeri Sembilan Malay")),
    ("zmj", _("Maridjabin")),
    ("zmk", _("Mandandanyi")),
    ("zml", _("Matngala")),
    ("zmm", _("Marimanindji")),
    ("zmn", _("Mbangwe")),
    ("zmo", _("Molo")),
    ("zmp", _("Mpuono")),
    ("zmq", _("Mituku")),
    ("zmr", _("Maranunggu")),
    ("zms", _("Mbesa")),
    ("zmt", _("Maringarr")),
    ("zmu", _("Muruwari")),
    ("zmv", _("Mbariman-Gudhinma")),
    ("zmw", _("Mbo")),
    ("zmx", _("Bomitaba")),
    ("zmy", _("Mariyedi")),
    ("zmz", _("Mbandja")),
    ("zna", _("Zan Gula")),
    ("znd", _("Zande languages")),
    ("zne", _("Zande")),
    ("zng", _("Mang")),
    ("znk", _("Manangkari")),
    ("zns", _("Mangas")),
    ("zoc", _("Copainalá Zoque")),
    ("zoh", _("Chimalapa Zoque")),
    ("zom", _("Zou")),
    ("zoo", _("Asunción Mixtepec Zapotec")),
    ("zoq", _("Tabasco Zoque")),
    ("zor", _("Rayón Zoque")),
    ("zos", _("Francisco León Zoque")),
    ("zpa", _("Lachiguiri Zapotec")),
    ("zpb", _("Yautepec Zapotec")),
    ("zpc", _("Choapan Zapotec")),
    ("zpd", _("Southeastern Ixtlán Zapotec")),
    ("zpe", _("Petapa Zapotec")),
    ("zpf", _("San Pedro Quiatoni Zapotec")),
    ("zpg", _("Guevea De Humboldt Zapotec")),
    ("zph", _("Totomachapan Zapotec")),
    ("zpi", _("Santa María Quiegolani Zapotec")),
    ("zpj", _("Quiavicuzas Zapotec")),
    ("zpk", _("Tlacolulita Zapotec")),
    ("zpl", _("Lachixío Zapotec")),
    ("zpm", _("Mixtepec Zapotec")),
    ("zpn", _("Santa Inés Yatzechi Zapotec")),
    ("zpo", _("Amatlán Zapotec")),
    ("zpp", _("El Alto Zapotec")),
    ("zpq", _("Zoogocho Zapotec")),
    ("zpr", _("Santiago Xanica Zapotec")),
    ("zps", _("Coatlán Zapotec")),
    ("zpt", _("San Vicente Coatlán Zapotec")),
    ("zpu", _("Yalálag Zapotec")),
    ("zpv", _("Chichicapan Zapotec")),
    ("zpw", _("Zaniza Zapotec")),
    ("zpx", _("San Baltazar Loxicha Zapotec")),
    ("zpy", _("Mazaltepec Zapotec")),
    ("zpz", _("Texmelucan Zapotec")),
    ("zqe", _("Qiubei Zhuang")),
    ("zra", _("Kara")),
    ("zrg", _("Mirgan")),
    ("zrn", _("Zerenkel")),
    ("zro", _("Záparo")),
    ("zrp", _("Zarphatic")),
    ("zrs", _("Mairasi")),
    ("zsa", _("Sarasira")),
    ("zsk", _("Kaskean")),
    ("zsl", _("Zambian Sign Language")),
    ("zsm", _("Standard Malay")),
    ("zsr", _("Southern Rincon Zapotec")),
    ("zsu", _("Sukurum")),
    ("zte", _("Elotepec Zapotec")),
    ("ztg", _("Xanaguía Zapotec")),
    ("ztl", _("Lapaguía-Guivini Zapotec")),
    ("ztm", _("San Agustín Mixtepec Zapotec")),
    ("ztn", _("Santa Catarina Albarradas Zapotec")),
    ("ztp", _("Loxicha Zapotec")),
    ("ztq", _("Quioquitani-Quierí Zapotec")),
    ("zts", _("Tilquiapan Zapotec")),
    ("ztt", _("Tejalapan Zapotec")),
    ("ztu", _("Güilá Zapotec")),
    ("ztx", _("Zaachila Zapotec")),
    ("zty", _("Yatee Zapotec")),
    ("zua", _("Zeem")),
    ("zuh", _("Tokano")),
    ("zum", _("Kumzari")),
    ("zun", _("Zuni")),
    ("zuy", _("Zumaya")),
    ("zwa", _("Zay")),
    ("zxx", _("No linguistic content")),
    ("zyb", _("Yongbei Zhuang")),
    ("zyg", _("Yang Zhuang")),
    ("zyj", _("Youjiang Zhuang")),
    ("zyn", _("Yongnan Zhuang")),
    ("zyp", _("Zyphe Chin")),
    ("zza", _("Zaza")),
    ("zzj", _("Zuojiang Zhuang")),
)
